import React, { useState } from 'react'
import { Button, Divider, Form, Row, Col, Card, Table, Select, Modal, Input, InputNumber, message } from "antd"
import { CHARGE_TYPES } from '../../CONSTANT'
import { GetChargeObjBillList, ChargePay } from '../../services/entity'
import { useHistory } from 'react-router'
import { Link } from 'react-router-dom'
import { getBillData } from '../../redux/action/chagre'
import { connect } from 'react-redux'
import './index.scss'

const BillHandle = (prop) => {
  const history = useHistory();
  const location = history.location
  const props: any = location.state
  console.log(props);

  const columns = [
    {
      title: '账单开始时间',
      dataIndex: 'start'
    },
    {
      title: '账单结束时间',
      dataIndex: 'end'
    },
    {
      title: '金额',
      dataIndex: 'amount',
      render: (_, row) => <span>{'￥' + row.amount / 100}</span>
    },
  ]

  const [payForm]: any = Form.useForm()
  const [order_id, setorder_id] = useState()
  const [state, setState]: any = React.useState(() => ({
    visible: false,
    successVisible: false,
    chargeType: '',
    billData: {}
  }))

  const onPay = () => {
    payForm.validateFields().then(async values => {
      const pay_amount = values.pay_amount * 100
      const should_pay_amount = values.should_pay_amount * 100
      const { order_id } = await (await ChargePay({
        bind_ids: [props.bind_id],
        ...values,
        pay_amount,
        should_pay_amount
      })).data
      setorder_id(order_id)
      message.success('缴费成功！')
      payForm.resetFields()
      setState(prevState => ({ ...prevState, visible: false, successVisible: true }))
    })
  }

  React.useEffect(() => {
    setState(prevState => ({
      ...prevState,
      chargeType: CHARGE_TYPES[props.charge_type].text
    }))
    prop.getBillData({
      bind_id: props.bind_id,
      page: 1,
      pageSize: 9999
    })
  }, [])
  console.log(prop);

  return (
    <Card>
      <div className={'page-line'}>
        {props.query.name}
        <Button type='primary' onClick={history.goBack}>返回</Button>
      </div>
      <Divider />
      <Form>
        <Row>
          <Col span={12}>
            <Form.Item label={'费项名称'}>
              {/* {prop.billData.charge_name} */}
              {props.charge_name}
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={'费用说明'}>
              {/* {prop.billData.data?.map(item => item.charge_desc
              )} */}
              {props.desc}
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={'费用类型'}>
              {/* {CHARGE_TYPES[prop.billData.charge_type]} */}
              {CHARGE_TYPES[props.charge_type]}
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={'应收款'}>
              <span className={'form-item__price'}>
                {'￥' + prop.billData.should_pay_amount / 100}
              </span>
            </Form.Item>
          </Col>
        </Row>
        <Row className={'mt-2'}>
          <Col span={24}>
            <Table
              columns={columns}
              dataSource={prop.billData.data}
              pagination={false}
              rowKey="bill_id"
            />
          </Col>
        </Row>
      </Form>
      <div style={{ display: 'flex', justifyContent: 'end', marginTop: "10px" }}>
        <Select
          placeholder='请选择'
          options={[
            { label: '现金', value: 1 },
            { label: '微信', value: 2 },
            { label: '支付宝', value: 3 },
            { label: 'pos', value: 4 },
            { label: '转账', value: 5 },
          ]}
          onChange={(value) => {
            payForm.setFieldsValue({ pay_type: value })
          }}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'end', marginTop: "10px" }}>
        <Button type={'primary'} onClick={() => {
          if (!payForm.getFieldValue('pay_type')) return message.error('请选择支付方式')
          setState(prevState => ({ ...prevState, visible: true }))
          payForm.setFieldsValue({ should_pay_amount: prop.billData.should_pay_amount / 100 })
        }}>收费</Button>
      </div>
      <Modal
        visible={state.visible}
        maskClosable={false}
        title={'收费确认'}
        onOk={onPay}
        onCancel={() => setState(prevState => ({
          ...prevState,
          visible: false
        }))}
      >
        <Form labelCol={{ span: 5 }} form={payForm}>
          <Form.Item label='缴费对象'>
            {props.query.name}
          </Form.Item>
          <Form.Item label='应收金额' name="should_pay_amount" rules={[{ required: true }]}>
            <InputNumber className="w-4/5" disabled placeholder="请输入" addonBefore='￥' />
          </Form.Item>
          <Form.Item label='实收金额' name="pay_amount" rules={[{ required: true }]}>
            <InputNumber className="w-4/5" placeholder="请输入" addonBefore='￥' min={0} />
          </Form.Item>
          <Form.Item label='支付方式' name="pay_type" rules={[{ required: true }]}>
            <Select placeholder='请选择' disabled options={[
              { label: '现金', value: 1 },
              { label: '微信', value: 2 },
              { label: '支付宝', value: 3 },
              { label: 'pos', value: 4 },
              { label: '转账', value: 5 },
            ]} />
          </Form.Item>
          <Form.Item label='备注' name="comment">
            <Input.TextArea placeholder='多行输入' rows={4} />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title={'缴费提示'}
        visible={state.successVisible}
        maskClosable={false}
        footer={false}
        onCancel={() => {
          setState(pre => ({ ...pre, successVisible: false }))
          history.goBack()
        }}
      >
        <div> 缴费成功！</div>
        <div className={'mt-2'} style={{ display: 'flex', justifyContent: "space-between", marginTop: "20px" }}>
          <Button className={'mr-4'} onClick={() => {
            setState(pre => ({ ...pre, successVisible: false }))
            history.goBack()
          }}>返回</Button>
          <Link to={{ pathname: "/admin/charge/print", state: order_id }}>
            <Button
              className={'mr-4'}
              type={'primary'}
            >打印小票</Button>
          </Link>
          <Link to={{ pathname: "/admin/charge/quittance", state: order_id }}>
            <Button className={'mr-4'} type={'primary'}>打印收据</Button>
          </Link>
        </div>
      </Modal>
    </Card>
  )
}
const mapStateToProps = (state) => {
  return {
    billData: state.getBillList.list,
  }
}

const mapDispatchToProps = (dispatch) => {
  return {
    getBillData: (userInput) => dispatch(getBillData(userInput)),
  }
}
export default connect(mapStateToProps, mapDispatchToProps, null, { forwardRef: true })(BillHandle as any)
