import React, { useState, useRef } from 'react'
import ReactToPrint from 'react-to-print';
import ComponentToPrint from './print/ComponentToPrint';
import {
  Button,
  Divider,
  Form,
  Row,
  Col,
  Card,
  InputNumber,
  Select,
  Modal,
  Input,
  DatePicker,
  message
} from "antd"
import './index.scss'
import { ChargePrePay, ChargePrePayInfo } from '../../services/charge'
import { SELECTOR_PAY_TYPES, CHARGE_TYPES, VALUEENUM_PAY_TYPES } from '../../CONSTANT'
import { useHistory } from "react-router"
import querystring from "querystring"
import { Link } from 'react-router-dom'

const BillPreStore: React.FC = () => {
  const componentRef: any = useRef();

  const history = useHistory()
  const [order_id, setorder_id] = useState()
  const [state, setState]: any = React.useState(() => ({
    visible: false,
    successVisible: false,
    query: {},
    chargeType: null
  }))
  const [shouldPay, setShouldPay]: any = React.useState({
    should_pay_amount: 0
  })
  const [month, setMonth] = React.useState([])
  const query = querystring.parse(history.location.search.split('?')[1])
  React.useEffect(() => {
    setState(prevState => ({
      ...prevState,
      query,
      chargeType: CHARGE_TYPES[query.obj_type]
    }))
  }, [])

  React.useEffect(() => {
    const month: any = []
    for (let i = 1; i < 13; i++) {
      month.push({ label: `${i}月`, value: i })
    }
    setMonth(month)
  }, [])
  const [form] = Form.useForm()
  const onPay = () => {
    form.validateFields().then(async values => {
      const bind_id = state.query.obj_id - 0
      if (bind_id == 0) {
        message.warning('暂时不能预存')
      }
      const data = {
        ...values,
        should_pay_amount: shouldPay.should_pay_amount,
        bind_id,
        pay_amount: values.pay_amount * 100,
        months: values.months.valueOf()
      }
       const { order_id } = await (await ChargePrePay(data)).data
       setorder_id(order_id)
      setState(pre => ({ ...pre, visible: false, successVisible: true }))
    })
  }
  const onSubmit = () => {
    form.validateFields().then(async (values) => {
      setState(pre => ({ ...pre, visible: true }))
    })

  }
  const getInfo = async (month) => {
    const bind_id =state.query.obj_id
   if(bind_id==0){
    message.warning('暂时不能预存')
   }else{
    const data = await ChargePrePayInfo({
      bind_id,
      months: month
    })
    setShouldPay(data.data)
   }
  }

  return (
    <><Card>
      <div className={'page-line'}>
        {state.query.name}
        <Button type='primary' onClick={history.goBack}>返回</Button>
      </div>
      <Divider />
      <Form labelCol={{ span: 5 }} form={form}>
        <Row>
          <Col span={12}>
            <Form.Item label={'费项名称'}>
              <span>{shouldPay.charge_name}</span>
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label="费用说明">
              <span>{shouldPay.charge_desc}</span>
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={'费用类型'}>
              <span> {CHARGE_TYPES[query.obj_type]}</span>
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={'应收款'} name="should_pay_amount">
              <span className={'form-item__price'}>{shouldPay.should_pay_amount ? '￥' + shouldPay.should_pay_amount / 100 : ''}</span>
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={'缴费月数'} name="months" rules={[{ required: true }]}>
              <Select style={{ width: 180 }} placeholder="请选择" options={month} onSelect={getInfo}></Select>
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label='支付方式' name="pay_type" rules={[{ required: true }]}>
              <Select style={{ width: 180 }} placeholder={'请选择'} options={SELECTOR_PAY_TYPES} />
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label='备注' name="comment">
              <Input.TextArea placeholder={'多行输入'} rows={4} />
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label='实际收款' name="pay_amount" rules={[{ required: true }]}>
              <InputNumber style={{ width: 180 }} placeholder={'请输入'} />
            </Form.Item>
          </Col>
        </Row>
        <Row justify={'end'}>
          <Button className={'ml-2'} type={'primary'} onClick={onSubmit}>收费</Button>
        </Row>
      </Form>
    </Card>
      <Modal
        visible={state.visible}
        maskClosable={false}
        title={'收费确认'}
        okText="确定收费"
        onOk={onPay}
        onCancel={() => setState(prevState => ({
          ...prevState,
          visible: false
        }))}
      >
        <Form labelCol={{ span: 5 }}>
          <Form.Item label='缴费对象'>
            {state.query.name}
          </Form.Item>
          <Form.Item label='应收金额'>
            <span>{shouldPay.should_pay_amount / 100 + '￥'}</span>
          </Form.Item>
          <Form.Item label='实收金额'>
            <span>{form.getFieldValue("pay_amount") + '￥'}</span>
          </Form.Item>
          <Form.Item label='支付方式'>
            <span>{VALUEENUM_PAY_TYPES[form.getFieldValue("pay_type")]}</span>
          </Form.Item>
          <Form.Item label='备注'>
            <span>{form.getFieldValue("comment")}</span>
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title='缴费提示'
        visible={state.successVisible}
        maskClosable={false}
        footer={false}
        onCancel={() => setState(prevState => ({
          ...prevState,
          successVisible: false,
          visible: false
        }))}
      >
        <div> 缴费成功！</div>
        <div className={'mt-2'} style={{ display: 'flex', justifyContent: "space-between", marginTop: "20px" }}>
          <Button className={'mr-4'} onClick={() => {
            setState(pre => ({ ...pre, successVisible: false }))
            history.goBack()
          }}>返回</Button>
          <Link to={{ pathname: "/admin/charge/print", state: order_id }}>
            <Button
              className={'mr-4'}
              type={'primary'}
            >打印小票</Button>
          </Link>
          <Link to={{pathname:"/admin/charge/quittance",state:order_id}}>
            <Button className={'mr-4'} type={'primary'}>打印收据</Button>
          </Link>
        </div>
      </Modal>
    </>
  )
}

export default BillPreStore
