import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Card, Modal, Form, DatePicker, message } from "antd"
import { useHistory } from "react-router"
import { GetChargeObjBill, ChangeChargeTime } from "../../services/entity"
import { CreateChargeBill } from "../../services/charge"
import { CHARGE_TIME_TYPES, CHARGE_TYPES } from '../../CONSTANT'
import HouseBillHandle from './bill-handle'
import { transitionSecond, GetTimeStamp } from '../../utils/utils'
import querystring from "querystring"
import { Link } from 'react-router-dom'
import moment from 'moment'


const columns: any = [
  {
    title: '费用类型',
    dataIndex: 'charge_type',
    valueEnum: CHARGE_TYPES
  },
  {
    title: '费项名称',
    dataIndex: 'charge_name'
  },
  {
    title: '费用标识',
    dataIndex: 'charge_time_type',
    valueEnum: CHARGE_TIME_TYPES
  },
  {
    title: '建账时间',
    dataIndex: 'created_at'
  },
  {
    title: '计费开始时间',
    dataIndex: 'start'
  },
  {
    title: '计费结束时间',
    dataIndex: 'end'
  },
  {
    title: '说明',
    dataIndex: 'desc',
    align: 'center',
    ellipsis: true,
  },
  {
    title: '状态',
    dataIndex: 'status'
  },
]

export const HouseArrears: React.FC = (props: any) => {
  const actionRef = React.useRef<ActionType>()
  const history = useHistory()
  const [state, setState]: any = React.useState(() => ({
    visible: false,
    billVisible: false,
    payVisible: false,
    query: {},
    time: false
  }))

  const [editId, setEditId] = React.useState(null)
  const [rowData, setRowData] = React.useState({})
  const [form] = Form.useForm()
  const [billForm] = Form.useForm()

  React.useEffect(() => {
    setState(prevState => ({
      ...prevState,
      query: querystring.parse(history.location.search.split('?')[1])
    }))
  }, [])
  const columns2 = [
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      align: 'center',
      width: "200px",
      render: (_, row, index, action) => <>
        {row.has_bill ? <Link to={{ pathname: "/admin/charge/house/bill/handle", state: { ...row, query: state.query } }}>
          <Button type='link'>缴费</Button>
        </Link> :
          <Button type='link' disabled>缴费</Button>
        }
        {
          [2, 3, 4].includes(row.charge_type) ?
            <>
              <Button type='link' onClick={() => {
                setEditId(row.bind_id)
                billForm.resetFields()
                setState(prevState => ({
                  ...prevState,
                  billVisible: true,
                  time: true,
                }))
              }}>生成账单</Button>
            </>
            : <>
              <Button type='link' onClick={() => {
                setState(prevState => ({
                  ...prevState,
                  visible: true
                }))
                setEditId(row.bind_id)
              }}>变更</Button>
            </>
        }
        {row.charge_time_type === 1 ? <Button type='link' onClick={() => {
          setEditId(row.bind_id)
          billForm.resetFields()
          setState(prevState => ({
            ...prevState,
            billVisible: true,
          }))
        }}>生成账单</Button> : null}
      </>
    }
  ]

  const onSubmit = () => {
    form.validateFields().then(async values => {
      let start = GetTimeStamp(moment(values.start).startOf('M').format("YYYY-MM-DD HH:mm:ss"));
      await ChangeChargeTime({ bind_id: editId, start })
      message.success('变更成功！')
      actionRef.current?.reload()
      form.resetFields()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }
  const onCreateBill = () => {
    billForm.validateFields().then(async values => {
      let end = GetTimeStamp(moment(values.end).startOf("M").format("YYYY-MM-DD HH:mm:ss"))
      await CreateChargeBill({ bind_id: editId, end })
      message.success('操作成功！')
      setState(prevState => ({ ...prevState, billVisible: false, time: false }))
    })
  }

  return (
    <React.Fragment>
      <Card>
        <ProTable
          actionRef={actionRef}
          columns={[...columns, ...columns2]}
          rowKey={record => record.bind_id}
          headerTitle={`房间 ${state.query.name}`}
          search={false}
          toolBarRender={() => [
            // <Button type='primary'>创建费用</Button>,
            <Button type='primary' onClick={history.goBack}>返回</Button>
          ]}
          params={state.query}
          request={GetChargeObjBill}
          bordered
        >
        </ProTable>
      </Card>
      <Modal
        width={420}
        visible={state.visible}
        maskClosable={false}
        title="日期变更"
        onOk={onSubmit}
        onCancel={() => setState(prevState => ({
          ...prevState,
          visible: false
        }))}
      >
        <Form form={form} labelCol={{ span: 7 }}>
          <Form.Item label="计费开始时间" name="start" rules={[{ required: true }]}>
            <DatePicker.MonthPicker placeholder='选择时间' />
          </Form.Item>
          <Form.Item label="注">精确到月</Form.Item>
        </Form>
      </Modal>
      <Modal
        width={420}
        visible={state.billVisible}
        maskClosable={false}
        title="生成账单"
        onOk={onCreateBill}
        onCancel={() => setState(prevState => ({
          ...prevState,
          billVisible: false,
          time: false
        }))}
      >
        <Form form={billForm} labelCol={{ span: 7 }}>
          {state.time ? null : <Form.Item label="结束时间" name="end" rules={[{ required: true }]}
            extra="结束时间代表到该月1号0点截止"
          >
            <DatePicker.MonthPicker placeholder='选择时间' />
          </Form.Item>}
        </Form>
      </Modal>

    </React.Fragment>
  )
}

export default HouseArrears
