import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Input, Card, DatePicker, message } from 'antd'
import { withRouter } from 'react-router-dom'
import { GetChargeObjHouse } from '../../services/entity'
import { ChargeBatchUrge } from '../../services/charge'
import { SELECTOR_HOUSE_TYPE2 } from '../../CONSTANT'
import './index.scss'

const ChargeHouse: React.FC = (props: any) => {
  const columns: any = [
    {
      title: '房号',
      dataIndex: 'house_name',
      search: false,
    },
    {
      title: '楼层',
      dataIndex: 'layer',
      search: false,
    },
    {
      title: '类型',
      dataIndex: 'house_type',
      search: false,
      valueEnum: SELECTOR_HOUSE_TYPE2,
    },
    {
      title: '建筑面积',
      dataIndex: 'house_area',
      search: false,
    },
    {
      title: '使用面积',
      dataIndex: 'house_used_area',
      search: false,
    },
    {
      title: '房屋状态',
      dataIndex: 'house_status',
      search: false,
      valueEnum: {
        1: {
          text: '未入驻'
        },
        2: {
          text: '已入驻'
        },
        3:{text:"已出租"}
      },
    },
    { 
      title: '操作',
      dataIndex: 'option',
      search: false,
      align: 'center',
      render: (_, row, index, action) => <div className='controller-group'>
        {row.has_unpay_bill == true ? <Button type='link' onClick={() => {
          props.history.push('/admin/charge/house/arrears' + `?obj_type=1&obj_id=${row.house_id}&name=${row.house_name}`)
        }}>欠费缴费</Button> : <Button type='link' disabled>欠费缴费</Button>}
        <Button type='link' onClick={() => {
          props.history.push('/admin/charge/house/bill' + `?obj_type=1&obj_id=${row.house_id}&name=${row.house_name}`)
        }}>查明费用</Button>
        <Button type='link' onClick={() => {
          props.history.push('/admin/charge/house/prestore' + `?obj_type=1&obj_id=${row.house_property_bind_id}&name=${row.house_name}`)
        }}>预存物业费</Button>
      </div>
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    exportVisible: false
  })
  const [batchData, setBatchData] = React.useState([])

  const actionRef = React.useRef<ActionType>();
  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="house_id"
        request={GetChargeObjHouse}
        search={false}
        // toolBarRender={() => [
        //   <Button
        //     type="primary"
        //     key="primary"
        //     onClick={() => {
        //       ChargeBatchUrge({obj_type:1}).then((res)=>{
        //         setBatchData(res.data)
        //         if(res.data.length>0){
        //         }else{
        //          setState(preState => ({ ...preState, visible: true }))
        //            message.info('没有欠费无需催缴')
        //         }
        //       })
        //       // setState(preState => ({ ...preState, visible: true }))
        //     }}
        //   >批量催缴单</Button>
        // ]}
        columns={columns}
      />
      <Modal
        title='批量创建房屋收费'
        visible={state.visible}
        width={680}
        onOk={() => setState(pre => ({ ...pre, visible: false }))}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
        >
          <Form.Item label='房屋类型'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]} />
            </Select>
          </Form.Item>
          <Form.Item label='收费范围'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]} />
            </Select>
          </Form.Item>
          <Form.Item label='楼栋'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]} />
            </Select>
          </Form.Item>
          <Form.Item label='单元'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]} />
            </Select>
          </Form.Item>
          <Form.Item label='房屋'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]} />
            </Select>
          </Form.Item>
          <Form.Item label='楼层'>
            <Input placeholder='请输入' />
          </Form.Item>
          <Form.Item label='费用类型'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]} />
            </Select>
          </Form.Item>
          <Form.Item label='收费项目'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]} />
            </Select>
          </Form.Item>
          <Form.Item label='房屋状态'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]} />
            </Select>
          </Form.Item>
          <Form.Item label='计费开始时间'>
            <DatePicker />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ChargeHouse)