import React, { useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import type { ProFormInstance } from '@ant-design/pro-form'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Input, DatePicker, Upload, message, Tabs } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { withRouter } from 'react-router-dom'
import { ChargePower, GetHouseList, ChargePowerBatch, GetChargePowerTemplate } from "../../services/charge"
import { transitionSecond } from '../../utils/utils'
import SearchHouse from "../Parking/searchHouse"
import moment from 'moment'

import './index.scss'

const GardenList: React.FC = (props: any) => {

  const formRef: any = React.useRef<ProFormInstance>()
  const actionRef: any = React.useRef<ActionType>()
  const columns: any = [
    {
      title: '房号',
      dataIndex: 'house_name',
      search: false
    },
    {
      title: '费用类型',
      dataIndex: 'charge_type',
      initialValue: '2',
      valueEnum: {
        2: {
          value: 2,
          text: '水费'
        },
        3: {
          value: 3,
          text: '电费'
        },
        4: {
          value: 4,
          text: '气费'
        }
      }
    },
    {
      title: '上期度数',
      dataIndex: 'last_amount',
      search: false,
    },
    {
      title: '本期度数',
      dataIndex: 'current_amount',
      search: false,
    },
    {
      title: '开始时间',
      dataIndex: 'start',
      valueType: 'dateRange',
      render: (_, row: any) => <div>{moment(row.start * 1000).format('YYYY-MM-DD')}</div>,
      search: false
    },
    {
      title: '结束时间',
      dataIndex: 'end',
      valueType: 'dateTime',
      render: (_, row: any) => <div>{moment(row.end * 1000).format('YYYY-MM-DD')}</div>,
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      align: 'center',
      width: 210,
      render: (_, row, index, action) => <>
        <a type='link' onClick={() => {
          Modal.confirm({
            title: '确认删除这条记录吗?',
            content: '你确定删除这条记录吗？',
            onOk: async () => {
              await ChargePower({ method: 'delete', id: row.id })
              message.success('操作成功')
              actionRef.current.reload()
            },
            onCancel() { }
          });
        }}>删除</a>
      </>
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    exportVisible: false,
    editId: null
  })

  // 手动上传文件暂存
  let uploadFile: any = null;
  const [form]: any = Form.useForm()

  const onSubmit = () => {
    form.validateFields().then(async values => {
      // 转换时间戳
      ['start', 'end'].forEach(key => {
        return values[key] = transitionSecond(values[key])
      });
      ['current_amount', 'last_amount'].forEach(key => {
        return values[key] = +parseFloat(values[key]).toFixed(2)
      })
      console.log(charge_type);

      await ChargePower({ method: 'post', charge_type, ...values })
      message.success('操作成功')
      actionRef.current.reloadAndRest()
      form.resetFields()
      // close modal
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }

  const getTemplate = async () => {
    const { data } = await GetChargePowerTemplate()
    window.open(data.url)
  }
  const [charge_type, setcharge_type]: any = useState(2);
  const onChange = (key) => {
    setcharge_type(parseInt(key))
  };
  const getvalue = (value) => {
    console.log(value);
    if (value) {
      form.setFieldsValue({ house_id: value.value })
    }
  }

  return (
    <React.Fragment>
      <Tabs defaultActiveKey="2" onChange={onChange}
      size="large"
      tabBarStyle={{fontWeight:"800"}}
      >
        <Tabs.TabPane tab="水费" key={2}>
          <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={ChargePower}
            search={false}
            params={{ charge_type: 2 }}
            toolBarRender={() => [
              <Button
                type="primary"
                key="primary"
                icon={<PlusOutlined />}
                onClick={() => {
                  setState(preState => ({ ...preState, visible: true }))
                  form.resetFields()
                }}
              >
                抄表
              </Button>,
              <Button
                type="primary"
                key="primary"
                icon={<PlusOutlined />}
                onClick={() => {
                  setState(preState => ({ ...preState, exportVisible: true }))
                }}
              >抄表导入</Button>
            ]}
            columns={columns}
          />
        </Tabs.TabPane>
        <Tabs.TabPane tab="电费" key={3}>
          <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={ChargePower}
            search={false}
            params={{ charge_type: 3 }}
            toolBarRender={() => [
              <Button
                type="primary"
                key="primary"
                icon={<PlusOutlined />}
                onClick={() => {
                  setState(preState => ({ ...preState, visible: true }))
                  form.resetFields()
                }}
              >
                抄表
              </Button>,
              <Button
                type="primary"
                key="primary"
                icon={<PlusOutlined />}
                onClick={() => {
                  setState(preState => ({ ...preState, exportVisible: true }))
                }}
              >抄表导入</Button>
            ]}
            columns={columns}
          />
        </Tabs.TabPane>
        <Tabs.TabPane tab="气费" key={4}>
          <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={ChargePower}
            search={false}
            params={{ charge_type: 4 }}
            toolBarRender={() => [
              <Button
                type="primary"
                key="primary"
                icon={<PlusOutlined />}
                onClick={() => {
                  setState(preState => ({ ...preState, visible: true }))
                  form.resetFields()
                }}
              >
                抄表
              </Button>,
              <Button
                type="primary"
                key="primary"
                icon={<PlusOutlined />}
                onClick={() => {
                  setState(preState => ({ ...preState, exportVisible: true }))
                }}
              >抄表导入</Button>
            ]}
            columns={columns}
          />
        </Tabs.TabPane>
      </Tabs>

      <Modal
        title={state.editId ? '编辑抄表' : '添加抄表'}
        visible={state.visible}
        maskClosable={false}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          name="meter-form"
          form={form}
        >
          <Form.Item label="注">
            <span>抄表录入前，请先配置相应费项，并绑定房屋</span>
          </Form.Item>
          <Form.Item label='房屋' name="house_id" rules={[{ required: true }]}>
            <SearchHouse getValue={getvalue} />
          </Form.Item>
          <Form.Item label='上期度数' name="last_amount" rules={[{ required: true }]}>
            <Input placeholder='单行输入' />
          </Form.Item>
          <Form.Item label='本期度数' name="current_amount" rules={[{ required: true }]}>
            <Input placeholder='单行输入' />
          </Form.Item>
          <Form.Item label='开始时间' name="start" rules={[{ required: true }]}>
            <DatePicker className="w-4/5" placeholder='选择时间' format="YYYY-MM-DD" />
          </Form.Item>
          <Form.Item label='结束时间' name="end" rules={[{ required: true }]}>
            <DatePicker className="w-4/5" placeholder='选择时间' format="YYYY-MM-DD" />
          </Form.Item>
          <Form.Item label='备注' name="comment">
            <Input.TextArea rows={4} placeholder='多行输入' />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title='抄表导入'
        visible={state.exportVisible}
        maskClosable={false}
        onOk={async () => {
          if (!uploadFile) message.error('请先选择文件！')
          const files = new FormData()
          files.append('file', uploadFile)
          await ChargePowerBatch({
            charge_type,
            file: files
          })
          message.success('上传成功')
          actionRef.current.reloadAndRest()
          setState(prevState => ({
            ...prevState,
            exportVisible: false
          }))
          uploadFile = null
        }}
        destroyOnClose={true}
        onCancel={() => {
          setState(prevState => ({
            ...prevState,
            exportVisible: false
          }))
          uploadFile = null
        }}
        okText="导入"
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 16 }}
        >
          <Form.Item label='选择文件'>
            <Upload
              beforeUpload={file => {
                uploadFile = file
                return false
              }}
              maxCount={1}
            >
              <Button>选择文件</Button>
            </Upload>
          </Form.Item>
          <Form.Item label='下载模板'>
            请先下载 <span className='link-primary' onClick={getTemplate}>导入模板</span> 准备数据后，上传导入
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(GardenList)