import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Card, Modal, Form, DatePicker, message } from "antd"
import { useHistory } from "react-router"
import { GetChargeObjBill, ChangeChargeTime } from "../../services/entity"
import { CreateChargeBill } from "../../services/charge"
import { CHARGE_TYPES } from '../../CONSTANT'
import BillHandle from './bill-handle'
import querystring from "querystring"
import { GetTimeStamp } from '../../utils/utils'
import moment from 'moment'
import { Link } from 'react-router-dom'


const columns: any = [
  {
    title: '费用类型',
    dataIndex: 'charge_type',
    valueEnum: CHARGE_TYPES
  },
  {
    title: '费项名称',
    dataIndex: 'charge_name'
  },
  {
    title: "开始时间",
    dataIndex:"start",
  },
  {
    title: '建账时间',
    dataIndex: 'created_at'
  },
  {
    title: '说明',
    dataIndex: 'desc',
    ellipsis: true,
  }
]

export const ParkingPositionBill: React.FC = () => {
  const actionRef = React.useRef<ActionType>()
  const history = useHistory()
  const [state, setState]: any = React.useState(() => ({
    visible: false,
    billVisible: false,
    payVisible: false,
    query: {}
  }))

  const [editId, setEditId] = React.useState(null)
  const [form] = Form.useForm()
  const [billForm] = Form.useForm()

  React.useEffect(() => {
    setState(prevState => ({
      ...prevState,
      query: querystring.parse(history.location.search.split('?')[1])
    }))
  }, [])
  const columns2 = [
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 210,
      align: 'center',
      render: (_, row, index, action) => <>
        <Link to={{ pathname: "/admin/charge/house/bill/handle", state: { ...row, query: state.query } }}>
          <Button type='link'>缴费</Button>
        </Link>
        <Button type='link' onClick={() => {
          setState(prevState => ({
            ...prevState,
            visible: true
          }))
          setEditId(row.bind_id)
        }}>变更</Button>
        {row.charge_time_type === 1 || [2, 3, 4].includes(row.charge_type) ?
          <Button type='link' onClick={() => {
            setEditId(row.bind_id)
            billForm.resetFields()
            setState(prevState => ({
              ...prevState,
              billVisible: true
            }))
          }}>生成账单</Button> : null
        }
      </>

    }
  ]

  const onSubmit = () => {
    form.validateFields().then(async values => {
      let start = GetTimeStamp(moment(values.start).startOf('M').format("YYYY-MM-DD HH:mm:ss"));
      await ChangeChargeTime({ bind_id: editId, start })
      message.success('变更成功！')
      actionRef.current?.reload()
      form.resetFields()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }
  const onCreateBill = () => {
    billForm.validateFields().then(async values => {
      let end = GetTimeStamp(moment(values.end).startOf("M").format("YYYY-MM-DD HH:mm:ss"))
      await CreateChargeBill({ bind_id: editId, end })
      message.success('操作成功！')
      setState(prevState => ({ ...prevState, billVisible: false }))
    })
  }

  return (
    <React.Fragment>
      <Card>
        <ProTable
          actionRef={actionRef}
          rowKey="bind_id"
          columns={[...columns, ...columns2]}
          headerTitle={`${state.query.name}`}
          search={false}
          toolBarRender={() => [
            <Button type='primary' onClick={history.goBack}>返回</Button>
          ]}
          params={state.query}
          request={GetChargeObjBill}
          bordered
        >
        </ProTable>
      </Card>
      <Modal
        width={420}
        visible={state.billVisible}
        maskClosable={false}
        title="生成账单"
        onOk={onCreateBill}
        onCancel={() => setState(prevState => ({
          ...prevState,
          billVisible: false
        }))}
      >
        <Form form={billForm} labelCol={{ span: 7 }}>
          <Form.Item label="结束时间" name="end" rules={[{ required: true }]}
            extra="结束时间月份代表到该月1号0点截止"
          >
            <DatePicker.MonthPicker placeholder='选择时间' />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        width={420}
        visible={state.visible}
        maskClosable={false}
        title="日期变更"
        onOk={onSubmit}
        onCancel={() => setState(prevState => ({
          ...prevState,
          visible: false
        }))}
      >
        <Form form={form} labelCol={{ span: 7 }}>
          <Form.Item label="计费开始时间" name="start" rules={[{ required: true }]}>
            <DatePicker placeholder='选择时间' />
          </Form.Item>
        </Form>
      </Modal>
      {/*  */}
    </React.Fragment>
  )
}

export default ParkingPositionBill
