import React, { useEffect, useState } from 'react'
import ProTable from "@ant-design/pro-table"
import { Button, Modal, Form } from "antd"
import { GetPayedBill } from "../../services/charge"
import { CHARGE_TYPES, VALUEENUM_PAY_TYPES } from "../../CONSTANT"
import { ChargeConfig } from '../../services/charge'

const PayedBill: React.FC = () => {
  const [state, setState] = React.useState({ visible: false })
  const [rowData, setRowData] = React.useState({});
  const [charge_type, setCharge_type]: any = useState("");
  const request = async (params) => {
    const { charge_type } = params;
    if (charge_type) {
      const { data } = await ChargeConfig({ page: -1, page_size: -1, ...params });
      return data?.map(({ charge_name }) => ({ value: charge_name, label: charge_name }))
    }
  };
  const columns: any = [
    {
      title: '房屋/车位/车辆',
      dataIndex: 'obj_name',
      search: true,
    },
    {
      title: '费用类型',
      dataIndex: 'charge_type',
      valueEnum: CHARGE_TYPES,
      search: true,
      fieldProps: (form, config) => {
        return {
          onChange: (e) => {
            setCharge_type(e)
            form.resetFields(['charge_name'])
          },
          onClear: (e) => {
            form.resetFields(['charge_name'])
          },
        }
      }
    },
    {
      title: '费项名称',
      dataIndex: 'charge_name',
      search: true,
      request,
      fieldProps: { placeholder: "请先选择费用类型" },
      params: { charge_type }
    },
    {
      title: '应收金额',
      dataIndex: 'amount',
      search: false,
      render: (_, row) => <span>{`￥${row.amount / 100}`}</span>
    },
    {
      title: '支付方式',
      dataIndex: 'pay_type',
      search: false,
      render: (_, row) => <span>{VALUEENUM_PAY_TYPES[row.pay_type]}</span>
    },
    {
      title: '支付时间',
      dataIndex: 'pay_time',
      search: false
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      align: 'center',
      render: (_, row, index, action) => <>
        <a
          onClick={() => {
            setState(prevState => ({ ...prevState, visible: true }))
            setRowData(row)
          }}
        >详情</a>
      </>
    }
  ]


  return (
    <React.Fragment>
      <ProTable
        columns={columns}
        rowKey="bill_id"
        request={GetPayedBill}
        bordered
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6, labelWidth: 'auto',
          optionRender: (searchConfig, formProps, dom) => [
            <Button key="rest" onClick={() => {
              formProps.form?.resetFields();
              setCharge_type('')
            }}>
              重置
            </Button>,
            dom[1],
          ],
        }}
      />
      <Modal
        title="详情"
        visible={state.visible}
        maskClosable={false}
        footer={false}
        onCancel={() => setState(prevState => ({ ...prevState, visible: false }))}
      >
        <Form>
          {
            columns.slice(0, columns.length - 1).map(item => {
              if (item.dataIndex == 'amount') {
                return <Form.Item label={item.title} key={item.title}>
                  {rowData[item.dataIndex] / 100 + "元"}
                </Form.Item>
              } else if (item.dataIndex == "charge_type") {
                return <Form.Item label={item.title} key={item.title}>
                  {CHARGE_TYPES[rowData[item.dataIndex]]}
                </Form.Item>
              } else if (item.dataIndex == "pay_type") {
                return <Form.Item label={item.title} key={item.title}>
                  {VALUEENUM_PAY_TYPES[rowData[item.dataIndex]]}
                </Form.Item>
              }
              else {
                return <Form.Item label={item.title} key={item.title}>
                  {rowData[item.dataIndex]}
                </Form.Item>
              }
            }
            )
          }
          <Form.Item label="费用描述">
            {rowData['charge_desc']}
          </Form.Item>
          <Form.Item label="开始时间-结束时间">
            {rowData['start']} - {rowData['end']}
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default PayedBill
