import React, { useState } from 'react'
import ProTable, { ActionType } from "@ant-design/pro-table"
import { Button, Form, message, Modal, Select } from "antd";
import { GetChargeOrderList, ChargeOrderConfirm } from "../../services/charge"
import { SELECTOR_PAY_TYPES } from "../../CONSTANT"
import { Link } from 'react-router-dom';

const columns: any = [
  {
    title: '房间/车位/车牌',
    dataIndex: 'obj_name',
  },
  {
    title: '订单号',
    dataIndex: 'order_id',
    search: false,
    align: "center",
    ellipsis: true,
  },
  {
    title: '总费用',
    dataIndex: 'should_pay_amount',
    search: false,
    align: "center",
    render: (_, row) => <span>应该支付：{row.should_pay_amount / 100}<br />实际支付：{row.pay_amount / 100}</span>
  },
  {
    title: '支付方式',
    dataIndex: 'pay_type',
    search: true,
    valueEnum: () => {
      const enums = {}
      SELECTOR_PAY_TYPES.forEach(item => {
        enums[item.value] = { text: item.label }
      })
      return enums
    }
  },
  {
    title: "支付状态",
    dataIndex: "pay_status",
    hideInTable: true,
    valueType: "select",
    valueEnum: {
      1: "待支付",
      2: "已支付"
    }
  },
  {
    title: '支付状态',
    dataIndex: 'status',
    valueEnum: {
      1: { text: '待支付' },
      2: { text: '已支付' },
    },
    search: false
  },
  {
    title: '三方订单',
    dataIndex: 'transaction_id',
    search: false,
    ellipsis: true,
  }
]

const PaymentBill: React.FC = () => {
  const [state, setState] = React.useState({
    visible: false,
    order_id: ''
  })
  const [printType, setPrintType] = useState('print')
  const [form] = Form.useForm();
  const columns2 = [{
    title: '操作',
    dataIndex: 'option',
    search: false,
    width: 210,
    align: 'center',
    render: (_, row, index, action) => <>
      {row.status == 1 ? <Button type='link' onClick={() => {
        Modal.confirm({
          title: '确认收款',
          content: '你确定要将这条记录确认收款吗？',
          onOk: async () => {
            await ChargeOrderConfirm({ order_id: row.order_id })
            message.success('操作成功！')
            actionRef.current.reload()
          }
        })
      }}>确认收款</Button> : <Button type='link' disabled>确认收款</Button>}
      <Button type='link' onClick={() => {
        form.resetFields()
        setState(prevState => ({
          ...prevState,
          visible: true,
          order_id: row.order_id
        }))
      }}>打印</Button>
      <Link to={{ pathname: "/admin/charge/payment-bill/detail", state: { order_id: row.order_id } }}>
        <Button type='link'>账单详情</Button>
      </Link>
    </>
  }]

  const actionRef: any = React.useRef<ActionType>()
  const cancleModal = () => {
    setState(prevState => ({
      ...prevState,
      visible: false,
      order_id: ""
    }))
  }
  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="order_id"
        columns={columns.concat(columns2)}
        request={GetChargeOrderList}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6, labelWidth: 'auto'
        }}
        bordered
      />
      <Modal
        title="打印"
        width={400}
        visible={state.visible}
        maskClosable={false}
        onCancel={cancleModal}
        footer={<>
          <Button type='default' style={{ marginRight: "10px" }}>取消</Button>
          <Link to={{ pathname: `/admin/charge/${printType}`, state: state.order_id }}>
            <Button type='primary'>确定</Button>
          </Link>
        </>}
      >
        <Form form={form} initialValues={{ printType: 'print' }}>
          <Form.Item label="请选择打印类型" name="printType" rules={[{ required: true, message: "请选择打印类型" }]}>
            <Select style={{ width: 200 }} options={[
              { label: "小票", value: "print" },
              { label: "收据", value: 'quittance' }
            ]}
              onChange={(value) => {
                setPrintType(value)
              }}
            />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default PaymentBill
