import { Form, Button, Table, Row, Col } from "antd";
import React, { useEffect, useState } from "react";
import { useHistory } from "react-router";
import { getTicketList } from "../../../redux/action/ticket";
import { connect } from "react-redux";
import { CHARGE_TYPES } from "../../../CONSTANT";
import "./print.scss"

const Quittance = React.forwardRef((props: any, ref: any) => {
    const history = useHistory()
    const location = history.location
    const order_id: any = location.state

    useEffect(() => {
        props.getTicketList({ order_id })
    }, [])
    const columns: any = [
        {
            title: "费用类型",
            dataIndex: "charge_type",
            render: (_, row) => <span>{CHARGE_TYPES[row.charge_type]}</span>
        },
        {
            title: "费项名称",
            dataIndex: "charge_name",
        },
        {
            title: "房屋/车位/车辆",
            dataIndex: "obj_name",
        },
        {
            title: "收费范围",
            dataIndex: "start",
            render: (_, row) => <span>{`${row.start}至${row.end}`}</span>
        },
        {
            title: "单价/固定费",
            dataIndex: "unit_price",
            render: (_, row) => <span>{`${(row.unit_price / 100).toFixed(2)}/${(row.fix_amount / 100).toFixed(2)}`}</span>
        },
        {
            title: "面积/用量",
            dataIndex: "area_used"
        },
        {
            title: "金额",
            dataIndex: "amount",
            render: (_, row) => <span>{(row.amount / 100).toFixed(2)}</span>
        }, {
            title: "单位",
            render: () => <span>元</span>
        },
        {
            title: "备注",
            dataIndex: "comment"
        }
    ]
    function cnMoneyFormat(money) {
        var cnMoney = "零元整";
        var strOutput = "";
        var strUnit = '仟佰拾亿仟佰拾万仟佰拾元角分';
        money += "00";
        var intPos = money.indexOf('.');
        if (intPos >= 0) {
            money = money.substring(0, intPos) + money.substr(intPos + 1, 2);
        }
        strUnit = strUnit.substr(strUnit.length - money.length);
        for (var i = 0; i < money.length; i++) {
            strOutput += '零壹贰叁肆伍陆柒捌玖'.substr(money.substr(i, 1), 1) + strUnit.substr(i, 1);
        }
        cnMoney = strOutput.replace(/零角零分$/, '整').replace(/零[仟佰拾]/g, '零').replace(/零{2,}/g, '零').replace(/零([亿|万])/g, '$1').replace(/零+元/, '元').replace(/亿零{0,3}万/, '亿').replace(/^元/, "零元");
        return cnMoney;
    }
    return (
        <div ref={ref} className="printPad">
            <h1 style={{ textAlign: 'center', fontSize: "20px" }}>收据单</h1>
            <div className="tableHeader">
                <span>住户姓名：</span>
                <span>单号：{order_id}</span>
                <span>时间：{props.ticket_info.map(item => {
                    return item.pay_time
                })}</span>
            </div>
            <Table
                columns={columns}
                dataSource={props.ticket_info}
                pagination={false}
                bordered
                summary={pageData => {
                    return (
                        <>
                            <Table.Summary.Row className="tableFooter">
                                <Table.Summary.Cell index={0} colSpan={3}>大写人民币（元）</Table.Summary.Cell>
                                <Table.Summary.Cell index={1} colSpan={3}>
                                    <span>{cnMoneyFormat(pageData.map(item => {
                                        return item.amount / 100
                                    }))}</span>
                                </Table.Summary.Cell>
                                <Table.Summary.Cell index={2} colSpan={3}>
                                    <span>{pageData.map(item => {
                                        return (item.amount / 100).toFixed(2)
                                    })}</span>
                                </Table.Summary.Cell>
                            </Table.Summary.Row>
                        </>
                    );
                }}
            />
            <div className="printFooter">
                <span>部门负责人：</span>
                <span>经办人：</span>
                <span>财务收款：</span>
                <span>客户确认:</span>
            </div>
        </div>
    );
});


const mapStateToProps = (state) => {
    return {
        ticket_info: state.getTicketInfo.list,
    }
}

const mapDispatchToProps = (dispatch) => {
    return {
        getTicketList: (userInput) => dispatch(getTicketList(userInput)),
    }
}

export default connect(mapStateToProps, mapDispatchToProps, null, { forwardRef: true })(Quittance)