import React ,{useState}from 'react'
import ProTable from "@ant-design/pro-table"
import { Button, Modal, message } from "antd"
import { GetDiscardBill, RecoverDiscardBill } from '../../services/charge'
import { CHARGE_TIME_TYPES, CHARGE_TYPES } from '../../CONSTANT'
import { ChargeConfig } from '../../services/charge'
import type { ActionType } from "@ant-design/pro-table";

const ScrapBill: React.FC = () => {
  const actionRef: any = React.useRef<ActionType>();
  const [charge_type, setCharge_type]: any = useState("");
  const request = async (params) => {
    const { charge_type } = params;
    if (charge_type) {
      const { data } = await ChargeConfig({ page: -1, page_size: -1, ...params });
      return data?.map(({ charge_name }) => ({ value: charge_name, label: charge_name }))
    }
  };

  const columns: any = [
    {
      title: '房屋/车位',
      dataIndex: 'obj_name',
      search: true,
      ellipsis: true,
    },
    {
      title: '费用类型',
      dataIndex: 'charge_type',
      search: true,
      valueType: 'select',
      valueEnum: CHARGE_TYPES,
      fieldProps: (form, config) => {
        return {
          onChange: (e) => {
            setCharge_type(e)
            form.resetFields(['charge_name'])
          },
          onClear: (e) => {
            form.resetFields(['charge_name'])
          },
        }
      }
    },
    {
      title: '费项名称',
      dataIndex: 'charge_name',
      search: true,
      request,
      fieldProps: { placeholder: "请先选择费用类型" },
      params: { charge_type }
    },
    {
      title: '应收金额',
      dataIndex: 'amount',
      search: false,
      render: (_, row) => <span>{`￥${row.amount / 100}`}</span>
    },
    {
      title: '账单开始时间',
      dataIndex: 'start',
      tooltip: "账单开始时间",
      search: false,
      ellipsis: true,
    },
    {
      title: '账单结束时间',
      dataIndex: 'end',
      tooltip: "账单结束时间",
      search: false,
      ellipsis: true,
    },
    {
      title: '上次度数',
      dataIndex: 'last_used',
      search: false
    },
    {
      title: '本次度数',
      dataIndex: 'current_used',
      search: false
    },
    {
      title: '账单作废时间',
      tooltip: "账单作废时间",
      dataIndex: 'del_at',
      search: false,
      ellipsis: true,
    },
    {
      title: '作废原因',
      dataIndex: 'del_reason',
      search: false,
      ellipsis: true,
    }, {
      title: "操作",
      dataIndex: "option",
      align: "center",
      search: false,
      render: (_, row) => <Button type='link' onClick={() => recoverBill(row.bill_id)}>恢复账单</Button>
    }
  ]
  const recoverBill = (bill_id) => {
    Modal.confirm({
      title: "恢复账单",
      content: "你确定恢复这条记录吗？",
      onOk: async () => {
        await RecoverDiscardBill({ bill_id });
        message.success("操作成功！");
        actionRef.current.reload();
      }
    });
  }
  return (
    <ProTable
      columns={columns}
      actionRef={actionRef}
      rowKey="del_at"
      request={GetDiscardBill}
      bordered
      search={{
        collapsed: false, collapseRender: () => false,
        span: 6, labelWidth: 'auto',
        optionRender: (searchConfig, formProps, dom) => [
          <Button key="rest" onClick={() => {
            formProps.form?.resetFields();
            setCharge_type('')
          }}>
            重置
          </Button>,
          dom[1],
        ],
      }}
    />
  )
}

export default ScrapBill
