import React, { useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, InputNumber, Space, DatePicker, message } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { withRouter } from 'react-router-dom'
import { GetChargeCar, ChargeBind, ChargeUnbind } from "../../services/entity"
import { transitionSecond } from '../../utils/utils'
import './index.scss'
import { VALUEENUM_CAR_TYPE } from '../../CONSTANT'
import moment from 'moment'

const SetupBindRoom: React.FC = (props: any) => {
  const charge_id = props.location.state.id;
  const { charge_basis } = props.location.state;
  const columns: any = [
    {
      title: '车牌',
      dataIndex: 'plate_no',
      search: false,
    },
    {
      title: '车辆类型',
      dataIndex: 'vehicle_type',
      search: false,
      valueEnum: VALUEENUM_CAR_TYPE
    },
    {
      title: '停车开始时间',
      dataIndex: 'start',
      search: false,
      render: (_, row) => <span>{row.start !== 0 ? moment(row.start * 1000).format("YYYY-MM-DD") : '-'}</span>
    },
    {
      title: '停车结束时间',
      dataIndex: 'end',
      search: false,
      render: (_, row) => <span>{row.end !== 0 ? moment(row.end * 1000).format("YYYY-MM-DD") : '-'}</span>
    },
    {
      title: "自定义费用",
      dataIndex:"custom_fee",
      search:false,
      hideInTable:charge_basis==6?false:true,
      align:"center",
      render:(_,row)=>row.custom_fee/100
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 210,
      align: 'center',
      render: (_, row, index, action) => <a onClick={() => {
        Modal.confirm({
          title: '解除绑定?',
          content: '你确定解除绑定吗？',
          onOk: async () => {
            await ChargeUnbind({
              charge_id,
              obj_id: row.vehicle_id
            })
            message.success('操作成功')
            actionRef.current.reload()
          }
        })
      }}>移除</a>
    }
  ]
  const [state, setState] = React.useState({
    bindVisible: false
  })
  const actionRef: any = React.useRef<ActionType>()
  const [form]: any = Form.useForm();
  const ref = React.useRef<ActionType>() as any
  const [selectedRowKeys, setSelectedRowKeys]: any = useState([]);
  const Tablecolumns: any = [
    {
      title: '车牌',
      dataIndex: 'plate_no',
      render: (_) => <a>{_}</a>,
    },
    {
      title: '操作',
      search: false,
      align: 'right',
      render: (_, row) => <>
        {selectedRowKeys.find(item => {
          if (item == row.vehicle_id) {
            return true
          }
        }) ? "已选择" : "未选择"}
      </>
    },
  ];
  const rowSelection = {
    selectedRowKeys,
    onSelect: (record, selected, selectedRow) => {
      let keys = [...selectedRowKeys]
      if (selected) {
        keys = [...selectedRowKeys, record.vehicle_id]
      } else {
        keys = selectedRowKeys.filter((item) => item !== record.vehicle_id)
      }
      setSelectedRowKeys(keys)
    },
    onSelectAll: (selected, selectedRows, changeRows) => {
      if (selected) {
        const addCheckedKeys = changeRows.map((item) => {
          return item.vehicle_id
        })
        setSelectedRowKeys([...selectedRowKeys, ...addCheckedKeys])
      } else {
        const subCheckedKeys = selectedRowKeys.filter((vehicle_id) => {
          return !changeRows.some((item) => {
            return item.vehicle_id === vehicle_id
          })
        })
        setSelectedRowKeys(subCheckedKeys)
      }
    },
    onChange: (record, selected, selectedRow) => {
      const { type } = selectedRow;
      if (type == "none") {
        setSelectedRowKeys([])
      }
    },
  }

  const handleBind = () => {
    form.validateFields().then(async (values) => {
      const { custom_fee } = values;
      ['start', 'end'].forEach(key => {
        values[key] = transitionSecond(values[key])
      })
      if (selectedRowKeys.length > 0) {
        await ChargeBind({
          charge_id,
          ...values,
          obj_ids: selectedRowKeys,
          custom_fee: custom_fee ? custom_fee * 100 : 0,
        })
        message.success('操作成功')
        ref.current.reloadAndRest();
      } else {
        message.info("请选择车位")
      }

    })
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey={r => r.vehicle_id}
        params={{
          charge_id,
          bind: true
        }}
        search={false}
        request={GetChargeCar}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={async () => {
              form.resetFields()
              await setState(preState => ({ ...preState, bindVisible: true }))
              ref.current.reloadAndRest();
            }}
          >
            <PlusOutlined /> 绑定车辆
          </Button>
        ]}
        columns={columns}
      />
      <Modal
        title='收费车辆绑定'
        width={800}
        visible={state.bindVisible}
        maskClosable={false}
        okText="绑定"
        onOk={handleBind}
        onCancel={() => {
          setState(pre => ({ ...pre, bindVisible: false }));
          actionRef.current?.reloadAndRest();
          setSelectedRowKeys([]);
        }}
      >
        <ProTable
          columns={Tablecolumns}
          actionRef={ref}
          rowSelection={{
            ...rowSelection,
            // selections: [Table.SELECTION_INVERT],
            defaultSelectedRowKeys: [],
            alwaysShowAlert: true,
          }}
          tableAlertRender={({ selectedRowKeys, selectedRows, onCleanSelected }) => {
            return (
              <Space size={24}>
                <span>
                  已选 {selectedRowKeys.length} 项
                </span>
              </Space>
            )
          }}
          request={GetChargeCar}
          search={false}
          params={{
            charge_id,
            bind: false
          }}
          pagination={{ defaultPageSize: 10 }}
          toolBarRender={false}
          rowKey="vehicle_id"
        />
        <div className={'mb-4'}>非必填，不填表示车辆剩余时间为0</div>
        <Form form={form}
          labelCol={{ span: 8 }}
          wrapperCol={{ span: 8, offset: 2 }}
        >
          <Form.Item label='停车开始时间（天）' name="start">
            <DatePicker style={{ width: "100%" }} />
          </Form.Item>
          <Form.Item label='停车结束时间（天）' name="end" extra="结束日期代表到该日期0点截止">
            <DatePicker style={{ width: "100%" }} />
          </Form.Item>
          {charge_basis == 6 ? <Form.Item label='自定义金额' name="custom_fee"
            rules={[{ required: true, message: "请输入自定义费用" }]}>
            <InputNumber style={{ width: "100%" }} placeholder="请输入自定义金额" min={1} />
          </Form.Item> : null}
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(SetupBindRoom)