import React, { useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, InputNumber, Card, DatePicker, Space, message } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { withRouter } from 'react-router-dom'
import { GetChargeHouse, ChargeBind, ChargeUnbind } from "../../services/entity"
import { GetTimeStamp } from '../../utils/utils'
import moment from 'moment'
import './index.scss'

const SetupBindRoom: React.FC = (props: any) => {
  const charge_id = +props.location.search.split('=')[1];
  const columns: any = [
    {
      title: '房屋',
      dataIndex: 'house_name',
      search: false,
    },
    {
      title: '类型',
      dataIndex: 'house_type',
      search: false,
      valueEnum: {
        1: {
          text: '公寓'
        },
        2: {
          text: '住房'
        }
      },
    },
    {
      title: '建筑面积',
      dataIndex: 'house_area',
      search: false,
    },
    {
      title: '使用面积',
      dataIndex: 'house_used_area',
      search: false,
    },
    {
      title: '房屋状态',
      dataIndex: 'house_status',
      search: false,
      valueEnum: {
        1: { text: '未入驻' },
        2: { text: '已入驻' },
        3: { text: '已出租' },
      },
    },
    {
      title: '账单开始计费时间',
      dataIndex: 'start',
      search: false,
      render: (_, row) => <span>{row.start !== 0 ? moment(row.start * 1000).format("YYYY-MM-DD") : '-'}</span>
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 210,
      align: 'center',
      render: (_, row, index, action) => <a onClick={() => {
        Modal.confirm({
          title: '解除绑定?',
          content: '你确定解除绑定这条记录吗？',
          onOk: async () => {
            await ChargeUnbind({
              charge_id,
              obj_id: row.house_id
            })
            message.success('操作成功')
            actionRef.current.reload()
          }
        })
      }}>移除</a>
    }
  ]
  const [state, setState] = React.useState({
    bindVisible: false
  })

  const actionRef: any = React.useRef<ActionType>();
  const [form]: any = Form.useForm();
  const ref = React.useRef<ActionType>() as any
  const [selectedRowKeys, setSelectedRowKeys]: any = useState([]);

  const handleBind = () => {
    form.validateFields().then(async (values) => {
      let start = GetTimeStamp(moment(values.start).startOf('M').format("YYYY-MM-DD HH:mm:ss"));
      if (selectedRowKeys.length > 0) {
        await ChargeBind({
          charge_id: +props.location.search.split('=')[1],
          start,
          obj_ids: selectedRowKeys
        })
        message.success('操作成功')
        ref.current.reloadAndRest();
      } else {
        message.info("请选择房屋")
      }
    })
  }
  const Tablecolumns: any = [
    {
      title: '房屋',
      dataIndex: 'house_name',
      render: (_) => <a>{_}</a>,
    },
    {
      title: '操作',
      search: false,
      align: 'right',
      render: (_, row) => <>
        {selectedRowKeys.find(item => {
          if (item == row.house_id) {
            return true
          }
        }) ? "已选择" : "未选择"}
      </>
    },
  ];
  const rowSelection = {
    selectedRowKeys,
    onSelect: (record, selected, selectedRow) => {
      let keys = [...selectedRowKeys]
      if (selected) {
        keys = [...selectedRowKeys, record.house_id]
      } else {
        keys = selectedRowKeys.filter((item) => item !== record.house_id)
      }
      setSelectedRowKeys(keys)
    },
    onSelectAll: (selected, selectedRows, changeRows) => {
      if (selected) {
        const addCheckedKeys = changeRows.map((item) => {
          return item.house_id
        })
        setSelectedRowKeys([...selectedRowKeys, ...addCheckedKeys])
      } else {
        const subCheckedKeys = selectedRowKeys.filter((house_id) => {
          return !changeRows.some((item) => {
            return item.house_id === house_id
          })
        })
        setSelectedRowKeys(subCheckedKeys)
      }
    },
    onChange: (record, selected, selectedRow) => {
      const { type } = selectedRow;
      if (type == "none") {
        setSelectedRowKeys([])
      }
    },
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="house_id"
        params={{
          charge_id,
          bind: true
        }}
        search={false}
        request={GetChargeHouse}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={async() => {
              form.resetFields()
             await setState(preState => ({ ...preState, bindVisible: true }));
              ref.current.reloadAndRest();
            }}
          >
            <PlusOutlined /> 绑定房屋
          </Button>
        ]}
        columns={columns}
      />
      <Modal
        title='收费房屋绑定'
        width={800}
        visible={state.bindVisible}
        maskClosable={false}
        okText="绑定"
        onOk={handleBind}
        onCancel={() => {
          setState(pre => ({ ...pre, bindVisible: false }));
          actionRef.current?.reloadAndRest();
          setSelectedRowKeys([]);
        }}
      >
        <ProTable
          columns={Tablecolumns}
          actionRef={ref}
          rowSelection={{
            ...rowSelection,
            // selections: [Table.SELECTION_INVERT],
            defaultSelectedRowKeys: [],
            alwaysShowAlert: true,
          }}
          tableAlertRender={({ selectedRowKeys, selectedRows, onCleanSelected }) => {
            return (
              <Space size={24}>
                <span>
                  已选 {selectedRowKeys.length} 项
                </span>
              </Space>
            )
          }}
          request={GetChargeHouse}
          search={{
            collapsed: false, collapseRender: () => false,
            span: 8, labelWidth: 'auto'
          }}
          params={{
            charge_id,
            bind: false
          }}
          pagination={{ defaultPageSize: 10 }}
          toolBarRender={false}
          rowKey="house_id"
        />
        <Form layout="vertical" form={form}>
          <Form.Item label='账单开始计费时间（月）' name="start" rules={[{ required: true }]}>
            <DatePicker picker="month" />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(SetupBindRoom)