import React, { useEffect } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Input, Card, DatePicker, Avatar, message, InputNumber } from 'antd'
import { PlusOutlined, CarOutlined, ClockCircleOutlined, createFromIconfontCN } from '@ant-design/icons'
import { Link, withRouter } from 'react-router-dom'
import TypeForm, { formTypes, LateFee } from "./type-form"
import OptionType from './type-form-option'
import { ChargeConfig, CreateChargeBill } from "../../services/charge"
import { CHARGE_TYPES, CHARGE_TIME_TYPES } from "../../CONSTANT"
import { GetTimeStamp } from '../../utils/utils'
import moment from 'moment'
import './index.scss'
import { center } from '@antv/g2plot/lib/plots/sankey/sankey'

const bindTypeStyle = { display: 'flex', alignItems: 'center', justifyContent: 'center' }
const Avatar2: any = Avatar

const ChargeSetup: React.FC = (props: any) => {
  const columns: any = [
    {
      title: '费用类型',
      dataIndex: 'charge_type',
      // 物业费 2 水费 3 电费 4 气费 5 车位管理费 6 月租停车费 99 其他
      search: false,
      valueEnum: CHARGE_TYPES,
    },
    {
      title: '费项名称',
      dataIndex: 'charge_name',
      search: false
    },
    {
      title: '费用方式',
      dataIndex: 'charge_time_type',
      search: false,
      valueEnum: CHARGE_TIME_TYPES,
      align: center
    },
    {
      title: '账单生成周期',
      dataIndex: 'bill_period',
      search: false,
      valueEnum: {
        0: { text: '-' },
        1: {
          text: '月份'
        },
        2: {
          text: '季度'
        },
        3: {
          text: '半年'
        },
        4: {
          text: '年'
        },
      }
    },
    {
      title: '收费方式',
      dataIndex: 'charge_basis',
      search: false,
      valueEnum: {
        1: { text: '按房屋面积' },
        2: { text: '按使用面积' },
        3: { text: '按车位面积' },
        4: { text: '按使用量' },
        5: { text: '固定费用' },
        6: { text: '自定义' }
      }
    },
    {
      title: '计费单价（单位：元）',
      dataIndex: 'unit_price',
      search: false,
      width: '100px',
      render: (_, row) => <span>{row.unit_price / 100}</span>
    },
    {
      title: '附加/固定费用（单位：元）',
      dataIndex: 'fix_amount',
      search: false,
      width: '100px',
      render: (_, row) => <span>{row.fix_amount / 100}</span>
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 210,
      align: 'center',
      render: (_, row, index, action) => <div className='controller-group'>
        <a style={{ marginRight: 20 }} onClick={() => {
          setState(prevState => ({
            ...prevState,
            bindVisible: true
          }))
          setEditRow(row)
        }}>绑定</a>
        <a style={{ marginRight: 20 }} onClick={() => {
          setState((prevState => ({
            ...prevState,
            visible: true,
            currentFormType: row.charge_type,
            fix_amount:row.charge_basis==6?false:true,
          })))
          row.charge_effective_time = moment(row.charge_effective_time * 1000)
          setEditRow(row)
          const data = { ...row, fix_amount: row.fix_amount / 100, unit_price: row.unit_price / 100 }
          form.setFieldsValue(data)
        }}>编辑</a>
        <a onClick={() => {
          Modal.confirm({
            title: '确认删除这条记录吗?',
            content: '你确定删除这条记录吗？',
            onOk: async () => {
              await ChargeConfig({ method: 'delete', id: row.id })
              message.success('操作成功')
              actionRef.current.reload()
            }
          })
        }}>删除</a>
        {/*{*/}
        {/*  (row.charge_time_type === 1 || [2, 3, 4].includes(row.charge_type)) && <Button onClick={() => {*/}
        {/*    setState(prevState => ({*/}
        {/*      ...prevState,*/}
        {/*      billVisible: true*/}
        {/*    }))*/}
        {/*  }}>生成账单</Button>*/}
        {/*}*/}
      </div>
    }
  ]
  const restFormInfo = [
    'charge_name',
    'charge_basis',
    'charge_time_type',
    "bill_period",
    "bill_period_type",
    "unit_price",
    "fix_amount",
    "fix_amount_name",
    "charge_effective_time",
    "late_fee_day",
    "late_fee_percent",
    "late_fee_max_days"
  ]
  const actionRef = React.useRef<ActionType>() as any
  const [form] = Form.useForm()
  // edit
  const [editRow, setEditRow] = React.useState({}) as any
  const [state, setState] = React.useState({
    visible: false,
    exportVisible: false,
    billVisible: false,
    bindVisible: false,
    currentFormType: 1,
    inputValue: '',
    lateFess: false,
    money_way: null,
    fix_amount: true
  })
  const [billDateRange, setBillDateRange]: any = React.useState([])
  const handleCreateBill = async () => {
    if (!billDateRange.length) return message.error('未选择日期')
    setState(pre => ({ ...pre, billVisible: false }))
    await CreateChargeBill({
      charge_id: editRow.id,
      end: billDateRange[1].valueOf()
    })
    message.success('操作成功！')
  }
  const onSubmit = () => {
    form.validateFields().then(async values => {
      ['fix_amount', 'unit_price'].forEach(key => {
        values[key] = +(parseFloat(values[key]) * 100).toFixed(0)
      })
      let charge_effective_time = GetTimeStamp(moment(values.charge_effective_time).startOf('M').format("YYYY-MM-DD HH:mm:ss"));
      await ChargeConfig({
        method: editRow.id ? 'put' : 'post', ...values,
        charge_effective_time,
        id: editRow.id
      })
      message.success('操作成功')
      form.resetFields()
      actionRef.current?.reloadAndRest()
      setState(pre => ({ ...pre, visible: false, inputValue: '' }))
    })
  }


  function fix_amount() {
    if ([1, 99].includes(state.currentFormType) && state.money_way == 5) {
      return (
        <>
          <Form.Item label='固定费用' name="fix_amount" rules={[{ required: true }]}>
            <Input placeholder='单行输入' onBlur={(e) => {
              setState(pre => ({ ...pre, inputValue: e.target.value }))
            }} />
          </Form.Item>
          <Form.Item label='固定费用别名' name="fix_amount_name" rules={[{ required: true }]}>
            <Input placeholder='请输入' />
          </Form.Item>
        </>
      )
    }
    else if (state.currentFormType == 6) {
      return (<>
        <Form.Item label='收费方式' name="charge_basis" rules={[{ required: true }]}>
          <Select placeholder='请选择' options={[
            { label: '固定费用', value: 5 },
            { label: '自定义费用', value: 6 }
          ]}
            onSelect={(value) => {
              if (value == 6) {
                setState(preState => ({ ...preState, fix_amount: false }))
              } else {
                setState(preState => ({ ...preState, fix_amount: true }))
              }
              form.resetFields(['fix_amount'])
            }
            }
          />
        </Form.Item>
        {state.fix_amount ? <Form.Item label='固定费用' name="fix_amount" rules={[{ required: true }]}>
          <Input placeholder='单行输入' />
        </Form.Item> : <Form.Item label='tips'>
          <div style={{color:"rgba(0, 0, 0, 0.45)"}}>自定义费用请在绑定车辆时填写</div>
        </Form.Item>}
      </>)
    }
    else if (state.currentFormType == 1 && state.money_way == 5) {
      return (
        <>
          <Form.Item label='固定费用' name="fix_amount" rules={[{ required: true }]}>
            <Input placeholder='单行输入' onBlur={(e) => {
              setState(pre => ({ ...pre, inputValue: e.target.value }))
            }} />
          </Form.Item>
          {
            state.inputValue !== '' ?
              <Form.Item label='附加费用别名' name="fix_amount_name" rules={[{ required: true }]}>
                <Input placeholder='请输入' />
              </Form.Item>
              :

              <Form.Item label='附加费用别名' name="fix_amount_name">
                <Input placeholder='请输入' />
              </Form.Item>
          }
        </>
      )
    }
    else if ([[1, 2, 3, 4, 5].includes(state.currentFormType)]) {
      return (<>
        <Form.Item label='附加费用' name="fix_amount">
          <Input placeholder='单行输入' onBlur={(e) => {
            setState(pre => ({ ...pre, inputValue: e.target.value }))
          }} />
        </Form.Item>
        {
          state.inputValue !== '' ?
            <Form.Item label='附加费用别名' name="fix_amount_name" rules={[{ required: true }]}>
              <Input placeholder='请输入' />
            </Form.Item>
            :

            <Form.Item label='附加费用别名' name="fix_amount_name">
              <Input placeholder='请输入' />
            </Form.Item>
        }
        <Form.Item label='计费单价（单位：元）' name="unit_price" rules={[{ required: true }]} >
          <InputNumber min={0} addonAfter="¥" />
        </Form.Item>
      </>)
    }
  }
  const charge_basis = (
    <>
      <Form.Item label='收费方式' name="charge_basis" rules={[{ required: true }]}>
        <Select placeholder='请选择' options={[
          { label: '按房屋建筑面积', value: 1 },
          { label: '按房屋使用面积', value: 2 },
          { label: '固定费用', value: 5 }
        ]} onSelect={(value) => setState(pre => ({ ...pre, money_way: value }))
        } />
      </Form.Item>
    </>
  )

  const IconFont = createFromIconfontCN({
    scriptUrl: '//at.alicdn.com/t/font_3403531_stt3g9j72on.js',
  });

  return (
    <React.Fragment>
      {/* <Card className='charge-filter' style={{ marginBottom: 16 }}>
        <Input style={{ width: 240 }} placeholder='请输入楼栋编号' />
        <Button type='primary' style={{ marginLeft: 12 }}>搜索</Button>
      </Card> */}
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        search={false}
        request={ChargeConfig}
        bordered={true}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setEditRow({})
              setState(preState => ({
                ...preState, visible: true, inputValue: "",
                exportVisible: false,
                billVisible: false,
                bindVisible: false,
                currentFormType: 1,
                lateFess: false,
                money_way: null,
                fix_amount: true
              }))
            }}
          >
            <PlusOutlined /> 添加
          </Button>
        ]}
        columns={columns}
      />
      <Modal
        title='请选择绑定类型'
        width={440}
        visible={state.bindVisible}
        maskClosable={false}
        onOk={() => setState(pre => ({ ...pre, bindVisible: false }))}
        onCancel={() => setState(pre => ({ ...pre, bindVisible: false }))}
        footer={false}
      >
        {
          editRow.charge_type !== 99 && [5].includes(editRow.charge_type) && (
            <div className={'bindHover'}
              style={{ position: "relative", height: "100px", width: "100px" }}
              onClick={() => {
                props.history.push(`/admin/charge/setup/parking?charge_id=${editRow.id}`)
              }}
            >
              <Avatar2
                style={{ ...bindTypeStyle, marginRight: '30px', backgroundColor: '#87d068' }}
                shape="square"
                size={100}
                icon={<IconFont type='icon-tingchewei' />}
              /><span className='bindText'>车位</span>
            </div>
          )
        }
        {
          editRow.charge_type !== 99 && [6].includes(editRow.charge_type) && (
           <Link to={{pathname:"/admin/charge/setup/car",state:editRow}}>
            <div className={'bindHover'}
              style={{ position: "relative", height: "100px", width: "100px" }}
              // onClick={() => {
              //   props.history.push(`/admin/charge/setup/car?charge_id=${editRow.id}`)
              // }}
            >
              <Avatar2
                style={{ ...bindTypeStyle, marginRight: '30px', backgroundColor: '#87d068' }}
                shape="square"
                size={100}
                icon={<IconFont type='icon-cheliangguanli' />}
              /><span className='bindText'>车辆</span>
            </div>
           </Link>
          )
        }
        {
          ![5, 6].includes(editRow.charge_type) && (
            <div className={'bindHover'}
              onClick={() => {
                props.history.push(`/admin/charge/setup/room?charge_id=${editRow.id}`)
              }}
              style={{ position: "relative", height: "100px", width: "100px" }}>
              <Avatar2
                style={{ ...bindTypeStyle, backgroundColor: '#87d068' }}
                shape="square"
                size={100}
                icon={<IconFont type='icon-fangwu' />}
              /><span className='bindText'>房屋</span>
            </div>
          )
        }
      </Modal>
      <Modal
        title='生成账单'
        width={340}
        visible={state.billVisible}
        maskClosable={false}
        onOk={handleCreateBill}
        onCancel={() => setState(pre => ({ ...pre, billVisible: false }))}
      >
        <div className={'mb-2'}>选择日期范围</div>
        <DatePicker.RangePicker onChange={(values) => {
          setBillDateRange(values)
        }} />
      </Modal>
      <Modal
        title={editRow.id ? '编辑费用设置' : '添加费用设置'}
        visible={state.visible}
        width={680}
        maskClosable={false}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 6 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <div className='form-subtitle'>基本设置</div>
          <Form.Item label='费用类型' name="charge_type" rules={[{ required: true }]}>
            <Select
              placeholder='请选择'
              options={formTypes}
              onChange={(value) => {
                form.resetFields(restFormInfo)
                form.setFieldsValue({ 'late_fee_enable': false })
                const lateValue = form.getFieldValue('late_fee_enable')
                // @ts-ignore
                setState(prevState => ({
                  ...prevState,
                  currentFormType: value,
                  lateFess: lateValue
                }))
              }}
            />
          </Form.Item>
          <Form.Item label='费项名称' name="charge_name" rules={[{ required: true }]}>
            <Input placeholder='单行输入' />
          </Form.Item>
          {
            [1, 99].includes(state.currentFormType) ? charge_basis : '' ||
              OptionType[[2, 3, 4].includes(state.currentFormType) ? 2 : state.currentFormType]() ||
              OptionType[[5].includes(state.currentFormType) ? 5 : state.currentFormType]()
              ||
              OptionType[[6].includes(state.currentFormType) ? 6 : state.currentFormType]()
          }
          {fix_amount()}
          {TypeForm[[2, 3, 4].includes(state.currentFormType) ? 2 : state.currentFormType]()}
          {
            state.currentFormType !== 6 && <React.Fragment>
              <div className={'form-subtitle'}> 滞纳金设置</div>
              <LateFee flag={state} />
            </React.Fragment>
          }
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ChargeSetup)