import React, { useState } from 'react'
import ProTable, { ActionType } from "@ant-design/pro-table"
import { Button, message, Modal, Input, Row, Form, Select } from "antd"
import { GetUnPayBillDetails, UnPayBillDiscard, ChargeUnPayBillUrge, ChargeConfig } from '../../services/charge'
import { CHARGE_TYPES } from "../../CONSTANT"




const ShouldBill: React.FC = () => {
  const [state, setState] = React.useState({
    visible: false, editId: null
  })
  const [form] = Form.useForm();
  const actionRef: any = React.useRef<ActionType>()
  const actionPrimaryRef: any = React.useRef<ActionType>();
  const [charge_type, setCharge_type]: any = useState("");
  const request = async (params) => {
    const { charge_type } = params;
    if (charge_type) {
      const { data } = await ChargeConfig({ page: -1, page_size: -1, ...params });
      return data?.map(({ charge_name }) => ({ value: charge_name, label: charge_name }))
    }
  };

  const columns: any = [
    {
      title: "房屋/车位/车辆",
      dataIndex: "obj_name",
    },
    {
      title: '费用类型',
      dataIndex: 'charge_type',
      valueEnum: CHARGE_TYPES,
      search: true,
      fieldProps: (form, config) => {
        return {
          onChange: (e) => {
            setCharge_type(e)
            form.resetFields(['charge_name'])
          },
          onClear: (e) => {
            form.resetFields(['charge_name'])
          },
        }
      }
    },
    {
      title: '费项名称',
      dataIndex: 'charge_name',
      request,
      fieldProps: { placeholder: "请先选择费用类型" },
      params: { charge_type }
    },
    {
      title: '应收金额',
      dataIndex: 'amount',
      search: false,
      render: (_, row) => <span>{`${row.amount / 100}`}</span>
    },
    {
      title: '滞纳金',
      dataIndex: 'late_fee',
      search: false,
      render: (_, row) => <span>{`${row.late_fee / 100}`}</span>
    },
    {
      title: '上次读数',
      dataIndex: 'last_used',
      search: false,
    },
    {
      title: '本次读数',
      dataIndex: 'current_used',
      search: false,
    },
    {
      title: '账单开始时间',
      dataIndex: 'start',
      search: false,
    },
    {
      title: '账单结束时间',
      dataIndex: 'end',
      search: false,
    },
    {
      title: '合计',
      dataIndex: 'should_pay_amount',
      search: false,
      align: "center",
      render: (_, row) => <span>{`${(row.amount + row.late_fee) / 100}`}</span>
    },
    {
      title: "操作",
      dataIndex: "option",
      align:"center",
      width:"200px",
      search: false,
      render: (_, row, index, action) => <>
        <Button type='link' onClick={() => {
          setState(prevState => ({ ...prevState, visible: true, editId: row.bill_id }))
        }}>作废账单</Button>
        <Button type='link' onClick={() => {
          Modal.confirm({
            title: '催缴',
            content: '你确定催缴这条记录吗？',
            onOk: async () => {
              await ChargeUnPayBillUrge({
                obj_id: row.obj_id,
                obj_type: row.obj_type
              })
              message.success('操作成功！')
              actionPrimaryRef.current.reload()
            }
          })
        }}>一键催缴</Button>
      </>
    }
  ]
  const discardBill = () => {
    form.validateFields().then(async (values) => {
      await UnPayBillDiscard({
        bill_id: state.editId,
        ...values
      })
      setState(prevState => ({ ...prevState, visible: false }))
      message.success('操作成功！')
      actionPrimaryRef.current.reload()
    })
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionPrimaryRef}
        columns={columns}
        rowKey="bill_id"
        request={GetUnPayBillDetails}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6, labelWidth: 'auto',
          optionRender: (searchConfig, formProps, dom) => [
            <Button key="rest" onClick={() => {
              formProps.form?.resetFields();
              setCharge_type('')
            }}>
              重置
            </Button>,
            dom[1],
          ],
        }}
        // toolBarRender={() => [
        //   <Button type="primary" onClick={() => {
        //     setState(prevState => ({
        //       ...prevState,
        //       visible: true
        //     }))
        //   }}>批量催缴</Button>
        // ]}
        bordered
      />
      <Modal
        title="确认作废账单"
        visible={state.visible}
        maskClosable={false}
        width={400}
        onOk={discardBill}
        onCancel={() => setState(prevState => ({
          ...prevState,
          visible: false
        }))}
        destroyOnClose
      >
        <Form form={form}>
          <Form.Item label="作废原因" name="del_reason" rules={[{ required: true, message: "请输入作废原因" }]}>
            <Input.TextArea
              rows={4}
              placeholder="请输入作废原因"
            />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default ShouldBill
