import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, message, Select, Upload } from 'antd'
import { withRouter } from 'react-router-dom'
import {
  ComplaintApi,
  ComplaintOrderSend,
  ComplaintOrderRefund,
  ComplaintOrderFinish,
} from '../../services/complaint'
import './index.scss'
import { useUser } from "../User/hooks"
import Uploadpic from '../../utils/handlePreview'
import { STATUS_TYPE } from '../../CONSTANT'

const ComplaintHandle: React.FC = (props: any) => {
  const columns: any = [
    {
      title: '投诉类型',
      dataIndex: 'suggestion_type',
      search: true,
      valueEnum: {
        1: { text: '投诉' },
        2: { text: '建议' }
      }
    },
    {
      title: '投诉人',
      dataIndex: 'apply_people',
      search: true,
    },
    {
      title: '联系电话',
      dataIndex: 'apply_people_phone',
      search: true,
    },
    {
      title: '投诉内容',
      dataIndex: 'apply_content',
      search: false,
      ellipsis: true,
    },
    {
      title: '投诉日期',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '状态',
      dataIndex: 'status',
      search: false,
      valueEnum: STATUS_TYPE,
      align:"center"
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 210,
      align: 'center',
      render: (_, row, index, action) => <>
        <Button type='link'
          onClick={() => setMethod('send', row.id)}
        >转单</Button>
        {/* <Button type='link'
          onClick={() => setMethod('refund', row.id)}
        >退单</Button> */}
        <Button type='link'
          onClick={() => {
            props.history.push(`/admin/complaint/handle/detail?id=${row.id}`)
          }}
        >详情</Button>
        <Button type='link' onClick={() =>  setMethod('finish', row.id)}>办结</Button>
      </>
    }
  ]

  const [pic, setPic]: any = React.useState([])
  const [cUsers, setUsers]: any = useUser(true)

  React.useEffect(() => {
    setUsers()
  }, [])

  const [state, setState] = React.useState({
    orderVisible: false,
    editId: null,
    formMode: ''
  })
  const setMethod = (method, id) => {
    orderForm.resetFields()
    setState(prevState => ({
      ...prevState,
      formMode: method,
      orderVisible: true,
      editId: id
    }))
  }
  const garden_pic = (arr) => {
    orderForm.setFieldsValue({ handle_pic: arr })
  }

  const FinishForm = <React.Fragment>
    <Form.Item label='处理意见' name="feedback" >
      <Input.TextArea placeholder="多行输入" rows={4} />
    </Form.Item>
    <Form.Item label='处理后照片' name="handle_pic" >
      <Uploadpic getSrc={garden_pic} src={pic} maxCount={8} />
    </Form.Item>
  </React.Fragment>

  // 报修退单
  const ChargeBackForm = <React.Fragment>
    <Form.Item label='处理意见' name="feedback" rules={[{ required: true }]}>
      <Input.TextArea placeholder="多行输入" rows={4} />
    </Form.Item>
  </React.Fragment>

  const SendForm = <React.Fragment>
    <Form.Item label='处理人' name="current_uid" rules={[{ required: true }]}>
      <Select placeholder='请选择' options={cUsers} />
    </Form.Item>
    <Form.Item label='处理意见' name="feedback" >
      <Input.TextArea placeholder="多行输入" rows={4} />
    </Form.Item>
  </React.Fragment>

  const Forms = {
    refund: ChargeBackForm,
    finish: FinishForm,
    send: SendForm
  }

  const actionRef: any = React.useRef<ActionType>()
  const [orderForm] = Form.useForm()

  const onSubmit = () => {
    const _Api = {
      send: ComplaintOrderSend,
      refund: ComplaintOrderRefund,
      finish: ComplaintOrderFinish
    }
    orderForm.validateFields().then(async values => {
      await _Api[state.formMode]({ ...values, id: state.editId })
      message.success('操作成功！')
      orderForm.resetFields()
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, orderVisible: false, editId: null }))
    })
  }

  const titleMap = {
    refund: '退单',
    finish: '办结工单',
    send: '转单'
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey={r => r.id}
        request={ComplaintApi}
        params={{ status: 2 ,is_me:true}}
        columns={columns}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6
        }}
      />
      <Modal
        title={titleMap[state.formMode]}
        visible={state.orderVisible}
        maskClosable={false}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, orderVisible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={orderForm}
        >
          {Forms[state.formMode]}
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ComplaintHandle)