import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, message, Select, Upload } from 'antd'
import { withRouter } from 'react-router-dom'
import { ComplaintApi, ComplaintOrderSend } from '../../services/complaint'
import './index.scss'
import { useUser } from "../User/hooks"
import Uploadpic from '../../utils/handlePreview'
import { STATUS_TYPE } from '../../CONSTANT'

const ComplaintPage: React.FC = (props: any) => {
  const columns: any = [
    {
      title: '投诉类型',
      dataIndex: 'suggestion_type',
      search: true,
      valueEnum: {
        1: { text: '投诉' },
        2: { text: '建议' }
      }
    },
    {
      title: "订单类型",
      dataIndex: "is_me",
      search: true,
      hideInTable: true,
      valueType: "select",
      valueEnum: {
        false: { text: "全部" },
        true: { text: "指派给我的" }
      }
    },
    {
      title: '投诉人',
      dataIndex: 'apply_people',
      search: true,
    },
    {
      title: '联系电话',
      dataIndex: 'apply_people_phone',
      search: true,
    },
    {
      title: '投诉内容',
      dataIndex: 'apply_content',
      search: false,
      ellipsis: true,
    },
    {
      title: '投诉日期',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '状态',
      dataIndex: 'status',
      search: true,
      valueType: "select",
      valueEnum: STATUS_TYPE
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      align: 'center',
      width:"200px",
      render: (_, row, index, action) => <>
        <Button type='link'
          onClick={() => {
            form.setFieldsValue(row)
            if (row.apply_pic.length === 1 && row.apply_pic[0] === '') {
              setPic([])
            } else {
              setPic(row.apply_pic);
            }
            setState(prevState => ({
              ...prevState,
              visible: true,
              editId: row.id
            }))
          }}
        >编辑</Button>
        <Button
          type='link'
          onClick={() => {
            props.history.push(`/admin/complaint/new/detail?id=${row.id}`)
          }}
        >详情</Button>
        {row.status === 1 ? <>
          <Button
            type='link'
            onClick={() => {
              orderForm.resetFields()
              setState(prevState => ({
                ...prevState,
                orderVisible: true,
                editId: row.id
              }))
            }}
          >派单</Button>
          <Button type='link' onClick={() => {
            Modal.confirm({
              title: '删除记录',
              content: '你确定删除这条记录吗？',
              onOk: async () => {
                await ComplaintApi({ method: 'delete', id: row.id })
                message.success('操作成功！')
                actionRef.current.reload()
              }
            })
          }}>删除</Button>
        </> : <>
          <Button type='link' disabled>派单</Button>
          <Button type='link' disabled>删除</Button>
        </>}
      </>
    }
  ]

  const [pic, setPic]: any = React.useState([])
  const [cUsers, setUsers]: any = useUser()

  React.useEffect(() => {
    setUsers()
  }, [])

  const [state, setState] = React.useState({
    visible: false,
    orderVisible: false,
    editId: null
  })

  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()

  const onSubmit = () => {
    form.validateFields().then(async values => {
      await ComplaintApi({
        method: state.editId ? "put" : "post",
        ...values,
        id: state.editId,
      })
      message.success('操作成功！')
      form.resetFields()
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }

  const [orderForm] = Form.useForm()
  const handleSendOrder = () => {
    orderForm.validateFields().then(async values => {
      await ComplaintOrderSend({
        ...values, id: state.editId
      })
      message.success('操作成功！')
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, orderVisible: false, editId: null }))
    })
  }
  const garden_pic = (arr) => {
    form.setFieldsValue({ apply_pic: arr })
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey={r => r.id}
        request={ComplaintApi}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6
        }}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setPic([])
              setState(preState => ({ ...preState, visible: true }))
            }}
          >添加</Button>
        ]}
        columns={columns}
      />
      <Modal
        title='派单'
        visible={state.orderVisible}
        maskClosable={false}
        onOk={handleSendOrder}
        onCancel={() => setState(pre => ({ ...pre, orderVisible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={orderForm}
        >
          <Form.Item label='处理对象' name="current_uid" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={cUsers} />
          </Form.Item>
          <Form.Item label='处理意见' name="feedback" >
            <Input.TextArea placeholder="多行输入" rows={4} />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title={state.editId ? '修改投诉/建议' : '添加投诉/建议'}
        visible={state.visible}
        maskClosable={false}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false, editId: null }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='投诉类型' name="suggestion_type" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={[
              { label: '投诉', value: 1 },
              { label: '建议', value: 2 },
            ]} />
          </Form.Item>
          <Form.Item label='投诉人' name="apply_people" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='联系方式' name="apply_people_phone" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='投诉内容' name="apply_content" rules={[{ required: true }]}>
            <Input.TextArea placeholder="多行输入" rows={4} />
          </Form.Item>
          <Form.Item label='投诉图片' name="apply_pic" rules={[{ required: false }]}>
            <Uploadpic getSrc={garden_pic} src={pic} maxCount={8} />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ComplaintPage)