import React, { useState } from "react";
import type { ActionType } from "@ant-design/pro-table"
import ProTable from "@ant-design/pro-table"
import { Button, Modal, Form, message, Input, Select } from "antd";
import moment from 'moment'
import { useHistory } from "react-router";
import { IcOption, CardDevices } from "../../services/device";

const ICManager = () => {
    const actionRef = React.useRef<ActionType>() as any
    const hisitory = useHistory();
    const [form] = Form.useForm();
    const columns: any = [
        {
            title: "IC卡号",
            align: 'center',
            search: false,
            dataIndex: "card_number",
            // ellipsis: true,
        },
        {
            title: "办卡人",
            align: 'center',
            search: true,
            dataIndex: "name",
        },
        {
            title: "访问权限",
            align: 'center',
            search: false,
            dataIndex: "gate_permissions",
            render: (_, row) => <>
                {row.gate_permissions.map((item, index) => {
                    return <div key={index}>{`${item.device_name}（${item.location}）`}</div>
                })}
            </>
        },
        {
            title: "下发状态",
            align: 'center',
            search: true,
            dataIndex: "down_status",
            render: (_, row) => <>
                {row.gate_permissions.map((item, index) => {
                    if (item.down_status == 1) {
                        return <div key={index}>
                            <span className="ant-badge ant-badge-status ant-badge-not-a-wrapper">
                                <span className="ant-badge-status-dot ant-badge-status-processing"></span>
                                <span className="ant-badge-status-text">待下发</span>
                            </span>
                        </div>
                    } else if (item.down_status == 2) {
                        return <div key={index}>
                            <span className="ant-badge ant-badge-status ant-badge-not-a-wrapper">
                                <span className="ant-badge-status-dot ant-badge-status-success"></span>
                                <span className="ant-badge-status-text">已下发</span>
                            </span>
                        </div>
                    } else {
                        return <div key={index}>
                            <span className="ant-badge ant-badge-status ant-badge-not-a-wrapper">
                                <span className="ant-badge-status-dot ant-badge-status-error"></span>
                                <span className="ant-badge-status-text">下发失败</span>
                            </span>
                        </div>
                    }
                })}
            </>,
            valueEnum: {
                0: { text: "全部" },
                1: { text: "待下发", status: "Processing" },
                2: { text: "下发成功", status: "Success" },
                3: { text: "下发失败", status: "Error" }
            }
        },
        {
            title: "添加时间",
            align: 'center',
            search: false,
            dataIndex: "created_at",
            render: (_, row: any) => moment(row.created_at * 1000).format('YYYY-MM-DD HH:MM:SS'),
        },
        {
            title: "操作",
            align: "center",
            search: false,
            dataIndex: "options",
            render: (_, row) => <>
                {row.down_status == 3 ? <Button type="link" onClick={() => ResetFace(row.id)}>重新下发</Button> : <></>
                }
                <Button type="link" onClick={() => deleteIc(row.id)}>删除</Button>
            </>
        }
    ]
    const ResetFace = (id) => {
        Modal.confirm({
            content: "你确定重新下发这条记录吗？",
            onOk: async () => {
                await IcOption({ method: "put", id });
                message.success("操作成功！");
                setTimeout(() => {
                    actionRef.current.reload();
                }, 2000)
            }
        });
    }
    const deleteIc = (id) => {
        Modal.confirm({
            content: "你确定删除这条记录吗？",
            onOk: async () => {
                await IcOption({ method: "delete", id });
                message.success("操作成功！");
                actionRef.current.reload();
            }
        });
    }
    const [isModalOpen, setIsModalOpen] = useState(false);
    const [options, setoptions]: any = useState([]);
    const [card_number, setcard_number]: any = useState("");
    const [value, setvalue]: any = useState("");

    const showModal = () => {
        setIsModalOpen(true);
        setvalue("")
        form.resetFields();
    };

    const handleOk = () => {
        form.validateFields().then(async (values) => {
            await IcOption({ method: "post", ...values });
            setIsModalOpen(false);
            message.success("操作成功")
            setTimeout(()=>{
                actionRef.current.reload();
            },2000)
        })
    };

    const handleCancel = () => {
        setIsModalOpen(false);
    };

    const getDevices = async () => {
        if (card_number !== value) {
            const { data } = await CardDevices({ card_number })
            setoptions(data);
            setvalue(card_number)
        }
    }
    return (<>
        <div style={{ display: "flex", justifyContent: "end", marginBottom: "20px" }}><Button type="primary" onClick={hisitory.goBack}>返回</Button></div>
        <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={IcOption}
            search={{
                collapsed: false, collapseRender: () => false,
                span: 6
            }}
            toolBarRender={() => [
                <Button type="primary" key="IcCard" onClick={showModal}>
                    新增IC卡
                </Button>
            ]}
            options={false}
            columns={columns}
        />
        <Modal title="审核" open={isModalOpen} onOk={handleOk} onCancel={handleCancel}
            maskClosable={false}
            okText="保存"
            width={480}
        >
            <Form form={form}
                labelCol={{ span: 4, }}
                wrapperCol={{ offset: 1 }}
            >
                <Form.Item name="card_number" label="IC卡号" rules={[{ required: true, message: "请输入IC卡号" }]} >
                    <Input placeholder="请输入IC卡号"
                        onChange={e => setcard_number(e.target.value)} />
                </Form.Item>
                <Form.Item name="name" label="办卡人" rules={[{ required: true, message: "请输入办卡人" }]} >
                    <Input placeholder="请输入办卡人" />
                </Form.Item>
                <Form.Item name="device_ids" label="访问权限" rules={[{ required: true, message: "请选择访问权限" }]}>
                    <Select
                        onFocus={getDevices}
                        mode="multiple"
                        allowClear
                        style={{ width: '100%' }}
                        placeholder="请选择访问权限"
                        fieldNames={{ label: "device_name", value: "device_id" }}
                        options={options}
                    />
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default ICManager