import React, { useEffect, useState } from "react"
import type { ActionType } from "@ant-design/pro-table"
import ProTable, { TableDropdown } from "@ant-design/pro-table"
import { withRouter } from "react-router"
import { Form, Button, Select, Modal, message, Input } from "antd"
import { GetDoorControl, SetGate, GateEnable, Open, Restart } from "../../services/device"
import './index.scss'
import { Link } from "react-router-dom"

const DoorControl = (props) => {
    const support = {
        1:{text:"支持",status: "Success" },
        2:{text:"不支持",status: "Error"}
    }
    const columns: any = [
        // {
        //     title: '设备ID',
        //     align: 'center',
        //     search: false,
        //     dataIndex: "device_id"
        // },
        {
            title: '设备序列号',
            align: 'center',
            search: true,
            dataIndex: "sn",
            // ellipsis: true,
        },
        {
            title: '设备名',
            align: 'center',
            search: true,
            dataIndex: "device_name",
            ellipsis: true,
        },
        {
            title: '厂家',
            search: true,
            align: 'center',
            dataIndex: "manufactor",
            ellipsis: true,
        },
        {
            title: '授权KEY',
            search: false,
            align: 'center',
            dataIndex: 'auth_key',
            ellipsis: true,
        },
        {
            title: '设备位置',
            align: 'center',
            search: false,
            dataIndex: "location"
        },
        {
            title: 'IC卡',
            align: 'center',
            search: false,
            dataIndex: "card_support",
            valueEnum:support
        },
        {
            title: '二维码',
            align: 'center',
            search: false,
            dataIndex: "qcode_support",
            valueEnum:support
        },
        {
            title: '人脸识别',
            align: 'center',
            search: false,
            dataIndex: "pic_support",
            valueEnum:support
        },
        {
            title: '方向',
            align: 'center',
            search: false,
            dataIndex: "direction",
            valueEnum: {
                1: "进场",
                2: "出场",
                3: "进出场"
            }
        },
        {
            title: "状态",
            search: false,
            align: 'center',
            dataIndex: 'enable',
            valueEnum: {
                true: "已启用",
                false: "已禁用"
            }
        },
        {
            title: '运行状态',
            align: 'center',
            search: false,
            dataIndex: "status",
            valueEnum: {
                1: { text: "在线", status: "Success" },
                2: { text: "离线", status: "Error" }
            }
        },
        {
            title: '操作',
            dataIndex: 'option',
            search: false,
            width: '210px',
            align: 'center',
            render: (_, row, index, action) =>
                <>
                    <Button type="link" onClick={() => modalOption(row, true)}>编辑</Button>
                    {row.enable ? <Button type="link" onClick={() => changeEnable(row.device_id, false)}>禁用</Button> :
                        <Button type="link" onClick={() => changeEnable(row.device_id, true)}>启用</Button>}
                    <Link to={{ pathname: "/admin/device/door/permission", state: row }}>
                        <Button type="link">开门权限</Button>
                    </Link>
                    <Button type="link">
                        <TableDropdown
                            key="actionGroup"
                            className="moreOption"
                            onSelect={e => {
                                const { device_id, device_name, sn } = row
                                if (e == 'open') {
                                    openDoor(device_id)
                                } else if (e == 'restart') {
                                    resartDoor(device_id)
                                } else if (e == "command") {
                                    props.history.push(`/admin/device/door/command?${device_id}`)
                                } else if (e == "record") {
                                    props.history.push(`/admin/device/door/doorrecord?device_id=${device_id}&device_name=${device_name}&sn=${sn}`)
                                } else if (e == "visitor") {
                                    props.history.push(`/admin/device/door/visitorrecord?device_id=${device_id}`)
                                } 

                            }}
                            menus={[
                                { key: 'record', name: '开门记录' },
                                { key: 'visitor', name: '访客留影' },
                                { key: 'open', name: '远程开门', disabled: row.status == 2 ? true : false },
                                { key: 'restart', name: '重启设备', disabled: row.status == 2 ? true : false },
                                { key: 'sync', name: '数据同步', disabled: row.status == 2 ? true : false },
                                { key: 'command', name: '操作记录' },
                            ]}
                        />
                    </Button>
                </>
        }
    ]
    const actionRef = React.useRef<ActionType>() as any
    const [form] = Form.useForm()
    const [state, setState] = useState({
        visible: false,
        device_id: null
    })
    const direction = [
        { label: "进场", value: 1 },
        { label: "出场", value: 2 },
        { label: "进出场", value: 3 }
    ]
    const modalOption = (row, flag) => {
        if (row !== null) {
            form.setFieldsValue(row)
            form.setFieldsValue({ gate_name: row.device_name })
            setState(pre => ({ ...pre, device_id: row.device_id, visible: flag }))
        } else {
            setState(pre => ({ ...pre, device_id: null, visible: flag }))
        }
    }
    const changeEnable = (device_id, enable) => {
        Modal.confirm({
            title: '更改状态',
            content: '你确定修改状态吗？',
            onOk: async () => {
                await GateEnable({ device_id, enable })
                message.success('操作成功')
                actionRef.current.reload()
            }
        })
    }
    const openDoor = (device_id) => {
        Modal.confirm({
            title: "远程开门",
            content: "你确定远程开门吗？",
            onOk: async () => {
                await Open({ device_id });
                message.success("开门成功！");
            }
        });
    }
    const resartDoor = (device_id) => {
        Modal.confirm({
            title: "重启设备",
            content: "你确定重启设备吗？",
            onOk: async () => {
                await Restart({ device_id });
                message.success("重启成功！");
            }
        });
    }

    const editDoor = () => {
        form.validateFields().then(async (values) => {
            const { device_id } = state
            await SetGate({ ...values, device_id })
            message.success('修改成功')
            actionRef.current.reload();
            modalOption({}, false)
        })
    }

    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey="device_id"
            request={GetDoorControl}
            search={{
                collapsed: false, collapseRender: () => false,
                span: 6
            }}
            toolBarRender={() => [
                <Link to="/admin/device/door/facemanager">
                    <Button type="primary" key="face">
                        人脸管理
                    </Button>
                </Link>,
                <Link to="/admin/device/door/ICmanager">
                    <Button type="primary" key="ic">
                        IC卡管理
                    </Button>
                </Link>
            ]}
            options={false}
            columns={columns}
        />
        <Modal
            visible={state.visible}
            title="编辑"
            width={400}
            onCancel={() => modalOption(null, false)}
            onOk={editDoor}
            maskClosable={false}
        >
            <Form form={form}
                labelCol={{ span: 6 }}
                labelAlign="left"
            >
                <Form.Item label="门禁方向" name="direction" rules={[{ required: true, message: "请选择门禁方向" }]}>
                    <Select allowClear placeholder="请选择进场方向" options={direction} />
                </Form.Item>
                <Form.Item label="门禁位置" name="location" rules={[{ required: true, message: "请输入门禁位置" }]}>
                    <Input placeholder="请输入门禁位置" />
                </Form.Item>
                <Form.Item label="设备名" name="gate_name" >
                    <Input placeholder="请输入设备名" />
                </Form.Item>
                <Form.Item label="IP" name="ip" >
                    <Input placeholder="请输入IP" />
                </Form.Item>
                <Form.Item label="MAC地址" name="mac" >
                    <Input placeholder="请输入MAC地址" />
                </Form.Item>
                <Form.Item label="用户名" name="user" >
                    <Input placeholder="请输入用户名" />
                </Form.Item>
                <Form.Item label="用户密码" name="password" >
                    <Input placeholder="请输入用户密码" />
                </Form.Item>
            </Form>
        </Modal>
    </>)
}
export default withRouter(DoorControl)