import React from "react";
import { useHistory } from "react-router";
import { getLocalTime } from "../../utils/utils";
import type { ActionType } from "@ant-design/pro-table";
import ProTable from "@ant-design/pro-table";
import { Record } from "../../services/device";
import { Button, Card } from "antd";
import { GetTimeStamp } from "../../utils/utils";


const DoorRecord = () => {
    const history = useHistory();
    const result = history.location.search.split('?')[1].split('&');
    const device_id = result[0].split('=')[1];
    const device_name = result[1].split('=')[1];
    const sn = result[2].split('=')[1];
    const columns: any = [
        {
            title: "用户/IC卡",
            align: "center",
            search: false,
            dataIndex: "card_number",
            render: (_, row) => <span>{row.card_number == "" ? row.household_user : row.card_number}</span>
        },
        {
            title: "开门方式",
            align: "center",
            search: false,
            dataIndex: "card_number",
            render: (_, row) => <span>{row.card_number == "" ? "二维码" : "IC卡"}</span>
        },
        {
            title: "开门人",
            dataIndex: "is_visitor",
            align: "center",
            valueEnum: {
                0: "全部",
                1: "访客",
                2: "非访客"
            }
        },
        {
            title: "访客",
            align: "center",
            dataIndex: "visitor_name",
            search: false,
            render:(_,row)=><span>{row.is_visitor==1?`${row.visitor_name}-${row.visitor_phone}`:''}</span>
        },
        {
            title: "开门时间",
            align: "center",
            search: false,
            dataIndex: "open_time",
            render: (_, row) => getLocalTime(row.open_time)
        },
        {
            title: "开始时间",
            align: "center",
            valueType: "date",
            dataIndex: "start",
            hideInTable: true,
        },
        {
            title: "结束时间",
            align: "center",
            valueType: "date",
            dataIndex: "end",
            hideInTable: true,
        },
    ]
    const actionRef: any = React.useRef<ActionType>();
    return (<>
        <ProTable
            toolbar={{
                title: `${device_name}（${sn}）`,
                actions: [
                    <Button
                        key="key"
                        type="primary"
                        onClick={history.goBack}
                    >
                        返回
                    </Button>
                ],
            }}
            search={{
                collapsed: false, collapseRender: () => false,
                span: 6
            }}
            beforeSearchSubmit={(params: any) => {
                let { start, end } = params;
                if (start&&end) {
                    start = GetTimeStamp(start)
                    end = GetTimeStamp(end)
                } else if (start) {
                    start = GetTimeStamp(start)
                } else if(end) {
                    end = GetTimeStamp(end)
                }
                return { ...params, start, end }
            }}
            actionRef={actionRef}
            rowKey="open_time"
            request={Record}
            params={{ device_id }}
            columns={columns}
        />
    </>)
}

export default DoorRecord