import React, { useState } from "react";
import { FaceList } from "../../services/device";
import type { ActionType } from "@ant-design/pro-table"
import ProTable from "@ant-design/pro-table"
import { Button, Modal, message, Form, Input, Image } from "antd";
import moment from 'moment'
import { useHistory } from "react-router";
import { user_type } from "../../CONSTANT";
import { FaceApprove } from "../../services/device";

const FaceManager = () => {
    const actionRef = React.useRef<ActionType>() as any
    const hisitory = useHistory();
    const [form] = Form.useForm();
    const [id, setId]: any = useState();
    const columns: any = [
        {
            title: "业主名",
            align: 'center',
            search: true,
            dataIndex: "name",
        },
        {
            title: "身份证号",
            align: 'center',
            search: false,
            dataIndex: "id_number",
            ellipsis: true,
        },
        {
            title: "房屋",
            align: 'center',
            search: false,
            dataIndex: "house_name",
            ellipsis: true,
        },
        {
            title: "访问权限",
            align: 'center',
            search: false,
            dataIndex: "gate_permissions",
            render: (_, row) => <>
                {row.gate_permissions.map((item, index) => {
                    return <div key={index}>{`${item.device_name}（${item.location}）`}</div>
                })}
            </>
        },
        {
            title: "下发状态",
            align: 'center',
            search: true,
            dataIndex: "down_status",
            render: (_, row) => <>
                {row.gate_permissions.map((item, index) => {
                    if (item.down_status == 1) {
                        return <div key={index}>
                            <span className="ant-badge ant-badge-status ant-badge-not-a-wrapper">
                            <span className="ant-badge-status-dot ant-badge-status-processing"></span>
                            <span className="ant-badge-status-text">待下发</span>
                        </span>
                        </div>
                    } else if (item.down_status == 2) {
                        return <div key={index}>
                            <span className="ant-badge ant-badge-status ant-badge-not-a-wrapper">
                            <span className="ant-badge-status-dot ant-badge-status-success"></span>
                            <span className="ant-badge-status-text">已下发</span>
                        </span>
                        </div>
                    } else {
                        return <div  key={index}>
                            <span className="ant-badge ant-badge-status ant-badge-not-a-wrapper">
                            <span className="ant-badge-status-dot ant-badge-status-error"></span>
                            <span className="ant-badge-status-text">下发失败</span>
                        </span>
                        </div>
                    }
                })}
            </>,
            valueEnum: {
                0: { text: "全部" },
                1: { text: "待下发", status: "Processing" },
                2: { text: "下发成功", status: "Success" },
                3: { text: "下发失败", status: "Error" }
            },
        },
        {
            title: "审核状态",
            align: 'center',
            search: false,
            dataIndex: "approve_status",
            valueEnum: {
                1: { text: "待审核", status: "Processing" },
                2: { text: "审核通过", status: "Success" },
                3: { text: "审核失败", status: "Error" }
            }
        },
        {
            title: "上传时间",
            align: 'center',
            search: false,
            dataIndex: "created_at",
            render: (_, row: any) => moment(row.created_at * 1000).format('YYYY-MM-DD'),
        },
        {
            title: "审核时间",
            align: 'center',
            search: false,
            dataIndex: "approved_at",
            render: (_, row: any) => {
                return row.approved_at == 0 ? '' : moment(row.approved_at * 1000).format('YYYY-MM-DD')
            },
        },
        {
            title: "操作",
            align: "center",
            search: false,
            dataIndex: "options",
            render: (_, row) => <>
                {row.approve_status == 1 ? <Button type="link" onClick={() => showModal(row)}>审核</Button> : ""
                }
                {row.down_status==3? <Button type="link" onClick={() => ResetFace(row.id)}>重新下发</Button> : ""}
                <Button type="link" onClick={()=>deleteFace(row.id)}>删除</Button>
            </>
        }
    ]
    const ResetFace = (id) => {
        Modal.confirm({
            content: "你确定重新下发这条记录吗？",
            onOk: async () => {
                await FaceList({ method: "put", id });
                message.success("操作成功！");
                setTimeout(()=>{
                    actionRef.current.reload();
                },2000)
            }
        });
    }
    const deleteFace = (id) =>{
        Modal.confirm({
            content: "你确定删除这条记录吗？",
            onOk: async () => {
                await FaceList({ method: "delete", id });
                message.success("操作成功！");
                actionRef.current.reload();
            }
        });
    }
    const [isModalOpen, setIsModalOpen] = useState(false);

    const showModal = (row) => {
        setIsModalOpen(true);
        let { created_at, gate_permissions, user_type: user } = row;
        created_at = moment(created_at * 1000).format('YYYY-MM-DD HH:MM:SS');
        let gate_permissionsArr = gate_permissions.map(item => item.device_name);
        gate_permissions = gate_permissionsArr.toString();
        form.setFieldsValue({ ...row, created_at, gate_permissions, user_type: user_type[user] });
        setId(row.id);
    };

    const handleCancel = () => {
        setIsModalOpen(false);
        setId();
    };
    const footer = <div className='footerButton'>
        <Button style={{ backgroundColor: "red", color: "#fff" }} onClick={() => checkPass(false)}>不通过</Button>
        <Button type='primary' onClick={() => checkPass(true)}>通过</Button>
    </div>
    const checkPass = (status) => {
        form.validateFields().then(async (values) => {
            const { feedback } = values;
            await FaceApprove({feedback,id,status})
            setIsModalOpen(false);
            message.success("操作成功")
            setTimeout(()=>{
                actionRef.current.reload();
            },2000)
        })
    }
    const FaceInfo = [
        { title: "业主", name: "name" },
        { title: "身份证号", name: "id_number" },
        { title: "住户身份", name: "user_type" },
        { title: "房屋", name: "house_name" },
        { title: "访问权限", name: "gate_permissions" },
        { title: "上传时间", name: "created_at" },
        { title: "人脸照片", name: "pic_url" },
    ]

    return (<>
        <div style={{ display: "flex", justifyContent: "end", marginBottom: "20px" }}><Button type="primary" onClick={hisitory.goBack}>返回</Button></div>
        <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={FaceList}
            search={{
                collapsed: false, collapseRender: () => false,
                span: 6
            }}
            options={false}
            columns={columns}
        />
        <Modal title="审核" open={isModalOpen} onCancel={handleCancel}
            maskClosable={false}
            footer={footer}
        >
            <Form form={form}
                labelCol={{ span: 4, }}
                wrapperCol={{ offset: 1 }}
            >
                {FaceInfo.map(item => {
                    if (item.name == "pic_url") {
                        return <Form.Item label={item.title} key={item.name} name={item.name}>
                            <Image src={form.getFieldValue(['pic_url'])} />
                        </Form.Item>
                    } else {
                        return <Form.Item label={item.title} key={item.name} name={item.name}>
                            <Input disabled />
                        </Form.Item>
                    }
                })}
                <Form.Item label="备注" name="feedback" wrapperCol={{ span: 12, offset: 1 }}>
                    <Input.TextArea autoSize={{ minRows: 4, maxRows: 6 }} placeholder="请输入备注" />
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default FaceManager