import { Select, Spin } from 'antd';
import debounce from 'lodash/debounce';
import { useMemo, useRef, useState } from 'react';
import { GetUser_list } from '../../services/user';
import { SearchOutlined } from '@ant-design/icons';


function DebounceSelect({ fetchOptions, ...props }) {
  const [fetching, setFetching] = useState(false);
  const [options, setOptions] = useState([]);
  const fetchRef = useRef(0);
  const debounceFetcher = useMemo(() => {
    const loadOptions = (value) => {
      fetchRef.current += 1;
      const fetchId = fetchRef.current;
      setOptions([]);
      setFetching(true);
      fetchUserList(value).then((newOptions) => {
        if (fetchId !== fetchRef.current) {
          // for fetch callback order
          return;
        }
        setOptions(newOptions);
        setFetching(false);
      });
    };
    return debounce(loadOptions);
  }, [fetchOptions]);
  return (
    <Select
      labelInValue
      filterOption={false}
      onSearch={debounceFetcher}
      //notFoundContent={fetching ? <Spin size="small" /> : null}
      {...props}
      options={options}
    />
  );
} // Usage of DebounceSelect

async function fetchUserList(name) {
  return GetUser_list({ name }).then(res => res.data).then((body) =>
    body.map((user) => ({
      label: `${user.name}--${user.phone}`,
      value: user.id
    }))
  )
}

const App = (props) => {
  const [value, setValue] = useState([]);
  return (
    <DebounceSelect
      mode={props.mode ? "multiple" : ''}
      allowClear={false}
      value={value}
      showSearch
      defaultOpen={false}
      suffixIcon={<SearchOutlined onClick={() => {
      }} />}
      placeholder="请输入住户姓名进行查询"
      fetchOptions={fetchUserList}
      onChange={(newValue) => {
        props.getValue(newValue)
        setValue(newValue);
      }}
      style={{
        width: '100%',
      }}
    />
  );
};

export default App;