import React, { useState, useEffect } from "react";
import type { ActionType } from "@ant-design/pro-table";
import ProTable from "@ant-design/pro-table";
import {
  Button,
  Modal,
  Form,
  Input,
  message,
  Select,
  DatePicker,
  Upload
} from "antd";
import { withRouter } from "react-router-dom";
import { FixApi, FixOrderSend, FixClassApi } from "../../services/fix";
import "./index.scss";
import { useUser } from "../User/hooks";
import { GetTimeStamp } from "../../utils/utils";
import moment from "moment";
import Uploadpic from "../../utils/handlePreview";
import { STATUS_TYPE } from "../../CONSTANT";
import { SearchOutlined } from '@ant-design/icons';
import { BuildingHouse } from '../../services/building';

const FixOnlineForm: React.FC = (props: any) => {
  const [pic, setPic]: any = React.useState([]);
  const [fixClass, setFixClass] = useState([]);
  const [buildHouse, setBuildHouse]: any = useState([]);
  const [cUsers, setUsers]: any = useUser();
  const [data, setData] = useState({});
  const [areaValue, setAreaValue]: any = useState("");
  const [value, setValue]: any = useState([]);
  const [searchValue, setsearchValue] = useState("");

  useEffect(() => {
    getAreaValue(areaValue)
  }, [areaValue]);
  const fetchUserList = async (house_name) => {
    return BuildingHouse({ house_name, page: -1, page_size: -1 }).then(res => res.data).then((body) =>
      body.map((user) => ({
        label: `${user.house_name}`,
        value: user.id
      }))
    ).then((newOptions) => {
      setBuildHouse(newOptions);
    });
  }
  const getAreaValue = async (areaValue = "") => {
    const { data } = await FixClassApi({ area: areaValue ? areaValue : "", page: 1, page_size: 999999 });
    if (areaValue) {
      const result = data.filter(item => item.enable === true);
      setFixClass(result?.map(({ name, id }) => ({ value: id, label: name })))
    } else {
      let area = {}
      data.map(item => {
        area[item.id] = { text: item.name }
      })
      setData(area)
    }
  };
  const columns: any = [
    {
      title: "订单类型",
      dataIndex: "is_me",
      search: true,
      hideInTable: true,
      valueType: "select",
      valueEnum: {
        false: { text: "全部" },
        true: { text: "指派给我的" }
      }
    },
    {
      title: "分类名称",
      dataIndex: "class_id",
      search: true,
      valueType: "select",
      valueEnum: data,
    },
    {
      title: "联系地址",
      dataIndex: "house_name",
      search: false
    },
    {
      title: "报修人",
      dataIndex: "apply_people",
      search: true
    },
    {
      title: "联系电话",
      dataIndex: "apply_people_phone",
      search: true
    },
    {
      title: "预约时间",
      dataIndex: "appointment",
      search: false,
      valueType: "dateTime"
    },
    {
      title: "报修内容",
      dataIndex: "apply_content",
      align: "center",
      search: false,
      ellipsis: true,
    },
    {
      title: "报修时间",
      dataIndex: "created_at",
      search: false,
      valueType: "dateTime",
      ellipsis: true,
    },
    {
      title: "状态",
      dataIndex: "status",
      search: true,
      width: "80px",
      valueType: "select",
      valueEnum: STATUS_TYPE
    },
    {
      title: "操作",
      dataIndex: "option",
      search: false,
      width: 210,
      align: "center",
      render: (_, row, index, action) => {
        const DETAIL_BUTTON = (
          <a
            className="mr-1.5"
            onClick={() => {
              props.history.push(`/admin/fix/online/order-detail?id=${row.id}`);
            }}
          >
            详情
          </a>
        );
        return [2, 3].includes(row.status)
          ? DETAIL_BUTTON
          : <>
            <a
              className="mr-1.5"
              onClick={() => {
                row.appointment = moment(row.appointment);
                form.setFieldsValue(row);
                if (row.house_id == 0) {
                  setBuildHouse([])
                  form.setFieldsValue({ house_id: "" })
                } else {
                  setBuildHouse([{ label: row.house_name, value: row.house_id }])
                }
                if (areaValue !== row.area) {
                  setAreaValue(row.area)
                }
                setPic(row.apply_pic);
                setState((prevState) => ({
                  ...prevState,
                  visible: true,
                  editId: row.id
                }));
              }}
            >
              编辑
            </a>
            <a
              className="mr-1.5"
              onClick={() => {
                setState((prevState) => ({
                  ...prevState,
                  orderVisible: true,
                  editId: row.id
                }));
              }}
            >
              派单
            </a>
            {DETAIL_BUTTON}
            <a
              onClick={() => {
                Modal.confirm({
                  title: "删除记录",
                  content: "你确定删除这条记录吗？",
                  onOk: async () => {
                    await FixApi({ method: "delete", id: row.id });
                    message.success("操作成功！");
                    actionRef.current.reload();
                  }
                });
              }}
            >
              删除
            </a>
          </>
      }
    }
  ];

  React.useEffect(() => {
    setUsers();
  }, []);
  const [state, setState] = React.useState({
    visible: false,
    orderVisible: false,
    editId: null
  });

  const actionRef: any = React.useRef<ActionType>();
  const [form] = Form.useForm();
  const [orderForm] = Form.useForm();

  const onSubmit = () => {
    form.validateFields().then(async (values) => {
      await FixApi({
        method: state.editId ? "put" : "post",
        ...values,
        appointment: GetTimeStamp(values.appointment),
        id: state.editId
      });
      message.success("操作成功！");
      form.resetFields();
      actionRef.current?.reloadAndRest();
      setState((prevState) => ({ ...prevState, visible: false, editId: null }));
    });
  };

  const handleSendOrder = () => {
    orderForm.validateFields().then(async (values) => {
      await FixOrderSend({ ...values, id: state.editId });
      message.success("操作成功！");
      orderForm.resetFields();
      actionRef.current?.reloadAndRest();
      setState((prevState) => ({
        ...prevState,
        orderVisible: false,
        editId: null
      }));
    });
  };
  const garden_pic = (arr) => {
    form.setFieldsValue({ apply_pic: arr })
  }
  const disabledDate = (current) => {
    // Can not select days before today and today
    return current && current <= moment().startOf('day');
  };

  //当日只能选择当前时间之后的时间点
  const disabledDateTime = (date: any) => {
    const hours = moment().hours();
    const minutes = moment().minutes();
    const seconds = moment().seconds();
    // 当日只能选择当前时间之后的时间点
    if (date && moment(date).date() === moment().date()) {
      return {
        disabledHours: () => range(0, 24).splice(0, hours).concat(range(21, 24)),
        disabledMinutes: () => range(0, 60).splice(0, minutes + 1)
      };
    }
    return {
      disabledHours: () => range(0, 9).concat(range(21, 24)),
    };
  };
  const range = (start, end) => {
    const result: any = [];

    for (let i = start; i < end; i++) {
      result.push(i);
    }

    return result;
  };

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey={r => r.id}
        request={FixApi}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6
        }}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields();
              setPic([]);
              setBuildHouse([])
              setState((preState) => ({
                ...preState,
                visible: true,
                editId: null
              }));
            }}
          >
            添加
          </Button>
        ]}
        columns={columns}
      />
      <Modal
        title="派单"
        visible={state.orderVisible}
        maskClosable={false}
        onOk={handleSendOrder}
        onCancel={() => setState((pre) => ({ ...pre, orderVisible: false }))}
      >
        <Form labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} form={orderForm}>
          <Form.Item
            label="处理人"
            name="current_uid"
            rules={[{ required: true }]}
          >
            <Select placeholder="请选择" options={cUsers} />
          </Form.Item>
          <Form.Item
            label="处理意见"
            name="feedback"
          >
            <Input.TextArea placeholder="多行输入" rows={4} />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title={state.editId ? "编辑报修" : "添加报修"}
        visible={state.visible}
        maskClosable={false}
        onOk={onSubmit}
        onCancel={() => setState((pre) => ({ ...pre, visible: false }))}
      >
        <Form labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} form={form}>
          <Form.Item label="区域" name="area" rules={[{ required: true }]}>
            <Select
              placeholder="请选择区域"
              onChange={(value) => {
                if (value == 1) {
                  setAreaValue(1)
                } else {
                  setAreaValue(2)
                }
                form.resetFields(["class_id"])
              }}
              options={[
                { label: "公共区域", value: 1 },
                { label: "室内", value: 2 }
              ]}
            />
          </Form.Item>
          <Form.Item
            label="报修分类"
            name="class_id"
            rules={[{ required: true }]}
          >
            <Select placeholder="请选择报修分类" options={fixClass} />
          </Form.Item>
          {[1, ""].includes(areaValue) ?
            null
            :
            <Form.Item
              label="联系地址"
              name="house_id"
              rules={[{ required: true }]}
              extra="请按1-1-1的格式进行查询选择联系地址"
            >
              <Select
                allowClear={false}
                value={value}
                showSearch
                defaultOpen={false}
                filterOption={false}
                onSearch={(value) => setsearchValue(value)}
                onSelect={(value) => setsearchValue("")}
                suffixIcon={<SearchOutlined onClick={() => {
                  fetchUserList(searchValue)
                }} />}
                placeholder="请输入房屋号进行查询"
                onChange={(newValue) => {
                  setValue(newValue)
                }}
                options={buildHouse}
                style={{
                  width: '100%',
                }} />
            </Form.Item>
          }
          <Form.Item
            label="报修人"
            name="apply_people"
            rules={[{ required: true }]}
          >
            <Input placeholder="请输入报修人" />
          </Form.Item>
          <Form.Item
            label="联系方式"
            name="apply_people_phone"
            rules={[{ required: true }]}
          >
            <Input placeholder="请输入联系方式" />
          </Form.Item>
          <Form.Item
            label="预约时间"
            name="appointment"
            rules={[{ required: true }]}
          >
            <DatePicker
              placeholder="选择时间"
              format="YYYY-MM-DD HH:mm"
              disabledDate={disabledDate}
              disabledTime={disabledDateTime}
              showTime={{
                defaultValue: moment('00:00:00', 'HH:mm'),
              }}
            />
          </Form.Item>
          <Form.Item
            label="报修内容"
            name="apply_content"
            rules={[{ required: true }]}
          >
            <Input.TextArea placeholder="请输入报修内容" rows={4} />
          </Form.Item>
          <Form.Item
            label="报修图片"
            name="apply_pic"
            rules={[{ required: true }]}
          >
            <Uploadpic getSrc={garden_pic} src={pic} maxCount={8} />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  );
};

export default withRouter(FixOnlineForm);
