import React, { useRef ,useState,useEffect} from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, message, Select } from 'antd'
import { withRouter } from 'react-router-dom'
import { FixOrderReturnVisit, FixApi,FixClassApi } from '../../services/fix'
import './index.scss'
import { STATUS_TYPE } from '../../CONSTANT'

const FixReturnVisit: React.FC = (props: any) => {
  const [data, setData] = useState({})
  useEffect(() => {
    FixClassApi({page:1,page_size:9999}).then(res => {
      let data = {}
      res.data.map(item => {
        data[item.id] = { text: item.name }
      })
      setData(data)
    })
  }, [])
  const columns: any = [
    {
      title: '分类名称',
      dataIndex: 'class_id',
      search: true,
      valueType: "select",
      valueEnum: data
    },
    {
      title: '联系地址',
      dataIndex: 'house_name',
      search: false,
    },
    {
      title: '报修人',
      dataIndex: 'apply_people',
      align:"center",
      search: true,
    },
    {
      title: '联系电话',
      dataIndex: 'apply_people_phone',
      search: true,
    },
    {
      title: '预约时间',
      dataIndex: 'appointment',
      search: false,
      align:"center",
      valueType: 'dateTime',
    },
    {
      title: '报修内容',
      dataIndex: 'apply_content',
      search: false,
      ellipsis: true,
    },
    {
      title: '报修时间',
      dataIndex: 'created_at',
      search: false,
      align:"center",
      valueType: 'dateTime',
    },
    {
      title: '状态',
      dataIndex: 'status',
      search: false,
      align:"center",
      valueEnum: STATUS_TYPE
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      align: 'center',
      render: (_, row, index, action) => <>
      <Button type='link'
            onClick={() => {
              if (row.return_visit_level == 0) {
                orderForm.setFieldsValue(row)
                orderForm.setFieldsValue({ return_visit_level: 1 })
              } else {
                orderForm.setFieldsValue(row)
              }
              setState(prevState => ({
                ...prevState,
                formMode: 'send',
                orderVisible: true,
                editId: row.id
              }))
            }}
          >回访</Button>
          <Button type='link'
            onClick={() => {
              props.history.push(`/admin/fix/return-visit/order-detail?id=${row.id}`)
            }}
          >详情</Button>
      </>
    }
  ]

  const [state, setState] = React.useState({
    orderVisible: false,
    editId: null,
    formMode: 'send'
  })

  const actionRef: any = useRef<ActionType>()
  const [orderForm] = Form.useForm()

  const onSubmit = () => {
    orderForm.validateFields().then(async values => {
      await FixOrderReturnVisit({ ...values, id: state.editId })
      message.success('操作成功！')
      orderForm.resetFields()
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, orderVisible: false, editId: null }))
    })
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        request={FixApi}
        params={{ status: 3 }}
        columns={columns}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6
        }}
      />
      <Modal
        title='报修回访'
        visible={state.orderVisible}
        maskClosable={false}
        onOk={onSubmit}
        onCancel={() => {
          setState(pre => ({ ...pre, orderVisible: false }))
          orderForm.resetFields()
        }}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={orderForm}
        >
          <Form.Item label='满意度' name="return_visit_level" rules={[{ required: true }]}>
            <Select placeholder="请选择" options={[
              { label: '满意', value: 1 || 0 },
              { label: '不满意', value: 2 },
            ]} />
          </Form.Item>
          <Form.Item label='业主评价' name="return_visit_content" rules={[{ required: true }]}>
            <Input.TextArea placeholder="多行输入" rows={4} />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(FixReturnVisit)