import React, { useState, useEffect } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, message, Select, Upload } from 'antd'
import { withRouter } from 'react-router-dom'
import { FixApi, FixOrderSend, FixOrderRefund, FixOrderFinish, FixClassApi } from '../../services/fix'
import './index.scss'
import { useUser } from "../User/hooks"
import Uploadpic from '../../utils/handlePreview'
import { STATUS_TYPE } from '../../CONSTANT'

const FixTodo: React.FC = (props: any) => {
  const [data, setData] = useState({})
  useEffect(() => {
    FixClassApi({page:1,page_size:9999}).then(res => {
      let data = {}
      res.data.map(item => {
        data[item.id] = { text: item.name }
      })
      setData(data)
    })
  }, [])

  const columns: any = [
    {
      title: '分类名称',
      dataIndex: 'class_id',
      search: true,
      valueType: "select",
      valueEnum: data
    },
    {
      title: '联系地址',
      dataIndex: 'house_name',
      search: false,
    },
    {
      title: '报修人',
      dataIndex: 'apply_people',
      search: true,
    },
    {
      title: '联系电话',
      dataIndex: 'apply_people_phone',
      search: true,
    },
    {
      title: '预约时间',
      dataIndex: 'appointment',
      search: false,
      valueType: 'dateTime',
    },
    {
      title: '报修内容',
      dataIndex: 'apply_content',
      search: false,
      ellipsis: true,
    },
    {
      title: '报修时间',
      dataIndex: 'created_at',
      search: false,
      valueType: 'dateTime',
    },
    {
      title: "处理人",
      dataIndex: "current_user",
      width: "60px",
      search: false
    },
    {
      title: '状态',
      dataIndex: 'status',
      search: true,
      width: "80px",
      align: "center",
      valueEnum: STATUS_TYPE
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 210,
      align: 'center',
      render: (_, row, index, action) => <>
      <Button
          type='link'
          onClick={() => setMethod('send', row.id)}
        >转单</Button>
        {/* <Button
          type='link'
          onClick={() => setMethod('refund', row.id)}
        >退单</Button> */}
         <Button
          type='link'
          onClick={() => {
            props.history.push(`/admin/fix/dealt/order-detail?id=${row.id}`)
          }}
        >详情</Button>
        <Button type='link' onClick={() => setMethod('finish', row.id)}>办结</Button>
      </>
    }
  ]

  const [pic, setPic]: any = React.useState([])
  const [cUsers, setUsers]: any = useUser(true)

  React.useEffect(() => {
    setUsers()
  }, [])

  const setMethod = (method, id) => {
    orderForm.resetFields()
    setState(prevState => ({
      ...prevState,
      formMode: method,
      orderVisible: true,
      editId: id
    }))
  }

  const [state, setState] = React.useState({
    visible: false,
    orderVisible: false,
    editId: null,
    formMode: 'send'
  })
  const repair_pic = (arr) => {
    orderForm.setFieldsValue({ repair_pic: arr })
  }

  const FinishForm = <React.Fragment>
    <Form.Item label='处理意见' name="feedback" >
      <Input.TextArea placeholder="多行输入" rows={4} />
    </Form.Item>
    <Form.Item label='维修后照片' name="repair_pic" >
      <Uploadpic getSrc={repair_pic} src={pic} maxCount={8}/>
    </Form.Item>
  </React.Fragment>

  // 报修退单
  const ChargeBackForm = <React.Fragment>
    {/*<Form.Item label='上级处理人' name="feedback" rules={[{ required: true }]}>*/}
    {/*  <Input placeholder="单行输入"/>*/}
    {/*</Form.Item>*/}
    <Form.Item label='处理意见' name="feedback" rules={[{ required: true }]}>
      <Input.TextArea placeholder="多行输入" rows={4} />
    </Form.Item>
  </React.Fragment>

  const SendForm = <React.Fragment>
    <Form.Item label='处理人' name="current_uid" rules={[{ required: true }]}>
      <Select placeholder='请选择' options={cUsers} />
    </Form.Item>
    <Form.Item label='处理意见' name="feedback" >
      <Input.TextArea placeholder="多行输入" rows={4} />
    </Form.Item>
  </React.Fragment>

  const Forms = {
    refund: ChargeBackForm,
    finish: FinishForm,
    send: SendForm
  }

  const actionRef: any = React.useRef<ActionType>()
  const [orderForm] = Form.useForm()

  const onSubmit = () => {
    const _Api = {
      send: FixOrderSend,
      refund: FixOrderRefund,
      finish: FixOrderFinish
    }
    orderForm.validateFields().then(async values => {
      const params: any = { id: state.editId }
      await _Api[state.formMode]({ ...values, ...params })
      message.success('操作成功！')
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, orderVisible: false, editId: null }))
    })
  }

  const titleMap = {
    refund: '退单',
    finish: '办结工单',
    send: '转单'
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey={r => r.id}
        request={FixApi}
        params={{status:2,is_me:true}}
        columns={columns}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6
        }}
      />
      <Modal
        title={titleMap[state.formMode]}
        visible={state.orderVisible}
        maskClosable={false}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, orderVisible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={orderForm}
        >
          {Forms[state.formMode]}
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(FixTodo)