import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Radio, Input, message, Select } from 'antd'
import { withRouter } from 'react-router-dom'
import { FixClassApi } from '../../services/fix'
import './index.scss'

const FixTypes: React.FC = (props: any) => {
  const columns: any = [
    {
      title: "报修区域",
      dataIndex:"area",
      valueType:"select",
      valueEnum:{
        1:{text:"公区"},
        2:{text:"室内"}
      }
    },
    {
      title: '分类名称',
      dataIndex: 'name',
      search: false,
    },
    {
      title: '状态',
      dataIndex: 'enable',
      search: false,
      valueEnum: {
        true: { text: '开启', status: 'Success' },
        false: { text: '关闭', status: 'Error' },
      }
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 210,
      align: 'center',
      render: (_, row, index, action) => <>
        <Button type='link'
          onClick={() => {
            form.setFieldsValue(row)
            setState(prevState => ({
              ...prevState,
              visible: true,
              editId: row.id
            }))
          }}
        >编辑</Button>
        <Button type='link' onClick={() => {
          Modal.confirm({
            title: '删除记录',
            content: '你确定删除这条记录吗？',
            onOk: async () => {
              await FixClassApi({ method: 'delete', id: row.id })
              message.success('操作成功！')
              actionRef.current.reload()
            }
          })
        }}>删除</Button>
      </>
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    editId: null
  })

  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(async values => {
      await FixClassApi({
        method: state.editId ? 'put' : 'post',
        ...values,
        id: state.editId
      })
      message.success('操作成功！')
      form.resetFields()
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false, editId: null }))
    })
  }
  const areaOption = [
    {label:"公区",value:1},
    {label:"室内",value:2}
  ]

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey={r=>r.id}
        request={FixClassApi}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              setState(preState => ({ ...preState, visible: true }))
              form.resetFields()
            }}
          >添加</Button>
        ]}
        columns={columns}
      />
      <Modal
        title={state.editId?"修改分类":"添加分类"}
        visible={state.visible}
        maskClosable={false}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false,editId:null }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
          labelAlign="left"
        >
          <Form.Item label='分类名称' name="name" rules={[{ required: true,message:"请输入分类名称" }]}>
            <Input placeholder="请输入分类名称" />
          </Form.Item>
          <Form.Item label="报修区域" name="area" rules={[{required:true,message:"请选择报修区域"}]}>
            <Select placeholder="请选择报修区域" options={areaOption}/>
          </Form.Item>
          <Form.Item label='状态' name="enable" rules={[{ required: true,message:"请选择状态" }]}>
            <Radio.Group>
              <Radio value={true}>开启</Radio>
              <Radio value={false}>关闭</Radio>
            </Radio.Group>
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(FixTypes)