import React, { useState } from "react";
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table';
import { HouseAppointment } from "../../services/rent";
import moment from 'moment'
import { Button, Modal, message, Form, Select, Input } from "antd";

const AppointmentHouse = () => {
    const actionRef: any = React.useRef<ActionType>();;
    const [form] = Form.useForm();
    const status1 = [
        { label: "已受理", value: 2 },
        { label: "已拒绝", value: 3 }
    ];
    const status2 = [
        { label: "未到访", value: 4 },
        { label: "已到访", value: 5 }
    ]
    const [state, setState]: any = useState({
        visible: false,
        id: null,
        status: 1
    })
    let formStatus;
    const columns: any = [
        {
            title: '房屋',
            dataIndex: 'house_name',
            search: true,
        },
        {
            title: '联系人',
            dataIndex: 'name',
        },
        {
            title: '联系人电话',
            dataIndex: 'phone',
        },
        {
            title: '看房时间',
            dataIndex: 'appointment_time',
            search: false,
            render: (_, row) => <>
                {row.appointment_time == 0 ? "随时看房" : moment(row.appointment_time * 1000).format("YYYY-MM-DD")}
            </>
        },
        {
            title: '类型',
            dataIndex: 'rent_type',
            search: false,
            render: (_, row) => <span>租房</span>
        },
        {
            title: '状态',
            dataIndex: 'status',
            search: false,
            valueEnum: {
                1: {
                    text: '待受理',
                    status: 'Default',
                },
                2: {
                    text: '已受理',
                    status: 'Processing',
                },
                3: {
                    text: '已拒绝',
                    status: 'Error',
                },
                4: {
                    text: '未到访',
                    status: 'Warning',
                },
                5: {
                    text: '已到访',
                    status: 'Success',
                },
                6: {
                    text: '已过期',
                    status: 'Error',
                },
            }
        },
        {
            title: '操作',
            dataIndex: 'option',
            search: false,
            align: 'center',
            render: (_, row) => <>
                {[1, 2].includes(row.status) ? <Button type="link"
                    onClick={() => {
                        form.resetFields();
                        setState({ visible: true, id: row.id, status: row.status })
                    }}
                >状态变更</Button> :
                    <Button type="link" disabled>状态变更</Button>}
                <Button type="link" onClick={() => deleteAppointment(row.id)}>删除</Button>
            </>
        }
    ]
    const deleteAppointment = (id) => {
        {
            Modal.confirm({
                content: '你确定删除这条记录吗？',
                onOk: async () => {
                    await HouseAppointment({ id, method: "delete" })
                    message.success('操作成功')
                    actionRef.current.reload()
                },
            });
        }
    }
    const submitAppointment = () => {
        form.validateFields().then(async (values) => {
            await HouseAppointment({
                method: "put",
                ...values,
                id: state.id
            })
            message.success("操作成功")
            setState({ visible: false, id: null, status: 1 })
            actionRef.current?.reload()
        })
    }
    return <>
        <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={HouseAppointment}
            search={{
                collapsed: false, collapseRender: () => false,
                span: 6
            }}
            columns={columns}
        />
        <Modal
            title="修改租房预约状态"
            visible={state.visible}
            width="400px"
            onCancel={() => setState({ visible: false, id: null, status: 1 })}
            maskClosable={false}
            okText="保存"
            onOk={submitAppointment}
        >
            <Form
                form={form}
                labelCol={{ span: 4 }}
            >
                <Form.Item label="状态" name="status" rules={[{ required: true, message: "请选择状态" }]}>
                    <Select placeholder="请选择要更改的状态" options={state.status == 1 ? status1 : status2}></Select>
                </Form.Item>
                <Form.Item label="备注" name="feedback">
                    <Input.TextArea placeholder="请输入备注" />
                </Form.Item>
            </Form>
        </Modal>
    </>
}

export default AppointmentHouse