import React, { useEffect, useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Form, message, Modal, Select } from 'antd'
import { RentHouseManager } from '../../services/rent'
import { useHistory } from 'react-router'
import { User } from '../../services/api'

const Broker = (props) => {
    const history = useHistory();
    const location = history.location
    const state: any = location.state
    const rent_id = props.rend_id || state.id
    const actionRef: any = React.useRef<ActionType>();
    const [form] = Form.useForm()
    const [managerState, setManagerState] = useState(false)
    const [managerList, setManagerList] = useState([])
    const [exclude, setexclude]: any = useState("")
    const [num,setNum] = useState(0)
    const columns: any = [
        {
            title: '经济人',
            align: 'center',
            dataIndex: 'name'
        },
        {
            title: '联系电话',
            align: 'center',
            dataIndex: 'phone'
        },
        {
            title: '姓名',
            align: 'center',
            dataIndex: 'name'
        },
        {
            title: '操作',
            align: 'center',
            dataIndex: 'option',
            render: (_, row) => <Button type='link' onClick={() => deleteManager(row.id)}>移除</Button>
        },
    ]
    const deleteManager = (id) => {
        Modal.confirm({
            title: "删除记录",
            content: "你确定删除这条记录吗？",
            onOk: async () => {
                await RentHouseManager({ method: 'delete', id });
                message.success("操作成功！");
                actionRef.current.reload();
                setNum(Math.random())
            }
        });
    }
    const controlModal = (visible) => {
        setManagerState(visible)
        form.resetFields()
    }
    useEffect(() => {
        User({ exclude}).then(res => {
            const data = res.data.map(item => {
                return { label: item.real_name, value: item.id }
            })
            setManagerList(data)
        })
    }, [exclude])
    useEffect(() => {
        RentHouseManager({ rent_id }).then(res => {
            const data = res.data.map(item => {
                return item.manager_uid
            })
            setexclude(data.join())
        })
    },[num])
    const addManager = () => {
        form.validateFields().then(async (value) => {
            await RentHouseManager({ method: 'post', ...value, rent_id })
            setNum(Math.random())
            message.success("添加成功")
            actionRef.current.reload();
            controlModal(false)
        })
    }
    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey={record => record.id}
            search={false}
            request={RentHouseManager}
            params={{ rent_id }}
            toolBarRender={() => [
                <Button type='primary' onClick={() => controlModal(true)}>添加</Button>,
                <Button type='primary' onClick={history.goBack}>返回</Button>
            ]}
            columns={columns}
        />
        <Modal
            title='房屋租赁分配经济人'
            visible={managerState}
            width='500px'
            onCancel={() => controlModal(false)}
            onOk={addManager}
            maskClosable={false}
        >
            <Form
                form={form}
            >
                <Form.Item label="经济人" name="manager_uid" rules={[{ required: true, message: "请选择经济人" }]}>
                    <Select placeholder="请选择经济人" options={managerList}></Select>
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default Broker