import React, { useEffect, useState } from 'react'
import {
  Form, Card, Row, Col, Select, Radio, Input, Checkbox, Upload, Button, InputNumber, DatePicker, message, Image,
  Modal
} from "antd"
import { PlusOutlined } from '@ant-design/icons'
import { RentHouse } from "../../services/rent"
import { useHistory } from "react-router"
import './index.scss'
import { getLocalTime } from '../../utils/utils'
import { transitionSecond } from '../../utils/utils'
import { connect } from 'react-redux'
import { getHouseBuildingsList } from '../../redux/action/owner'
import Uploadpic from '../../utils/handlePreview'
import moment from 'moment'

const defaultConfig = {
  1: '床',
  2: '天然气',
  3: '暖气',
  4: '宽带',
  5: '冰箱',
  6: '衣柜',
  7: '沙发',
  8: '空调',
  9: '电视',
  10: '热水器',
  11: '洗衣机',
}
const especiallyConfig = {
  1: '智能门锁',
  2: 'WIFI',
  3: '近地铁',
  4: '停车场',
  5: '独立卫生间',
  6: '私人阳台',
  7: '首次出租',
}

const House_direction = [
  { label: '东', value: 1 },
  { label: '南', value: 2 },
  { label: '西', value: 3 },
  { label: '北', value: 4 },
]
const House_decorating = [
  { label: '精装', value: 1 },
  { label: '简装', value: 2 },
  { label: '清水', value: 3 },
]
const House_pay_time_type = [
  { label: '月付', value: 1 },
  { label: '季付', value: 2 },
  { label: '半年付', value: 3 },
  { label: '年付', value: 4 }
]
const House_rent_type = [
  { label: '整租', value: 1 },
  { label: '合租', value: 2 },
  { label: '转租', value: 3 }
]
const House_room_type = [
  { label: '全部', value: 1 },
  { label: '主卧', value: 2 },
  { label: '次卧', value: 3 }
]

const LeaseCreate: React.FC = (props: any) => {
  const [currentHouse, setCurrentHouse]: any = React.useState({})
  const [housePic, setHousePic]: any = React.useState([])
  const [certPic, setCertPic]: any = React.useState([])
  useEffect(() => {
    if (!state) {
      props.getHouseBuildingsList({ house_rent: true })
    }
  }, [])
  const history = useHistory();
  const location = history.location
  const state: any = location.state;
  const [form] = Form.useForm()

  const onSubmit = () => {
    const { wc_count, id: house_id } = currentHouse
    if (!house_id) return message.error('请先选择房屋！')
    if (!wc_count) return message.error('请输入卫生间数量！')
    form.validateFields().then(async values => {
      try {
        await RentHouse({
          method: state ? "put" : 'post',
          ...values,
          wc_count,
          house_id,
          id: state ? state.id : null,
          in_time: transitionSecond(values.in_time),
          base_conf: (() => {
            let value = 0
            values?.base_conf.forEach(n => {
              value = value | (1 << n)
            })
            return value
          })(),
          special_conf: (() => {
            let value = 0
            values?.special_conf.forEach(n => {
              value = value | (1 << n)
            })
            return value
          })()
        })
        message.success('操作成功！')
        history.push('/admin/house/manager')
      } catch (e) {
        console.log(e)
      }
    })
  }
  //限制当天之前的如期不可选
  const { RangePicker } = DatePicker
  const disabledDate = (current) => {
    return current && current < moment().add(-1, 'day')
  }
  const getInital = (arr) => {
    let result: any = []
    arr.map((item, index) => {
      if (item == 1) {
        result.push(index + 1 + '')
      }
    })
    return result
  }

  useEffect(() => {
    if (state) {
      const { base_conf, special_conf } = state
      const base_confArr = base_conf.toString(2).split('').slice(0, base_conf.toString(2).length - 1).reverse()
      const special_confArr = special_conf.toString(2).split('').slice(0, special_conf.toString(2).length - 1).reverse()
      const in_time = moment(state.in_time * 1000)
      setHousePic(state.house_pic)
      setCertPic(state.cert_pic)
      setCurrentHouse({ wc_count: state.wc_count, id: state.house_id })
      form.setFieldsValue({
        ...state,
        base_conf: getInital(base_confArr),
        special_conf: getInital(special_confArr),
        in_time
      })
    }
  }, [state])
  const house_pic = (arr) => {
    form.setFieldsValue({ house_pic: arr })
  }
  const cert_pic = (arr) => {
    form.setFieldsValue({ cert_pic: arr })
  }
  return (
    <><Card>
      <Form labelCol={{ span: 7 }} wrapperCol={{ span: 17 }} form={form}
      >
        <Row>
          <div className={'form-block__title'}>房屋基本信息
            <Button type='primary' className='goBack' onClick={history.goBack}>返回</Button>
          </div>
          <Col span={8}>
            <Form.Item label='房屋' name='house_name' required>
              {
                state ?
                  <Select options={[{ label: state.house_name, value: state.house_id }]} disabled />
                  : <Select placeholder="请选择" onChange={(value, index: any) => {
                    props.house_info.map(item => {
                      if (value == item.id) {
                        setCurrentHouse({...currentHouse,...item})
                      }
                    })
                  }}>
                    {props.house_info.map((item) => <Select.Option value={item.id} key={item.house_name}>{item.house_name}</Select.Option>
                    )}
                  </Select>}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label='楼层'>
              {state ? <span>{state.layer}</span> :
                currentHouse.layer || '未选择房屋'}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label='建筑面积'>
              {state ? <span>{state.house_area}</span> :
                currentHouse.house_area || '未选择房屋'}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label='朝向' name="direction" rules={[{ required: true }]}>
              {
                <Select placeholder="请选择" options={House_direction} />}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label='户型' rules={[{ required: true }]}>
              <Input
                disabled
                bordered={false}
                value={state ? state.room_count : currentHouse.room_count}
                style={{ width: '30px', marginRight: 10 }} />
              <span>室</span>
              <Input
                disabled
                bordered={false}
                value={state ? state.hall_count : currentHouse.hall_count}
                style={{ width: '30px', marginRight: 10 }} />
              <span>厅</span>
              {state ? <>
                <InputNumber
                  bordered={false}
                  disabled={false}
                  min={0}
                  max={9}
                  value={currentHouse.wc_count}
                  controls={false}
                  style={{ width: '40px' }}
                  onChange={(e) => {
                    setCurrentHouse({ ...currentHouse, wc_count: e })
                  }} />
                <span>卫</span>
              </> :
                <><InputNumber
                  bordered={false}
                  disabled={false}
                  min={0}
                  max={9}
                  style={{ width: '40px' }}
                  controls={false}
                  onChange={(e) => {
                    setCurrentHouse({ ...currentHouse, wc_count: e })
                  }} /><span>卫</span></>
              }
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label='装修情况' name='decorating' rules={[{ required: true }]}>
              {
                <Select placeholder={'精装修'} options={House_decorating} />}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label='是否有电梯'>
              {state ? <Radio checked>{state.has_lift == true ? "是" : "否"}</Radio> :
                <Radio checked>{currentHouse.has_lift == true ? "是" : "否"}</Radio>}
            </Form.Item>
          </Col>
        </Row>
        {/* 联系人信息 */}
        <Row>
          <div className={'form-block__title'}>联系人信息</div>
          <Col span={6}>
            <Form.Item label={'联系人'} name="contacter" rules={[{ required: true }]}>
              {
                <Input placeholder="单行输入" />}
            </Form.Item>
          </Col>
          <Col span={7}>
            <Form.Item label={'联系方式'} name="contact_phone" rules={[{ required: true }]}>
              {
                <Input placeholder="单行输入" />}
            </Form.Item>
          </Col>
        </Row>
        <Row>
          <div className={'form-block__title'}>租房信息</div>
          <Col span={8}>
            <Form.Item className='w-4/5' label='付款方式' name="pay_time_type" rules={[{ required: true }]}>
              {
                <Select placeholder={'请选择'} options={House_pay_time_type} />}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item className={'w-4/5'} label='出租方式' name="rent_type" rules={[{ required: true }]}>
              {
                <Select placeholder={'请选择'} options={House_rent_type} />}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item className={'w-4/5'} label='房间类型' name="room_type" rules={[{ required: true }]}>
              {
                <Select placeholder={'请选择'} options={House_room_type} />}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item className={'w-4/5'} label='面积' name="room_area" rules={[{ required: true }]}>
              {<InputNumber placeholder={'请选择'} />}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item className={'w-4/5'} label='租金(元/月)' name="rent_price" rules={[{ required: true }]}>
              {<InputNumber placeholder={'请选择'} />}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item className={'w-4/5'} label='押金(元)' name="desposit" rules={[{ required: true }]}>
              {<InputNumber placeholder={'请选择'} />}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item className={'w-4/5'} label='服务费(元)' name="service_price" rules={[{ required: true }]}>
              {<InputNumber placeholder={'请选择'} />}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item className={'w-4/5'} label='中介费(元)' name="intermediary_price" rules={[{ required: true }]}>
              {<InputNumber placeholder={'请选择'} />}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item className={'w-4/5'} label='可入住时间' name="in_time" rules={[{ required: true }]}>
              {<DatePicker disabledDate={disabledDate} placeholder={'请选择'} />}
            </Form.Item>
          </Col>
        </Row>
        <Row className={'mb-5'}>
          <div className={'form-block__title'}>基本配置</div>
          <Form.Item
            label="内容"
            style={{ width: "100%" }}
            wrapperCol={{ span: 22 }}
            labelCol={{ span: 2 }}
            name="base_conf"
            rules={[{ required: true }]}
          >
            {
              <Checkbox.Group>
                {Object.keys(defaultConfig).map((key, index) => (
                  <Checkbox value={key} key={key}>{defaultConfig[key]}</Checkbox>
                ))}
              </Checkbox.Group>}
          </Form.Item>
        </Row>
        <Row className={'mb-5'}>
          <div className={'form-block__title'}>特色</div>
          <Form.Item
            label="内容"
            name="special_conf"
            style={{ width: "100%" }}
            wrapperCol={{ span: 22 }}
            labelCol={{ span: 2 }}
            rules={[{ required: true }]}
          >
            {
              <Checkbox.Group>
                {Object.keys(especiallyConfig).map((key, index) => <Checkbox value={key} key={key}>{especiallyConfig[key]}</Checkbox>
                )}
              </Checkbox.Group>}
          </Form.Item>
        </Row>
        <Row className={'mb-5'}>
          <div className={'form-block__title'}>房屋照片</div>
          <div style={{ textAlign: 'left' }}>
            <Form.Item name="house_pic" wrapperCol={{ span: 24 }}
              rules={[{ required: true, message: "请上传房屋照片" }]}
            >
              <Uploadpic getSrc={house_pic} src={housePic} maxCount={8} />
            </Form.Item>
          </div>
        </Row>
        <Row >
          <div className={'form-block__title'}>房屋证件</div>
          <div style={{ textAlign: 'left' }}>
            <Form.Item name="cert_pic" rules={[{ required: true, message: "请上传房屋证件" }]}
              wrapperCol={{ span: 24 }} className="pics">
              <Uploadpic getSrc={cert_pic} src={certPic} maxCount={8} />
            </Form.Item>
          </div>
        </Row>
        <div className={'form-block__title'}>房屋简介</div>
        <Form.Item wrapperCol={{ span: 12 }} name="desc" rules={[{ required: true, message: "请输入房屋简介" }]}>
          {
            <Input.TextArea placeholder="多行输入" rows={4} />}
        </Form.Item>
        {state ? <>
          {state.approve_status == 1 ?
            <Form.Item>
              <Button type="primary" onClick={onSubmit}>更新房源</Button>
            </Form.Item>
            : ""}
        </>
          : <Form.Item>
            <Button type="primary" onClick={onSubmit}>发布房源</Button>
          </Form.Item>}
      </Form>
    </Card>
    </>
  )
}
const mapStateToProps = (state) => {
  return {
    house_info: state.getBuilindsHouse.list,
  }
}

const mapDispatchToProps = (dispatch) => {
  return {
    getHouseBuildingsList: (userInput) => dispatch(getHouseBuildingsList(userInput)),
  }
}

export default connect(mapStateToProps, mapDispatchToProps)(LeaseCreate)
