import React, { useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, message } from 'antd'
import { Link, withRouter } from 'react-router-dom'
import { RentHouse, RentHouseDown } from '../../services/rent'
import './index.scss'

const Activity: React.FC = (props: any) => {
  const actionRef: any = React.useRef<ActionType>();

  const columns: any = [
    {
      title: '房屋',
      dataIndex: 'house_name',
      search: false,
    },
    {
      title: '联系人',
      dataIndex: 'contacter'
    },
    {
      title: '联系人电话',
      dataIndex: 'contact_phone',
    },
    {
      title: '期望租金',
      dataIndex: 'rent_price',
      search: false,
    },
    {
      title: '出租方式',
      dataIndex: 'rent_type',
      valueEnum: {
        1: { text: '整租' },
        2: { text: '合租' },
        3: { text: '转租' },
      }
    },
    {
      title: '建筑面积',
      dataIndex: 'room_area',
      search: false,
    },
    {
      title: '装修情况',
      dataIndex: 'decorating',
      search: false,
      valueEnum: {
        1: { text: '精装' },
        2: { text: '简装' },
        3: { text: '清水' },
      }
    },
    {
      title: '状态',
      dataIndex: 'approve_status',
      valueType: 'select',
      valueEnum: {
        1: { text: '待审核', status: 'Default' },
        2: { text: '已审核', status: 'Success', },
        3: { text: '未通过', status: 'Error' },
        4: { text: "已下架", status: "Default" }
      }
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      align: 'center',
      render: (_, row, index, action) => <>
        {row.approve_status == 1 ? <Link to={{ pathname: "/admin/house/manager/check", state: row }} style={{ marginRight: 10 }}>审核</Link> :
          <Button type='link' disabled>审核</Button>
        }
        {row.approve_status == 2 ? <>
          <Link to={{ pathname: "/admin/house/manager/assigning", state: row }} style={{ marginRight: 10 }}>经济人管理</Link>
          <Button type='link' onClick={() => {
            Modal.confirm({
              title: '确认下架这条记录吗?',
              content: '你确定下架这条记录吗？',
              onOk: async () => {
                await RentHouseDown({ id: row.id })
                message.success('操作成功')
                actionRef.current.reload()
              },
            });
          }}>下架</Button>
        </> :
          <>
            <Button type='link' disabled>经纪人管理</Button>
            <Button type='link' disabled>下架</Button>
          </>
        }
        <Link to={{ pathname: "/admin/house/manager/details", state: row }} style={{ marginRight: 10 }}>详情</Link>

      </>
    }
  ]

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        request={RentHouse}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6
        }}
        toolBarRender={() => [
          <Button
            type="primary"
            onClick={() => {
              props.history.push('/admin/house/manager/create')
            }}
          >发布房源</Button>
        ]}
        columns={columns}
      />
    </React.Fragment>
  )
}

export default withRouter(Activity)