import { ProList } from '@ant-design/pro-components';
import React from 'react';
import { Button, message, Space } from 'antd';
import { System_msg, System_msgList } from '../../services/message';
import type { ActionType } from '@ant-design/pro-table'
import { useEffect, useState } from 'react';

const SystemMessage = (props) => {
    const [selectedRowKeys, setSelectedRowKeys]: any = useState([]);
    const [dataSource, setdataSource]: any = useState([]);
    const [loading, setloading] = useState(true);
    const ref = React.useRef<ActionType>() as any
    const rowSelection = {
        selectedRowKeys,
        onChange: (keys, val, type) => setSelectedRowKeys(keys),
        preserveSelectedRowKeys: false,
        alwaysShowAlert: true,
    };
    useEffect(() => {
        getDataList(1, 10);
    }, [])

    const getDataList = async (page, page_size) => {
        const { data } = await System_msgList({ page, page_size });
        setdataSource(data);
        setloading(false)
    }
    const setMessage = async (id, flag = false, code: any = "") => {
        await System_msg({ id });
        if (flag) {
            message.success("设置成功");
            window.location.reload();
        } else {
            switch (code) {
                case "1":
                    window.location.href = '/admin/owner/examine'
                    break;
                case "2":
                    window.location.href = '/admin/fix/online'
                    break;
                case "3":
                    window.location.href = '/admin/fix/dealt'
                    break;
                case "4":
                    window.location.href = '/admin/complaint/new'
                    break;
                case "5":
                    window.location.href = '/admin/complaint/handle'
                    break;
                case "6":
                    window.location.href = '/admin/house/manager'
                    break;
                case "7":
                    window.location.href = '/admin/house/appointment'
                    break;
                case "8":
                    window.location.href = 'admin/device/door/facemanager'
                    break;
                default:
                    console.log("打错了")
                    break;
            }
        }
    }

    return (
        <ProList<{ title: string }>
            actionRef={ref}
            pagination={{
                defaultPageSize: 10,
                onChange: (page, pageSize) => {
                    getDataList(page, pageSize)
                }
            }}
            loading={loading}
            toolBarRender={() => {
                return [
                    <Button key="add" type="primary" onClick={() => {
                        if (selectedRowKeys.length > 0) {
                            setMessage(selectedRowKeys, true)
                        } else {
                            message.info("请选择要设置的消息")
                        }

                    }}>
                        设置消息已读
                    </Button>,
                ];
            }}
            metas={{
                title: { dataIndex: 'content', },
                content: {
                    dataIndex: 'created_at',
                    render: (text) => <div style={{ textAlign: "right" }}>{text}</div>
                },
                // description: {dataIndex: 'created_at',},
                actions: {
                    render: (text, row: any) => {
                        return [<Button type='link' key="init" onClick={() => {
                            setMessage([row.id], false, row.code)
                        }}>查看</Button>];
                    },
                },
            }}
            rowKey="id"
            headerTitle="未读消息"
            rowSelection={rowSelection}
            tableAlertRender={({ selectedRowKeys, selectedRows, onCleanSelected }) => {
                return (
                    <Space size={24}>
                        <span>
                            已选 {selectedRowKeys.length} 项
                        </span>
                        <a style={{ marginInlineStart: 8 }} onClick={() => {
                            let allKeys = dataSource.map(item => item.id)
                            setSelectedRowKeys(allKeys)
                        }}>
                            全选
                        </a>
                    </Space>
                )
            }}
            dataSource={dataSource}
        />
    );
};


export default SystemMessage