import React, { useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Image, Input, message } from 'antd'
import { withRouter } from 'react-router-dom'
import { GetHouseholdApproveList, HouseholdApprove } from '../../services/household'
import { APPROVE_STATUS, id_type, user_type } from '../../CONSTANT'
import './index.scss'

const OwnerList: React.FC = (props: any) => {
  const [form] = Form.useForm()
  // @ts-ignore
  const columns: any = [
    {
      title: '姓名',
      dataIndex: 'name',
      search: true
    },
    {
      title: '联系电话',
      dataIndex: 'phone',
      search: false,
    },
    {
      title: '住户身份',
      dataIndex: 'user_type',
      valueEnum: user_type,
    },
    {
      title: '证件类型',
      dataIndex: 'id_type',
      valueEnum: id_type,
      search: false,
    },
    {
      title: '证件号码',
      dataIndex: 'id_number',
      search: false,
    },
    {
      title: '房号',
      dataIndex: 'house_name',
      search: false,
    },
    {
      title: '附件',
      dataIndex: 'appendix',
      search: false,
      render: (_, row) => <>
        {row.appendix[0] ?
          <Image key={row.appendix[0]}
            src={row.appendix[0]}
            style={{ width: "50px", height: "50px" }}
          ></Image> : null
        }
        {row.appendix.length > 1 ? <Button type='link' onClick={() => showModal(row.appendix)}>更多</Button> : null}
      </>
    },
    {
      title: '认证状态',
      dataIndex: 'approve_status',
      search: true,
      valueType: "select",
      valueEnum: APPROVE_STATUS,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      align: 'center',
      render: (_, row, index, action) => <>
        {row.approve_status == 1 ? <Button type='link' onClick={() => {
          controlMoadl(row.id, true)
          form.setFieldsValue(row)
        }}>审核</Button>
          : <Button type='link' disabled>审核</Button>
        }
      </>
    }
  ]
  const [state, setState]: any = React.useState({
    visible: false,
    id: null
  })
  const controlMoadl = (id, visible) => {
    setState(pre => ({ ...pre, visible, id }))
    form.resetFields()
  }
  const footer = <div className='footerButton'>
    <Button style={{ backgroundColor: "red", color: "#fff" }} onClick={() => checkPass(false)}>不通过</Button>
    <Button type='primary' onClick={() => checkPass(true)}>通过</Button>
  </div>
  const checkPass = (status) => {
    form.validateFields().then(async (values) => {
      const { id } = state
      await HouseholdApprove({ ...values, id, status })
      message.success("操作成功")
      controlMoadl(null, false)
      actionRef.current?.reload()
    })
  }
  const actionRef = React.useRef<ActionType>();
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [appendixPic, setappendixPix] = useState([]);
  const showModal = (appendix) => {
    setIsModalOpen(true);
    setappendixPix(appendix)
  };

  const handleOk = () => {
    setIsModalOpen(false);
  };

  const handleCancel = () => {
    setIsModalOpen(false);
  };
  const ownerInfo = [
    { label: "姓名", name: "name" },
    { label: "联系电话", name: "phone" },
    { label: "业主身份", name: "user_type" },
    { label: "证件类型", name: "id_type" },
    { label: "证件号码", name: "id_number" },
    { label: "房号", name: "house_name" }
  ]
  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        request={GetHouseholdApproveList}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6
        }}
        columns={columns}
      />
      <Modal
        visible={state.visible}
        forceRender
        title='业主认证'
        footer={footer}
        maskClosable={false}
        onCancel={() => controlMoadl(null, false)}
      >
        <Form
          form={form}
          labelCol={{ span: 4 }}
        >
          {ownerInfo.map(item => {
            if (item.name == "user_type") {
              return <Form.Item label={item.label} key={item.label}>
                <span>{user_type[form.getFieldValue(item.name)]}</span>
              </Form.Item>
            } else if (item.name == "id_type") {
              return <Form.Item label={item.label} key={item.label}>
                <span>{id_type[form.getFieldValue(item.name)]}</span>
              </Form.Item>
            } else {
              return <Form.Item label={item.label} key={item.label}>
                <span>{form.getFieldValue(item.name)}</span>
              </Form.Item>
            }
          })}
          <Form.Item label="附件">
            {form.getFieldValue('appendix') ? form.getFieldValue('appendix').map(item => {
              return <Image src={item} key={item} style={{ width: "100px", height: "100px", margin: "10px" }} />
            }) : ''}
          </Form.Item>
          <Form.Item label='审核意见' name='feedback' rules={[{ required: true, message: "请输入审核意见" }]}>
            <Input.TextArea />
          </Form.Item>
        </Form>
      </Modal>
      <Modal title="附件详情" open={isModalOpen} onOk={handleOk} onCancel={handleCancel}>
        {appendixPic.map(item => <Image key={item}
          src={item}
          style={{ width: "100px", height: "100px", margin: "10px 20px" }}
        />)}
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(OwnerList)
