import React, { useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Link, withRouter } from 'react-router-dom'
import { GetHouseholdApproveList } from '../../services/household'
import { Button, Image, Modal } from 'antd'
import { APPROVE_STATUS, id_type, user_type } from '../../CONSTANT'

const OwnerList: React.FC = (props: any) => {
  // @ts-ignore
  const columns: any = [
    {
      title: '姓名',
      dataIndex: 'name',
      search: true
    },
    {
      title: '联系电话',
      dataIndex: 'phone',
      search: false,
    },
    {
      title: '住户身份',
      dataIndex: 'user_type',
      valueEnum: user_type,
    },
    {
      title: '证件类型',
      dataIndex: 'id_type',
      valueEnum: id_type,
      search: false,
    },
    {
      title: '证件号码',
      dataIndex: 'id_number',
      search: false,
    },
    {
      title: '房号',
      dataIndex: 'house_name',
      search: false,
    },
    {
      title: '附件',
      dataIndex: 'appendix',
      search: false,
      render: (_, row) => <>
        {row.appendix[0] ?
          <Image key={row.appendix[0]}
            src={row.appendix[0]}
            style={{ width: "50px", height: "50px" }}
          ></Image> : null
        }
        {row.appendix.length > 1 ? <Button type='link' onClick={() => showModal(row.appendix)}>更多</Button> : null}
      </>
    },
    {
      title: '认证状态',
      dataIndex: 'approve_status',
      hideInForm: true,
      search: false,
      valueEnum: APPROVE_STATUS,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      align: 'center',
      render: (_, row, index, action) => <>
        <Link to={{ pathname: "/admin/owner/info/houseinfo", state: row.uid }}>
          <Button type='link'>房屋</Button>
        </Link>
        <Link to={{ pathname: "/admin/owner/info/carinfo", state: row.uid }}>
          <Button type='link'>车辆</Button>
        </Link>
      </>
    }
  ]



  const actionRef = React.useRef<ActionType>();
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [appendixPic, setappendixPix] = useState([]);
  const showModal = (appendix) => {
    setIsModalOpen(true);
    setappendixPix(appendix)
  };

  const handleOk = () => {
    setIsModalOpen(false);
  };

  const handleCancel = () => {
    setIsModalOpen(false);
  };
  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey='id'
        request={GetHouseholdApproveList}
        params={{ approve_status: 2 }}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6
        }}
        columns={columns}
      />
      <Modal title="附件详情" open={isModalOpen} onOk={handleOk} onCancel={handleCancel}>
        {appendixPic.map(item => <Image key={item}
          src={item}
          style={{ width: "100px", height: "100px", margin: "10px 20px" }}
        />)}
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(OwnerList)
