import React, { useEffect, useState, } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Input, InputNumber, message, } from 'antd'
import { withRouter } from 'react-router-dom'
import { Car, Brand } from '../../services/parking'
import { SELECTOR_CAR_TYPE, SELECTOR_CAR_BIND_TYPE, VALUEENUM_CAR_TYPE } from '../../CONSTANT'
import { ParkingPosition } from '../../services/parking'
import { SearchOutlined } from '@ant-design/icons';
import { GetUser_list } from '../../services/user'
import './index.scss'

const { Option } = Select;
const ParkingCar: React.FC = (props: any) => {
  const columns: any = [
    {
      title: '车牌号',
      dataIndex: 'plate_no',
      search: true,
    },
    {
      title: '车牌类型',
      dataIndex: 'bind_type',
      search: false,
      valueType: 'select',
      hideInTable: true
    },
    {
      title: '车架号',
      dataIndex: 'vin',
      search: false,
      ellipsis: true,
    },
    {
      title: '车辆品牌',
      dataIndex: 'brand',
      search: false,
    },
    {
      title: '车辆类型',
      dataIndex: 'vehicle_type',
      valueType: 'select',
      search: false,
      valueEnum: VALUEENUM_CAR_TYPE
    },
    {
      title: '车身颜色',
      dataIndex: 'color',
      search: false,
    },
    {
      title: '车位',
      dataIndex: 'space_number',
      search: false,
      align: "center",
      render: (_, row) => row.park_number + "-" + row.space_number
    },
    {
      title: '车位绑定类型',
      dataIndex: 'bind_type',
      valueEnum: {
        1: { text: '无固定车位' },
        2: { text: '已出售车位' },
        3: { text: "租车位" }
      },
      search: false,
    },
    {
      title: '住户',
      dataIndex: 'household_name',
      width: 180,
      search: false,
      render: (_, row) => <div>{row.household_name}-{row.household_phone}</div>
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 200,
      align: 'center',
      render: (_, row, index, action) => <>
        <Button type='link' onClick={() => {
          if (row.space_id == 0) {
            form.setFieldsValue({ ...row, space_id: null })
          } else {
            form.setFieldsValue(row)
            setBind_type(row.bind_type)
          }
          setoptions([{ label: `${row.household_name}--${row.household_phone}`, value: row.household_uid }])
          sethousehold_uid(row.household_uid)
          setbind_space_id(row.space_id)
          setState(prevState => ({ ...prevState, visible: true, editId: row.id }))
        }}>编辑</Button>
        <Button type='link' onClick={() => {
          Modal.confirm({
            title: '删除记录',
            content: '你确定删除这条记录吗？',
            onOk: async () => {
              await Car({ method: 'delete', id: row.id })
              message.success('操作成功！')
              actionRef.current.reload()
            }
          })
        }}>删除</Button>
        <Button type='link' onClick={() => {
          const queryParams = `?obj_type=3&obj_id=${row.id}&name=${row.plate_no}`
          props.history.push('/admin/charge/car/bill' + queryParams)
        }}>费用</Button>
      </>
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    editId: null
  })
  const [parkingPosition, setParkingPosition] = useState([])
  const [bind_type, setBind_type] = useState(1)
  const [household_uid, sethousehold_uid] = useState()
  const [bind_space_id, setbind_space_id] = useState()
  const [carband, setcarband]: any = useState([]);

  useEffect(() => {
    if (bind_type == 2 || bind_type == 3) {
      ParkingPosition({ bind_type, household_uid, bind_space_id }).then(res => {
        const { data } = res
        setParkingPosition(data?.map(({ space_number, id, park_number }) =>
          ({ value: id, label: park_number + "-" + space_number })))
      })
    }
  }, [bind_type])

  useEffect(() => {
    Brand().then(res => {
      let newArr = res.data.shift();
      let strList = res.data.map(item => item.brand)
      strList.sort((a, b) => {
        return (a)
          .toLowerCase()
          .localeCompare((b).toLowerCase())
      });
      strList.unshift(newArr.brand)
      setcarband(strList)
    })
  }, [])

  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(async values => {
      await Car({
        ...values,
        method: state.editId ? 'put' : 'post',
        id: state.editId
      })
      message.success('操作成功！')
      form.resetFields()
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }
  const getvalue = (value) => {
    if (value) {
      form.setFieldsValue({ household_uid: value.value })
      sethousehold_uid(value.value)
    }
  }
  const [value, setValue]: any = useState([]);
  const [searchValue, setsearchValue] = useState("");
  const [options, setoptions]: any = useState([]);
  const fetchUserList = async (name) => {
    return GetUser_list({ name, page: -1, page_size: -1 }).then(res => res.data).then((body) =>
      body.map((user) => ({
        label: `${user.name}--${user.phone}`,
        value: user.id
      }))
    ).then((newOptions) => {
      setoptions(newOptions);
    });
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        request={Car}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6
        }}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setState(preState => ({ ...preState, visible: true }))
            }}
          >添加</Button>
        ]}
        columns={columns}
      />
      <Modal
        title={state.editId ? '编辑住户车辆' : '添加住户车辆'}
        visible={state.visible}
        maskClosable={false}
        width={550}
        onOk={onSubmit}
        onCancel={() => {
          setState(pre => ({ ...pre, visible: false, editId: null }))
          setBind_type(1)
        }}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='车牌号' name="plate_no" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='车辆类型' name="vehicle_type" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={SELECTOR_CAR_TYPE} />
          </Form.Item>
          <Form.Item label='车辆品牌' name="brand" rules={[{ required: true }]}>
            <Select
              allowClear
              showSearch
              placeholder="请选择车辆品牌"
            // optionFilterProp="children"
            //filterOption={(input, option) => (option!.children as unknown as string).includes(input)}
            // filterSort={(optionA, optionB) =>{
            // return  (optionA!.children as unknown as string)
            //   .toLowerCase()
            //   .localeCompare((optionB!.children as unknown as string).toLowerCase())
            // }
            // }
            >
              {carband.map(item => {
                return <Option value={item} key={item}>{item}</Option>
              })}
            </Select>
          </Form.Item>
          <Form.Item label='住户' name="household_uid" rules={[{ required: true }]}>
            {/* <App getValue={getvalue}  /> */}
            <Select
              allowClear={false}
              value={value}
              showSearch
              defaultOpen={false}
              filterOption={false}
              onSearch={(value) => setsearchValue(value)}
              onSelect={(value) => setsearchValue("")}
              suffixIcon={<SearchOutlined onClick={() => {
                fetchUserList(searchValue);
              }} />}
              placeholder="请输入住户姓名进行查询"
              onChange={(newValue) => {
                // props.getValue(newValue)
                setValue(newValue);
              }}
              options={options}
              style={{
                width: '100%',
              }}
            />
          </Form.Item>
          <Form.Item label='车位绑定类型' name="bind_type" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={SELECTOR_CAR_BIND_TYPE} onChange={value => {
              setBind_type(value)
            }} />
          </Form.Item>
          {bind_type == 1 ? null :
            <Form.Item label='车位' name="space_id" rules={[{ required: true }]}>
              <Select placeholder="请选择" options={parkingPosition} />
            </Form.Item>
          }
          <Form.Item label='车架号' name="vin">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='发动机号' name="engine_no">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='车身颜色' name="color">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label="排量单位" name="displacement_unit">
            <Select placeholder="请选择">
              <Select.Option value="l">L</Select.Option>
              <Select.Option value="t">T</Select.Option>
            </Select>
          </Form.Item>
          <Form.Item label='排量' name="displacement">
            <InputNumber placeholder="请输入" min={0} />
          </Form.Item>
          <Form.Item label='座位数' name="seat">
            <InputNumber placeholder="请输入" min={1} />
          </Form.Item>

        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ParkingCar)
