import React, { useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Input, message, InputNumber, Row } from 'antd'
import { withRouter } from 'react-router-dom'
import { ParkingPosition } from '../../services/parking'
import { SearchOutlined } from '@ant-design/icons';
import { BuildingHouse } from '../../services/building';
import { useParking } from "./hooks"
import './index.scss'

const ParkingPositionPage: React.FC = (props: any) => {
  const columns: any = [
    {
      title: '区域编号',
      dataIndex: 'park_number',
      search: false,
    },
    {
      title: '停车场',
      dataIndex: 'park_name',
      hideInTable: true,
      search: true,
      renderFormItem: (_, { type, defaultRender, formItemProps, fieldProps, ...rest }, form) => {
        if (type === 'form') {
          return null;
        }
        const status = form.getFieldValue('state');
        if (status !== 'open') {
          return (
            // value 和 onchange 会通过 form 自动注入。
            <Select placeholder="请选择" options={parking} />
          );
        }
        return defaultRender(_);
      }
    },
    {
      title: '车位编号',
      dataIndex: 'space_number',
      search: true,
    },
    {
      title: '车位类型',
      dataIndex: 'space_type',
      search: true,
      valueEnum: {
        1: { text: '普通车位' },
        2: { text: '子母车位' },
        3: { text: '豪华车位' },
      }
    },
    {
      title: '面积',
      dataIndex: 'space_area',
      search: false,
    },
    {
      title: '车位状态',
      dataIndex: 'status',
      search: false,
      valueEnum: {
        1: { text: '空闲' },
        2: { text: '出售' },
        3: "已租"
      }
    },
    {
      title: '房屋/车辆',
      dataIndex: 'house_name',
      search: false,
      align:"center",
      render: (_, row) => <>
        {[1, 3].includes(row.status) ? <>{row.plate_no==""?"--":row.plate_no}</> : row.house_name}
      </>
    },
    {
      title: '创建时间',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 250,
      align: 'center',
      render: (_, row, index, action) => <>
        <Button type='link' onClick={() => {
          form.setFieldsValue(row)
          if (row.house_id == 0) {
            setoptions([])
            form.setFieldsValue({house_id:""})
          }else{
            setoptions([{ label: row.house_name, value: row.house_id }])
          }
          setState(prevState => ({ ...prevState, visible: true, editId: row.id }))
        }}>编辑</Button>
        <Button type='link' onClick={() => {
          Modal.confirm({
            title: '删除记录',
            content: '你确定删除这条记录吗？',
            onOk: async () => {
              await ParkingPosition({ method: 'delete', id: row.id })
              message.success('操作成功！')
              actionRef.current.reload()
            }
          })
        }}>删除</Button>
        {/* {row.status==1?<Button type='link' onClick={() => {
        }}>绑定车辆</Button>:<Button type='link' disabled>绑定车辆</Button>} */}
      </>
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    editId: null
  })
  const [parking, setParking] = useParking();
  React.useEffect(() => {
    setParking()
  }, [])

  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(async values => {
      const {house_id} = values;
      await ParkingPosition({
        ...values,
        method: state.editId ? 'put' : 'post',
        id: state.editId,
        house_id:house_id?house_id:0
      })
      message.success('操作成功！')
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }
  const [value, setValue]: any = useState([]);
  const [searchValue, setsearchValue] = useState("");
  const [options, setoptions]: any = useState([]);
  const fetchUserList = async (house_name) => {
    return BuildingHouse({ house_name, page: -1, page_size: -1 }).then(res => res.data).then((body) =>
      body.map((user) => ({
        label: `${user.house_name}`,
        value: user.id
      }))
    ).then((newOptions) => {
      setoptions(newOptions);
    });
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        request={ParkingPosition}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6
        }}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setoptions([])
              setState(preState => ({ visible: true, editId: null }))
            }}
          >添加</Button>
        ]}
        columns={columns}
      />
      <Modal
        title={state.editId ? "编辑停车位" : "添加停车位"}
        visible={state.visible}
        maskClosable={false}
        width={500}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='区域' name="park_id" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={parking} />
          </Form.Item>
          <Form.Item label='车位编码' name="space_number" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='车位类型' name="space_type" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={[
              { label: '普通车位', value: 1 },
              { label: '子母车位', value: 2 },
              { label: '豪华车位', value: 3 }
            ]} />
          </Form.Item>
          <Form.Item label='面积' name="space_area" rules={[{ required: true }]}>
            <InputNumber placeholder="请输入" />
          </Form.Item>
          <Form.Item label='绑定房屋' name="house_id">
            {/* <SearchHouse getValue={getvalue} /> */}
            <Select
              allowClear={false}
              value={value}
              showSearch
              defaultOpen={false}
              filterOption={false}
              onSearch={(value) => setsearchValue(value)}
              onSelect={(value) => setsearchValue("")}
              suffixIcon={<SearchOutlined onClick={() => {
                fetchUserList(searchValue)
              }} />}
              placeholder="请输入房屋号进行查询"
              onChange={(newValue) => {
                setValue(newValue)
              }}
              options={options}
              style={{
                width: '100%',
              }} />
          </Form.Item><Form.Item label="注">
            <span>绑定房屋后代表车位已出售给该房业主</span>
          </Form.Item>
          <Form.Item label='备注' name="comment">
            <Input.TextArea rows={4} placeholder="请输入" />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ParkingPositionPage)