import { Select, Spin } from 'antd';
import debounce from 'lodash/debounce';
import { useMemo, useRef, useState } from 'react';
import { BuildingHouse } from '../../services/building';

function DebounceSelect({ fetchOptions, debounceTimeout = 1000, ...props }) {
  const [fetching, setFetching] = useState(false);
  const [options, setOptions] = useState([]);
  const fetchRef = useRef(0);
  const debounceFetcher = useMemo(() => {
    const loadOptions = (value) => {
      fetchRef.current += 1;
      const fetchId = fetchRef.current;
      setOptions([]);
      setFetching(true);
      fetchOptions(value).then((newOptions) => {
        if (fetchId !== fetchRef.current) {
          // for fetch callback order
          return;
        }
        setOptions(newOptions);
        setFetching(false);
      });
    };

    return debounce(loadOptions, debounceTimeout);
  }, [fetchOptions, debounceTimeout]);
  return (
    <Select
      labelInValue
      filterOption={false}
      onSearch={debounceFetcher}
      notFoundContent={fetching ? <Spin /> : "暂无数据"}
      {...props}
      options={options}
    />
  );
} // Usage of DebounceSelect

async function fetchUserList(house_name) {
  return BuildingHouse({ house_name })
  .then(res => res.data).then((body) =>
  body.map((user) => ({
    label: user.house_name,
    value: user.id
  }))
).catch(res => {
    console.log(res);
    return
  })
}

const SearchHouse = (props) => {
  const [value, setValue] = useState([]);
  return (
    <DebounceSelect
      mode={props.mode ? "multiple" : ''}
      allowClear={props.mode ? false : true}
      value={value}
      showSearch
      placeholder="请输入房屋号进行查询"
      fetchOptions={fetchUserList}
      onChange={(newValue) => {
        props.getValue(newValue)
        setValue(newValue);
      }}
      style={{
        width: '100%',
      }}
    />
  );
};

export default SearchHouse;