import { FormItemProvide } from "@ant-design/pro-form";
import { Button, Card, Form, Input, message } from "antd";
import React, { useEffect } from "react";
import { useHistory } from "react-router";
import { Notice } from "../../../services/service/notice";
import Draft from "./draft";


const AddNotice = (props) => {
    const history = useHistory();
    const [form] = Form.useForm();
    const { state } = props
    const addNotice = () => {
        form.validateFields().then(async (values) => {
            await Notice({
                method: state ? "put" : "post",
                ...values,
                id:state?state.id:null
            })
            message.success("操作成功")
            history.goBack()
        })
    }
    const getContent = (value) => {
        form.setFieldsValue({ content: value })
    }
    useEffect(() => {
        form.setFieldsValue(state)
    }, [state])
    return <>
        <Card
            title={state ? "编辑公告" : "发布新公告"}
            extra={<Button type="primary" onClick={history.goBack}>返回</Button>}
        >
            <Form
                form={form}
                labelCol={{ span: 2 }}
                labelAlign="left"
            >
                <Form.Item label="标题" name="title"
                    wrapperCol={{ span: 8 }}
                    rules={[{ required: true, message: "请输入公告标题" }]}>
                    <Input placeholder="请输入公告标题" />
                </Form.Item>
                <Form.Item label="公告内容" name="content" rules={[{ required: true, message: "请输入公告内容" }]}>
                    <Draft getContent={getContent} content={state ? state.content : null} />
                </Form.Item>
            </Form>
            <div style={{ display: 'flex', justifyContent: 'end' }}>
                <Button type="primary" danger style={{ marginRight: '20px' }}
                    onClick={history.goBack}
                >取消</Button>
                <Button type="primary"
                    onClick={addNotice}
                >{state ? "修改" : "发布"}</Button>
            </div>
        </Card>
    </>
}

export default AddNotice