import React, { useEffect } from "react";
import { Card, Form, Input, Button, message, InputNumber, DatePicker } from "antd";
import { useHistory } from "react-router";
import Draft from "../announcement/draft";
import { Event } from "../../../services/service/event";
import Uploadpic from "../../../utils/handlePreview";
import moment from 'moment';
import { transitionSecond } from "../../../utils/utils";

const AddEvent = (props) => {
    const history = useHistory();
    const [form] = Form.useForm();
    const { state } = props;
    const [pic, setPic]: any = React.useState([])
    const { RangePicker } = DatePicker

    const addEvent = () => {
        form.validateFields().then(async (values) => {
            console.log(values);
            const sign_up_end = transitionSecond(values.sign_up_end)
            const start = transitionSecond(values.time[0])
            const end = transitionSecond(values.time[1])
            const fee = values.fee*100
            await Event({
                method: state ? "put" : "post",
                ...values,
                id: state ? state.id : null,
                sign_up_end,
                start,
                end,
                fee
            })
            message.success("操作成功")
            history.goBack()
        })
    }
    useEffect(() => {
        if (state) {
            if (state.pic[0] !== '') {
                setPic(state.pic)
                form.setFieldsValue({
                    pic:state.pic
                })
            }
            const sign_up_end = moment(state.sign_up_end * 1000)
            const time = [moment(state.start * 1000), moment(state.end * 1000)]
            form.setFieldsValue({
                addr: state.addr,
                fee: state.fee,
                people_limit: state.people_limit,
                title: state.title,
                sign_up_end,
                time
            })
        }
    }, [state])

    const getContent = (value) => {
        form.setFieldsValue({ content: value })
    }
    const garden_pic = (arr) => {
        form.setFieldsValue({ pic: arr })
    }
    const disabledDate = (current) => {
        return current && current < moment().endOf('day');
    }
    return <>
        <Card
            title={state ? "编辑活动" : "发布新活动"}
            extra={<Button type="primary" onClick={history.goBack}>返回</Button>}
        >
            <Form
                form={form}
                labelCol={{ span: 3 }}
                labelAlign="left"
            >
                <Form.Item label="活动名称" name="title"
                    wrapperCol={{ span: 8 }}
                    rules={[{ required: true, message: "请输入活动名称" }]}>
                    <Input placeholder="请输入活动" />
                </Form.Item>
                <Form.Item label="内容内容" name="content" rules={[{ required: true, message: "请输入公告内容" }]}>
                    <Draft getContent={getContent} content={state ? state.content : null} />
                </Form.Item>
                <Form.Item label="上传图片" name="pic"
                    extra={<span>图片的宽度建议为：640px，高度建议为：238px。最多上传5张   </span>}
                >
                    <Uploadpic getSrc={garden_pic} src={pic} maxCount={5} />
                </Form.Item>
                <Form.Item label="活动时间" name='time'
                    wrapperCol={{ span: 9 }}
                    rules={[{ required: true, message: "请选择活动时间" }]}>
                    <RangePicker disabledDate={disabledDate} showTime/>
                </Form.Item>
                <Form.Item label="报名结束时间" name="sign_up_end"
                    wrapperCol={{ span: 5 }}
                    rules={[{ required: true, message: "请选择报名结束时间" }]}>
                    <DatePicker disabledDate={disabledDate} showTime />
                </Form.Item>
                <Form.Item label="人数限制" name="people_limit"
                    wrapperCol={{ span: 8 }}
                    rules={[{ required: true, message: "请输入活动报名人数" }]}>
                    <InputNumber min={1} />
                </Form.Item>
                <Form.Item label="报名费用" name="fee"
                    wrapperCol={{ span: 8 }}
                    rules={[{ required: true, message: "请输入报名费用" }]}>
                    <InputNumber min={0} />
                </Form.Item>
                <Form.Item label="活动地址" name="addr"
                    wrapperCol={{ span: 8 }}
                    rules={[{ required: true, message: "请输入活动地址" }]}>
                    <Input placeholder="请输入活动地址" />
                </Form.Item>
            </Form>
            <div style={{ display: 'flex', justifyContent: 'end' }}>
                <Button type="primary" danger style={{ marginRight: '20px' }}
                    onClick={history.goBack}
                >取消</Button>
                <Button type="primary"
                    onClick={addEvent}
                >{state ? "修改" : "发布"}</Button>
            </div>
        </Card>
    </>
}
export default AddEvent