import React, { useEffect } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Image, Card, Radio, Input, message } from 'antd'
import { Link, withRouter } from 'react-router-dom'
import Uploadpic from '../../../utils/handlePreview'
import { NeighborClass } from '../../../services/service/neighbor'
import '../index.scss'


const Neighbor: React.FC = (props: any) => {
  // @ts-ignore
  const columns: any = [
    {
      title: '分类名称',
      dataIndex: 'class_name'
    },
    {
      title: '分类图标',
      dataIndex: 'class_pic',
      search: false,
      render:(_,row)=><Image src={row.class_pic} style={{width:"100px",height:"100px"}} />
    },
    {
      title: '文章总数',
      dataIndex: 'article_count',
      search: false
    },
    {
      title: '状态',
      dataIndex: 'enable',
      search: false,
      valueEnum: {
        false: {
          text: '关闭',
          status: 'Processing',
        },
        true: {
          text: '开启',
          status: 'Success',
        },
      },
    },
    {
      title: '创建时间',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '更新时间',
      dataIndex: 'updated_at',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 210,
      align: 'center',
      render: (_, row, index, action) => <>
        <Button type='link' onClick={() => editClass(row)}>修改</Button>
        <Button type='link' onClick={()=>deleteClass(row.id)}>删除</Button>
        <Link to={{pathname:"/admin/service/neighbor/page-list",state:row.id}}>
        <Button type='link'>文章列表</Button>
        </Link>
      </>
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    id: null
  })
  const actionRef = React.useRef<ActionType>();
  const [pic, setPic]: any = React.useState([])
  const [form] = Form.useForm()
  const radioValue = [
    { label: "开启", value: true },
    { label: "关闭", value: false }
  ]

  const controlModal = (flag) => {
    setState(pre => ({ ...pre, visible: flag,id:null}))
    form.resetFields()
    setPic([])
  }
  const garden_pic = (arr) => {
    form.setFieldsValue({class_pic : arr[0] })
  }
  const addClass = () =>{
    form.validateFields().then(async (values)=>{
      await NeighborClass({
        method:state.id?"put":"post",
        ...values,
        id:state.id
      })
      message.success("操作成功")
      actionRef.current?.reload()
      controlModal(false)
    })
  }
  const editClass = (row) =>{
    setPic([row.class_pic])
    setState(pre => ({ ...pre, visible: true ,id:row.id}))
    form.setFieldsValue(row)
  }
  const deleteClass = (id) =>{
    Modal.confirm({
      title: "删除分类",
      content: "你确定删除这条记录吗？",
      onOk: async () => {
        await NeighborClass({ method: "delete", id });
        message.success("操作成功！");
        actionRef.current?.reload()
      }
    });
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6, labelWidth: 'auto'
        }}
        request={NeighborClass}
        toolBarRender={() => [
          <Button type='primary' onClick={() => controlModal(true)}>添加分类</Button>
        ]}
        columns={columns}
      />
      <Modal
        title={state.id ? "编辑分类" : "添加分类"}
        visible={state.visible}
        maskClosable={false}
        okText="保存"
        onCancel={() => controlModal(false)}
        onOk={addClass}
      >
        <Form
          form={form}
          wrapperCol={{ span: 8 }}
        >
          <Form.Item label="分类名称" name="class_name" rules={[{required:true,message:"请输入分类名称"}]}>
            <Input placeholder='请输入分类名称' />
          </Form.Item>
          <Form.Item label="分类图标" name="class_pic" rules={[{required:true,message:"请上传分类图标"}]}>
            <Uploadpic getSrc={garden_pic} src={pic} maxCount={1}/>
          </Form.Item>
          <Form.Item label="分类状态" name="enable" rules={[{required:true,message:"请选择分类状态"}]}>
            <Radio.Group options={radioValue} />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(Neighbor)