import React, { useState } from "react";
import ProTable from "@ant-design/pro-table";
import type { ActionType } from '@ant-design/pro-table'
import { Service_phoneClass } from "../../../services/service/phone";
import { Button, Modal, Form, Input, Radio, message } from "antd";
import { ENABLE } from "../../../CONSTANT";
import history from "../../../utils/hisitory";

const PhoneClass = () => {
    const actionRef = React.useRef<ActionType>();
    const [form] = Form.useForm();
    const [state, setState] = useState({
        visible: false,
        id: null
    })
    const columns: any = [
        { title: "分类", dataIndex: "class_name", align: "center" },
        {
            title: "状态", dataIndex: "enable", align: "center",
            valueEnum:ENABLE
        },
        {
            title: "操作",
            dataIndex: "option",
            align: "center",
            render: (_, row) => <>
                <Button type="link" onClick={()=>{
                    controlModal(true)
                    form.setFieldsValue(row)
                    setState(pre=>({...pre,id:row.id}))
                }}>修改</Button>
                <Button type="link" onClick={()=>deleteClass(row.id)}>删除</Button>
            </>
        }
    ]
    const rules = [{ required: true }]
    const controlModal = (flag) => {
        setState(pre => ({ ...pre, visible: flag }))
    }
    const submitClass = () => {
        form.validateFields().then(async (values) => {
            console.log(values);
            await Service_phoneClass({
                method: state.id ? "put" : "post",
                ...values,
                id: state.id
            })
            await message.success("操作成功")
            actionRef.current?.reload()
            controlModal(false)
        })
    }
    const deleteClass =(id) =>{
        Modal.confirm({
            title: "删除分类",
            content: "你确定删除这条分类记录吗？",
            onOk: async () => {
              await Service_phoneClass({ method: "delete", id });
              message.success("操作成功！");
              actionRef.current?.reload()
            }
          });
    }
    return <>
        <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={Service_phoneClass}
            search={false}
            toolBarRender={() => [
                <>
                <Button type="primary" onClick={() => {
                    controlModal(true)
                    form.resetFields()
                }}>添加分类</Button>
                 <Button type="primary" onClick={history.goBack}>返回</Button>
                </>
            ]}
            columns={columns}
        />
        <Modal
            title={state.id ? "修改分类" : "添加分类"}
            visible={state.visible}
            width="400px"
            onCancel={() => controlModal(false)}
            maskClosable={false}
            okText="保存"
            onOk={submitClass}
        >
            <Form
                form={form}
            >
                <Form.Item label="名称" name="class_name" rules={rules}>
                    <Input placeholder="请输入名称" />
                </Form.Item>
                <Form.Item label="状态" name="enable" rules={rules}>
                    <Radio.Group>
                        <Radio value={true} >开启</Radio>
                        <Radio value={false}>关闭</Radio>
                    </Radio.Group>
                </Form.Item>
            </Form>
        </Modal>
    </>
}
export default PhoneClass