import React, { useEffect, useState } from "react";
import ProTable from "@ant-design/pro-table";
import type { ActionType } from '@ant-design/pro-table'
import { Service_phone, Service_phoneClass } from "../../../services/service/phone";
import { Link } from "react-router-dom";
import { Button, Form, Input, message, Modal, Radio, Select } from "antd";
import { ENABLE } from "../../../CONSTANT";

const Phone = () => {
    const actionRef = React.useRef<ActionType>();
    const [classList, setClassList] = useState({});
    const [data, setDate] = useState([])
    const [form] = Form.useForm();
    const [state, setState] = useState({
        visible: false,
        id: null
    })
    const columns: any = [
        {
            title: "分类",
            align: "center",
            search: false,
            dataIndex: "class_name"
        },
        {
            title: "分类名",
            align: "center",
            hideInTable: true,
            //formItemProps: { label: '分类名' },
            dataIndex: "class_id",
            valueEnum: classList
        },
        {
            title: "姓名",
            align: "center",
            search: false,
            dataIndex: "name"
        },
        {
            title: "电话",
            align: "center",
            search: false,
            dataIndex: "phone"
        },
        {
            title: "状态",
            align: "center",
            search: false,
            dataIndex: "enable",
            valueEnum: ENABLE
        },
        {
            title: "操作",
            align: "center",
            search: false,
            dataIndex: "option",
            render: (_, row) => <>
                <Button type="link" onClick={() => {
                    controlModal(true)
                    form.setFieldsValue(row)
                    setState(pre => ({ ...pre, id: row.id }))
                }}>修改</Button>
                <Button type="link" onClick={()=>deletePhone(row.id)}>删除</Button>
            </>
        }
    ]
    const rules = [{ required: true }]

    useEffect(() => {
        Service_phoneClass({ page: 1, page_size: 9999 }).then(res => {
            let object = {}
            const result = res.data.map(item => {
                object[item.id] = { text: item.class_name }
                return { label: item.class_name, value: item.id }
            })
            setDate(result)
            setClassList(object)
        })
    }, [])
    const controlModal = (flag) => {
        setState(pre => ({ ...pre, visible: flag }))
    }
    const submitPhone = () => {
        form.validateFields().then(async (values) => {
            await Service_phone({
                method: state.id ? "put" : "post",
                ...values,
                id: state.id
            })
            message.success("操作成功")
            actionRef.current?.reload()
            controlModal(false)
        })
    }
    const deletePhone = (id) => {
        Modal.confirm({
            title: "删除电话",
            content: "你确定删除这条服务电话吗？",
            onOk: async () => {
                await Service_phone({ method: "delete", id });
                message.success("操作成功！");
                actionRef.current?.reload()
            }
        });
    }
    return <>
        <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={Service_phone}
            toolBarRender={() => [
                <>
                    <Link to="/admin/service/phone/class">
                        <Button type="primary">分类管理</Button>
                    </Link>
                    <Button type="primary" onClick={() => {
                        controlModal(true)
                        form.resetFields()
                    }}>添加电话</Button>
                </>
            ]}
            columns={columns}
        />
        <Modal
            title={state.id ? "修改服务电话" : "添加服务电话"}
            visible={state.visible}
            width="400px"
            onCancel={() => controlModal(false)}
            maskClosable={false}
            okText="保存"
            onOk={submitPhone}
        >
            <Form
                form={form}
            >
               {state.id?null: <Form.Item label="分类" name="class_id" rules={rules}>
                    <Select options={data}></Select>
                </Form.Item>}
                <Form.Item label="名称" name="name" rules={rules}>
                    <Input placeholder="请输入名称" />
                </Form.Item>
                <Form.Item label="电话" name="phone" rules={[
                    {
                        required: true,
                        message: '请输入手机号！',
                    },
                    {
                        pattern: /^1\d{10}$/,
                        message: '手机号格式错误！',
                    },
                ]} >
                    <Input placeholder="请输入电话" />
                </Form.Item>
                <Form.Item label="状态" name="enable" rules={rules}>
                    <Radio.Group>
                        <Radio value={true} >开启</Radio>
                        <Radio value={false}>关闭</Radio>
                    </Radio.Group>
                </Form.Item>
            </Form>
        </Modal>
    </>
}
export default Phone