import React from "react";
import ProTable from "@ant-design/pro-table";
import type { ActionType } from '@ant-design/pro-table'
import { Button, Modal, message } from "antd";
import { Vote } from "../../../services/service/vote";
import { getLocalTime } from "../../../utils/utils";
import { Link } from "react-router-dom";

const VoteList = () => {
    const actionRef = React.useRef<ActionType>();

    const columns: any = [
        {
            title: "标题",
            dataIndex: "title"
        },
        {
            title: "开始时间",
            dataIndex: "start",
            search: false,
            render: (_, row) => <span>{getLocalTime(row.start)}</span>
        },
        {
            title: "结束时间",
            dataIndex: "end",
            search: false,
            render: (_, row) => <span>{getLocalTime(row.end)}</span>
        },
        {
            title: "参与人次",
            dataIndex: "user_count",
            search: false
        },
        {
            title: "操作",
            dataIndex: "option",
            search: false,
            render: (_, row) => <>
                <Link to={{ pathname: "/admin/service/vote/detailvote", state: row }}>
                    <Button type="link">详情</Button>
                </Link >
                <Link to={{ pathname: "/admin/service/vote/editvote", state: row }}>
                    <Button type="link">修改</Button>
                </Link>
                <Button type="link" onClick={() => deleteVote(row.id)}>删除</Button>
                <Link to={{ pathname: "/admin/service/vote/voteresult", state: row.id }}>
                <Button type="link">投票结果</Button>
                </Link>
            </>
        }
    ]
    const deleteVote = (id) => {
        Modal.confirm({
            title: "删除投票",
            content: "你确定删除这条投票记录吗？",
            onOk: async () => {
                await Vote({ method: "delete", id });
                message.success("操作成功！");
                actionRef.current?.reload()
            }
        });
    }

    return <>
        <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={Vote}
            toolBarRender={() => [
                <Link to="/admin/service/vote/addvote">
                    <Button type="primary">添加投票</Button>
                </Link>
            ]}
            columns={columns}
        />
    </>
}

export default VoteList