import React from "react";
import { useHistory } from "react-router";
import ProTable from "@ant-design/pro-table";
import type { ActionType } from '@ant-design/pro-table'
import { Button, Rate, Row, Progress } from "antd";
import { VoteStatistic } from "../../../services/service/vote";
import { TOPIC_TYPE } from "../../../CONSTANT";
import "./vote.scss"
import { Link } from "react-router-dom";

const VoteResult = () => {
    const history = useHistory();
    const location = history.location
    const id: any = location.state;
    const actionRef = React.useRef<ActionType>();
    const columns: any = [
        {
            title: "题目名称",
            dataIndex: "topic_name",
            ellipsis: true
        },
        {
            title: "题目类型",
            dataIndex: "topic_type",
            align: "center",
            valueEnum: TOPIC_TYPE
        },
        {
            title: "结果统计",
            render: (_, row) => <>
                {row.topic_type == 4 ? <>
                    <Rate defaultValue={row.star_avg} disabled />
                    <span style={{ color: "#ffcc00" }}>{row.star_avg.toFixed(1)}</span>
                </> : ''}
                {[2, 3].includes(row.topic_type) ? <>
                    {row.choice_items.map((item, index) => {
                        let total = getTotal(row.choice_statistic)
                        let count = 0;
                        row.choice_statistic.map(key => {
                            if (item.flag == key.flag) {
                                count = count + key.count
                            }
                        })
                        let percent: any = (count / total * 100).toFixed(2)
                        return <div key={index} style={{ width: 200 }}>
                            <span>{item.text}</span>
                            <Progress
                                percent={percent}
                                size="small"
                                strokeColor={{
                                    '0%': '#108ee9',
                                    '100%': '#87d068',
                                }}
                                status="normal"
                            />
                        </div>
                    })
                    }
                </> : ""}
            </>
        },
        {
            title: "详情",
            dataIndex: "option",
            align: "center",
            render: (_, row) => <Link to={{ pathname: "/admin/service/vote/voteresult/detail", state: { number: row.number, id } }}>
                <Button type="link">详情</Button>
            </Link>
        },
    ]
    const getTotal = (arr) => {
        let total = 0;
        arr.map(item => {
            total += item.count
        })
        return total
    }
    return <>
        <ProTable
            actionRef={actionRef}
            rowKey="uid"
            search={false}
            request={VoteStatistic}
            params={{ id }}
            toolBarRender={() => [
                <Button type="primary" onClick={history.goBack}>返回</Button>
            ]}
            columns={columns}
        />
    </>
}
export default VoteResult