import React, { FC, useEffect, useState } from 'react'
import { Form, Card, Image, Divider, Input, Upload, Button, message, InputNumber, Select, DatePicker } from 'antd'
import { connect } from 'react-redux'
import { UploadOutlined } from '@ant-design/icons'
import { getGardenList } from '../../redux/action/garden'
import Uploadpic from '../../utils/handlePreview'
import MapElement from './myMap'
import { GetGardenList } from '../../services/garden'
import moment from 'moment'
import { GetTimeStamp } from '../../utils/utils'
import "./index.scss"
const { RangePicker } = DatePicker;


const buildingTypes = [
  { label: "塔楼", value: 1 },
  { label: "板楼", value: 2 },
  { label: "塔板结合", value: 3 },
  { label: "其他", value: 4 }
]
const gardenInfo = [
  { label: "开发商", name: "building_company" },
  { label: "总户数", name: "house_total" },
  { label: "固定车位数", name: "space_total" },
  { label: "车位配比", name: "space_info" },
  { label: "容积率", name: "area_percent" },
  { label: "绿化率", name: "green_percent" },
  { label: "小区占地面积", name: "covered_area" },
  { label: "小区建筑面积", name: "building_area" },
]
const CompanyInfo = (props) => {
  const [form] = Form.useForm()
  const [pic, setPic]: any = React.useState([]);
  const [pics, setPics]: any = React.useState([])
  useEffect(() => {
    props.getGardenList()
  }, [])
  useEffect(() => {
    const { lnt, lat, garden_pics, garden_pic, avg_price, property_fee_start, property_fee_end,
      building_start,building_end,gas_fee_start,gas_fee_end,water_type,electric_type
    } = props.garden_info;  
    form.setFieldsValue(props.garden_info)
    form.setFieldsValue({ lntlat: { lnt, lat } })
    form.setFieldsValue({building_year:[moment(building_start*1000),moment(building_end*1000)]})
    form.setFieldsValue({ avg_price: avg_price / 100 });
    form.setFieldsValue({ property_fee_start: property_fee_start / 100 });
    form.setFieldsValue({ property_fee_end: property_fee_end / 100 });
    form.setFieldsValue({ gas_fee_start: gas_fee_start / 100 });
    form.setFieldsValue({ gas_fee_end: gas_fee_end / 100 });
    form.setFieldsValue({ water_type: water_type?water_type.map(item=>item+''):[]});
    form.setFieldsValue({ electric_type: electric_type?electric_type.map(item=>item+''):[]});
    setPic([garden_pic])
    if (garden_pics && garden_pics[0] !== '') {
      setPics(garden_pics)
    }
  }, [props.garden_info])

  const gardenForm = [
    { label: "物业联系人", name: "property_person" },
    { label: "物业联系人手机号", name: "property_phone" },
  ]
  const garden_pic = (arr) => {
    form.setFieldsValue({ garden_pic: arr[0] })
  }
  const garden_pics = (arr) => {
    form.setFieldsValue({ garden_pics: arr })
  }
  const mapAdress = (arr) => {
    form.setFieldsValue({ 'lntlat': arr })
  }
  const onSubmit = () => {
    form.validateFields().then(async (values) => {
      const { avg_price, property_fee_start, property_fee_end,
        lntlat: { lnt, lat },
        building_year,gas_fee_start,gas_fee_end,water_type,electric_type
      } = values;
      await GetGardenList({
        method: 'put',
        ...props.garden_info,
        ...values,
        lnt,
        lat,
        avg_price: avg_price ? avg_price * 100 : 0,
        property_fee_start: property_fee_start ? property_fee_start * 100 : 0,
        property_fee_end: property_fee_end ? property_fee_end * 100 : 0,
        building_start: building_year ? GetTimeStamp(moment(building_year[0]).format("YYYY")) : 0,
        building_end: building_year ? GetTimeStamp(moment(building_year[1]).format("YYYY")) : 0,
        gas_fee_start: gas_fee_start ? gas_fee_start * 100 : 0,
        gas_fee_end: gas_fee_end ? gas_fee_end * 100 : 0,
        water_type:water_type?water_type.map(item=>parseInt(item)):[],
        electric_type:electric_type?electric_type.map(item=>parseInt(item)):[]
      })
      message.success("更新成功")
    })
  }

  return (
    <Card>
      <div className='garden_info'>
        <Form
          form={form}
          labelCol={{ span: 7 }}
          labelAlign='left'
          wrapperCol={{ span: 10 }}
          initialValues={{ remember: true }}
        >
          <Form.Item label="小区名称">
            <span>{props.garden_info.garden_name}</span>
          </Form.Item>
          <Form.Item label="城市">
            <span style={{ marginRight: "10px" }}>{props.garden_info.province}</span>
            <span style={{ marginRight: "10px" }}>{props.garden_info.city}</span>
            <span>{props.garden_info.area}</span>
          </Form.Item>
          <Form.Item label="社区">
            <span style={{ marginRight: "10px" }}>{props.garden_info.street}</span>
            <span style={{ marginRight: "10px" }}>{props.garden_info.committee}</span>
          </Form.Item>
          {gardenForm.map(item => {
            return <Form.Item label={item.label} name={item.name} key={item.label} required>
              <Input></Input>
            </Form.Item>
          })}
          <Form.Item label="小区介绍" name="garden_desc" required>
            <Input.TextArea></Input.TextArea>
          </Form.Item>
          <Form.Item label="小区LOGO" name='garden_pic' required>
            <Uploadpic getSrc={garden_pic} src={pic} maxCount={1} />
          </Form.Item>
          <Form.Item label='请选择小区位置' wrapperCol={{ span: 18 }} name='lntlat' rules={[{ required: true, message: '请选择小区位置' }]}>
            <MapElement location={mapAdress} />
          </Form.Item>
          <Form.Item label="小区位置" wrapperCol={{ span: 18 }} name="garden_addr" required>
            <Input />
          </Form.Item>
        </Form>
        <Form form={form}
          labelCol={{ span: 6 }}
          labelAlign='left'
          wrapperCol={{ span: 10 }}
        >
          <Form.Item label="建成年份" name="building_year" wrapperCol={{ span: 16 }}>
            <RangePicker picker="year" allowEmpty={[true, true]} />
          </Form.Item>
          <Form.Item label="物业费用" style={{ marginBottom: 0 }} wrapperCol={{ span: 16 }}>
            <Form.Item
              name="property_fee_start"
              style={{ display: 'inline-block', width: "calc(40%)" }}
              dependencies={['property_fee_end']}
              rules={[
                ({ getFieldValue }) => ({
                  validator(_, value) {
                    if (getFieldValue('property_fee_end')) {
                      if (!value) {
                        return Promise.reject(new Error('请输入最低价'));
                      }
                    }
                    return Promise.resolve();
                  },
                }),
              ]}
            >
              <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="最低价" />
            </Form.Item>
            <Form.Item style={{ display: 'inline-block', margin: '0 8px' }}>至</Form.Item>
            <Form.Item
              name="property_fee_end"
              dependencies={['property_fee_start']}
              rules={[
                ({ getFieldValue }) => ({
                  validator(_, value) {
                    if (getFieldValue('property_fee_start')) {
                      if (!value) {
                        return Promise.reject(new Error('请输入最高价'));
                      } else if (getFieldValue('property_fee_start') > value) {
                        return Promise.reject(new Error('请输入合理的价格'));
                      }
                    }
                    return Promise.resolve();
                  },
                }),
              ]}
              style={{ display: 'inline-block', width: "calc(40%)", margin: '0 8px' }}
            >
              <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="最高价" />
            </Form.Item>
          </Form.Item>
          <Form.Item label="燃气费用" style={{ marginBottom: 0 }} wrapperCol={{ span: 16 }}>
            <Form.Item
              name="gas_fee_start"
              style={{ display: 'inline-block', width: "calc(40%)" }}
              dependencies={['gas_fee_end']}
              rules={[
                ({ getFieldValue }) => ({
                  validator(_, value) {
                    if (getFieldValue('gas_fee_end')) {
                      if (!value) {
                        return Promise.reject(new Error('请输入最低价'));
                      }
                    }
                    return Promise.resolve();
                  },
                }),
              ]}
            >
              <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="最低价" />
            </Form.Item>
            <Form.Item style={{ display: 'inline-block', margin: '0 8px' }}>至</Form.Item>
            <Form.Item
              name="gas_fee_end"
              dependencies={['gas_fee_start']}
              rules={[
                ({ getFieldValue }) => ({
                  validator(_, value) {
                    if (getFieldValue('gas_fee_start')) {
                      if (!value) {
                        return Promise.reject(new Error('请输入最高价'));
                      } else if (getFieldValue('gas_fee_start') > value) {
                        return Promise.reject(new Error('请输入合理的价格'));
                      }
                    }
                    return Promise.resolve();
                  },
                }),
              ]}
              style={{ display: 'inline-block', width: "calc(40%)", margin: '0 8px' }}
            >
              <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="最高价" />
            </Form.Item>
          </Form.Item>
          <Form.Item label="建筑类型" name="building_type">
            <Select placeholder='请选择建筑类型' allowClear options={buildingTypes} />
          </Form.Item>
          <Form.Item label="用水类型" name="water_type">
            <Select placeholder='请选择用水类型' allowClear mode="tags" options={[
              { label: "民用", value: '1' },
              { label: "商用", value: '2' },
            ]} />
          </Form.Item>
          <Form.Item label="用电类型" name="electric_type">
            <Select placeholder='请选择用电类型' allowClear mode="tags" options={[
              { label: "民用", value: '1' },
              { label: "商用", value: '2' },
            ]} />
          </Form.Item>
          <Form.Item label="小区均价" name="avg_price">
            <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="请输入均价" />
          </Form.Item>
          {gardenInfo.map(item => {
            if (item.name == "area_percent" || item.name == "green_percent") {
              return (
                <Form.Item
                  label={item.label}
                  name={item.name}
                  key={item.name}
                >
                  <InputNumber placeholder={`请输入${item.label}`} addonAfter="%" />
                </Form.Item>);
            } else if (item.name == "building_area" || item.name == "covered_area") {
              return (
                <Form.Item
                  label={item.label}
                  name={item.name}
                  key={item.name}
                >
                  <InputNumber placeholder={`请输入${item.label}`} addonAfter="m²" />
                </Form.Item>);
            } else if (item.name == "space_total" || item.name == "house_total") {
              return (
                <Form.Item
                  label={item.label}
                  name={item.name}
                  key={item.name}
                  wrapperCol={{ span: 10 }}
                >
                  <InputNumber placeholder={`请输入${item.label}`} style={{ width: "100%" }} />
                </Form.Item>);
            } else if(item.name=="space_info") {
              return (
                <Form.Item
                  label={item.label}
                  name={item.name}
                  key={item.name}
                  extra={<span>例：1:1.12 </span>}
                >
                  <Input placeholder={`请输入${item.label}`} style={{ width: "100%" }} />
                </Form.Item>);
            }
            else {
              return (
                <Form.Item
                  label={item.label}
                  name={item.name}
                  key={item.name}

                >
                  <Input placeholder={`请输入${item.label}`} style={{ width: "100%" }} />
                </Form.Item>);
            }
          })}
          <Form.Item label="小区图片" name='garden_pics'>
            <Uploadpic getSrc={garden_pics} src={pics} maxCount={6} />
          </Form.Item>
        </Form>
      </div>

      <div style={{ display: 'flex', justifyContent: 'end' }}>
        <Button type='primary' onClick={onSubmit}>更新小区信息</Button>
      </div>
    </Card>
  )
}
const mapStateToProps = (state) => {
  return {
    garden_info: state.getGardenList.list,
  }
}

const mapDispatchToProps = (dispatch) => {
  return {
    getGardenList: (userInput) => dispatch(getGardenList(userInput)),
  }
}

export default connect(mapStateToProps, mapDispatchToProps)(CompanyInfo)