import sha256 from 'sha256'
import * as React from 'react'
import '../index.scss'
import "./login.scss"
import { PostLogin } from '../../../services/api'
import { Login_by_phone } from '../../../services/user'
import { LoginForm, ProFormText, ProFormCaptcha } from '@ant-design/pro-form';
import {
  UserOutlined,
  MobileOutlined,
  LockOutlined
} from '@ant-design/icons';
import { message, Tabs, Image, Form, Modal } from 'antd';
import type { CSSProperties } from 'react';
import { useState } from 'react';
import { Getcaptcha } from '../../../services/user'
import { connect } from "react-redux";
import { setUserInfo } from "../../../redux/action/userinfo/index"

type LoginType = 'phone' | 'account';

const iconStyles: CSSProperties = {
  marginLeft: '16px',
  color: 'rgba(0, 0, 0, 0.2)',
  fontSize: '24px',
  verticalAlign: 'middle',
  cursor: 'pointer',
};
// @ts-ignore


const Login: React.FC = (props: any) => {
  const [loginType, setLoginType] = useState<LoginType>('account');
  const [visible, setVisible] = useState(false)
  const [loginAccount, setloginAccount] = useState([])
  const [form] = Form.useForm();
  let msgShow = true;

  const onFinish = async (values: any) => {
    if (loginType == 'account') {
      const name = values.username
      const password = values.password || 'zaq123edc'
      const { data } = await PostLogin({ user: name, password: sha256(password) });
      props.setUserInfo(data)
      const { token, user, uid, company, permissions, openim_id } = data;
      message.success('登录成功！')
      sessionStorage.setItem('area-token', token)
      sessionStorage.setItem('username', user)
      sessionStorage.setItem('uid', uid)
      sessionStorage.setItem('openim_id', openim_id)
      sessionStorage.setItem('company', company)
      sessionStorage.setItem('permissions', JSON.stringify(permissions))
      window.location.href = '/admin/index'
    }
    if (loginType == 'phone') {
      const phone = values.mobile
      const vcode = values.captcha - 0
      const { data, token }: any = await Login_by_phone({ phone, vcode })
      if (data.length > 1) {
        setloginAccount(data.list)
        setVisible(true)
        console.log(1);
        //暂定
      } else {
        message.success('登录成功！')
        sessionStorage.setItem('area-token', token)
        sessionStorage.setItem('username', data[0].user)
        props.history.push('/admin/index')
      }
    }
  };
  const handleOk = () => {
    setVisible(false)
  }
  const handleCancle = () => {
    setVisible(false)
  }
  return (
    <><div className="login-container">
      <div className="login-box">
        <div className="login-cover">
          <div className="login-title">
            勤爱家
            <div>物业管理系统</div>
          </div>
        </div>
        <div className="login-form">
          <div style={{ backgroundColor: 'white' }}>
            <LoginForm
              onFinish={onFinish}
              form={form}
            >
              <Tabs activeKey={loginType} onChange={(activeKey) => setLoginType(activeKey as LoginType)}>
                <Tabs.TabPane key={'account'} tab={'账号密码登录'} />
                <Tabs.TabPane key={'phone'} tab={'手机号登录'} />
              </Tabs>
              {loginType === 'account' && (
                <>
                  <ProFormText
                    name="username"
                    fieldProps={{
                      size: 'large',
                      prefix: <UserOutlined className={'prefixIcon'} />,
                    }}
                    placeholder={'账号'}
                    rules={[
                      {
                        required: true,
                        message: '请输入用户名!',
                      },
                    ]} />
                  <ProFormText.Password
                    name="password"
                    fieldProps={{
                      size: 'large',
                      prefix: <LockOutlined className={'prefixIcon'} />,
                    }}
                    placeholder={'密码'}
                    rules={[
                      {
                        required: true,
                        message: '请输入密码！',
                      },
                    ]} />
                </>
              )}
              {loginType === 'phone' && (
                <>
                  <ProFormText
                    fieldProps={{
                      size: 'large',
                      prefix: <MobileOutlined className={'prefixIcon'} />,
                    }}
                    name="mobile"
                    placeholder={'手机号'}
                    rules={[
                      {
                        required: true,
                        message: '请输入手机号！',
                      },
                      {
                        pattern: /^1\d{10}$/,
                        message: '手机号格式错误！',
                      },
                    ]} />
                  <ProFormCaptcha
                    fieldProps={{
                      size: 'large',
                      prefix: <LockOutlined className={'prefixIcon'} />,
                    }}
                    captchaProps={{
                      size: 'small',
                      
                    }}
                    placeholder={'请输入验证码'}
                    captchaTextRender={(timing, count) => {
                      if (timing) {
                        return `${count}s后${'获取验证码'}`
                      }
                      return '获取验证码'
                    }}
                    name="captcha"
                    phoneName="mobile"
                    rules={[
                      {
                        required: true,
                        message: '请输入验证码！',
                      },
                    ]}
                    onGetCaptcha={async (phone) => {
                      await Getcaptcha({phone})
                      message.success('验证码发送成功')
                    }} />
                </>
              )}
            </LoginForm>
          </div>
        </div>
      </div>
    </div>
      <Modal title="选择需要登录的账户" visible={visible} onOk={handleOk} onCancel={handleCancle}>

      </Modal>
    </>
  )
}
const mapStateToProps = (state) => {
  return {
    userInfo: state.setUserInfo.list,
  }
}

const mapDispatchToProps = (dispatch) => {
  return {
    setUserInfo: (userInput) => dispatch(setUserInfo(userInput)),
  }
}

export default connect(mapStateToProps, mapDispatchToProps)(Login)
