import React, { useEffect, useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, message } from 'antd'
import { Link, withRouter } from 'react-router-dom'
import { User } from '../../services/user'
import { GetPermissionGroups } from '../../services/permission'
import './index.scss'

const Roles: React.FC = (props: any) => {
  const actionRef: any = React.useRef<ActionType>()
  const [data, setData] = useState({})
  useEffect(() => {
    GetPermissionGroups({page:1,page_size:9999}).then(res => {
      let data = {}
      res.data.map(item => {
        data[item.id] = { text: item.group_name }
      })
      setData(data)
    })
  }, [])
  const columns: any = [
    {
      title: '用户名',
      dataIndex: 'user_name',
      search: true,
    },
    {
      title: '电话号码',
      dataIndex: 'phone',
      search: true,
    },
    {
      title: '姓名',
      dataIndex: 'real_name',
      search: false,
    },
    {
      title: '邮箱',
      dataIndex: 'email',
      search: false,
    },
    {
      title: '权限组',
      dataIndex: 'group_id',
      search: true,
      valueType: 'select',
      valueEnum: data,
    },
    {
      title: '创建时间',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 210,
      align: 'center',
      render: (_, row, index, action) => <>
        <Link to={{pathname:"/admin/account/list/edituser",state:row}}>
          <Button type='link' onClick={() => {
          }}>编辑</Button>
        </Link>
        <Button type='link' onClick={() => deleteUser(row.id)}>删除</Button>
      </>
    }
  ]

  const deleteUser = (id) => {
    Modal.confirm({
      title: '删除记录',
      content: '你确定删除这条记录吗？',
      onOk: async () => {
        await User({ method: 'delete', id })
        message.success('操作成功！')
        actionRef.current.reload()
      }
    })
  }
  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        request={User}
        search={{ span: 6 }}
        toolBarRender={() => [
          <Link to={{ pathname: "/admin/account/list/adduser" }}>
            <Button
              type="primary"
              key="primary"
            >添加</Button>
          </Link>
        ]}
        columns={columns}
      />
    </React.Fragment>
  )
}

export default withRouter(Roles)