import React, { useEffect, useState } from "react";
import { Card, Button, Form, Row, Col, Select, Input, message } from "antd";
import { LeftOutlined } from '@ant-design/icons'
import { Department, User } from "../../services/user";
import { GetPermissionGroups } from "../../services/permission";
import { useHistory } from "react-router";
import { PassWordRules } from "../../CONSTANT";
import sha256 from 'sha256'
import './index.scss'

const AddUser = (props) => {
    const [form] = Form.useForm()
    const [userList, setUserList]: any = useState({
        department: [],
        group: []
    })
    const history = useHistory();
    const location = history.location
    const state: any = location.state
    const [flag, setFlag] = useState(true)

    useEffect(() => {
        if (typeof (state) === 'number') {
            setFlag(false)
        }
    }, [])
    useEffect(() => {
        if (JSON.stringify(props) !== '{}') {
            userList.department.map(item => {
                if (item.department_name == props.user.department_name) {
                    form.setFieldsValue({ department_id: item.id })
                }
            })
            form.setFieldsValue(props.user)
        }
    }, [userList.department])
    useEffect(() => {
        Department({}).then(res => {
            setUserList(pre => ({ ...pre, department: res.data }))
        })
        GetPermissionGroups({}).then(res => {
            setUserList(pre => ({ ...pre, group: res.data }))
        })
    }, [])
    const addUser = () => {
        form.validateFields().then(async (value) => {
            const { password } = value
            await User({ method: 'post', ...value, password: sha256(password) })
            message.success('添加成功')
            history.goBack()
        })
    }
    const editUser = () => {
        form.validateFields().then(async (value) => {
            const { password } = value
            const { id } = props.user
            await User({ method: 'put', ...value, id, password: sha256(password) })
            message.success('修改成功')
            history.goBack()
        })
    }
    const base_permission = [
        {
            value: 1,
            label: "仅用于小区后台"
        }, {
            value: 2,
            label: "仅用于员工小程序"
        }, {
            value: 3,
            label: "二者皆可"
        }
    ]
    
    const group_permission = userList.group.map(item => {
        return {
            value: item.id,
            label: item.group_name
        }
    })
    const department = userList.department.map(item => {
        return {
            value: item.id,
            label: item.department_name
        }
    })
    return (<>
        <Card
            extra={<Button type='primary' icon={<LeftOutlined />}
                onClick={history.goBack}
            >返回</Button>}
        >
            <Form
                form={form}
                labelCol={{ span: 6 }}
                wrapperCol={{ span: 9 }}
                initialValues={{ group_id: state }}
            >
                <Row>
                    <div className='form-group-title'>基本信息 :</div>
                    <Col span={10}>
                        <Form.Item label='账户名' name='user_name' rules={[{ required: true, message: "请输入账户名" }]}>
                            <Input placeholder="请输入账户名"></Input>
                        </Form.Item>
                    </Col>
                    <Col span={10}>
                        {JSON.stringify(props) == '{}' ? <Form.Item label='密码' name='password'
                            rules={[
                                { required: true, message: '请输入密码' },
                                ...PassWordRules
                            ]}
                            hasFeedback
                        >
                            <Input.Password placeholder="请输入密码"></Input.Password>
                        </Form.Item> :
                            <Form.Item label='密码' name='password' rules={PassWordRules}
                            hasFeedback
                            >
                                <Input.Password placeholder="请输入密码"></Input.Password>
                            </Form.Item>}
                    </Col>
                    <Col span={10}>
                        <Form.Item label='手机号' name='phone'
                            rules={[
                                {
                                    required: true,
                                    message: '请输入手机号！',
                                },
                                {
                                    pattern: /^1\d{10}$/,
                                    message: '手机号格式错误！',
                                },
                            ]}
                        >
                            <Input placeholder="请输入手机号"></Input>
                        </Form.Item>
                    </Col>
                    <Col span={10}>
                        <Form.Item label='邮箱' name='email'
                            rules={[
                                {
                                    type: "email"
                                }
                            ]}
                        >
                            <Input placeholder="请输入邮箱"></Input>
                        </Form.Item>
                    </Col>
                    <Col span={10}>
                        <Form.Item label='部门' name='department_id'>
                            <Select placeholder='请选择部门' options={department}>
                            </Select>
                        </Form.Item>
                    </Col>
                    <Col span={10}>
                        <Form.Item label='姓名' name='real_name'
                            rules={[
                                { required: true, message: '请输入姓名' }
                            ]}
                        >
                            <Input placeholder="请输入姓名"></Input>
                        </Form.Item>
                    </Col>
                </Row>
                <Row>
                    <div className='form-group-title'>权限信息 :</div>
                    <Col span={10}>
                        <Form.Item label='权限组' name='group_id' rules={[{ required: true, message: "请选择部门" }]}>
                            {!flag ? <Select disabled options={group_permission}>
                            </Select> :
                                <Select placeholder='请选择权限组' options={group_permission}>
                                </Select>
                            }
                        </Form.Item>
                        <Form.Item label='后台权限' name='base_permission' rules={[{ required: true, message: "请选择后台权限" }]}>
                            <Select placeholder="请选择后台权限" options={base_permission}>
                            </Select>
                        </Form.Item>
                    </Col>
                </Row>
            </Form>
            <div className="creatuserBtn">
                {JSON.stringify(props) == '{}' ? <Button type="primary" onClick={addUser}>创建用户</Button> :
                    <Button type="primary" onClick={editUser}>修改用户</Button>}
            </div>
        </Card>
    </>)
}

export default AddUser