import React, { useState } from "react";
import { Button, Modal, message, Form, Input } from "antd";
import ProTable from "@ant-design/pro-table";
import type { ActionType } from "@ant-design/pro-table";
import { Department } from "../../services/user";

const DepartmentList = () => {
    const columns: any = [
        {
            title: "部门名",
            align: "center",
            dataIndex: "department_name"
        },
        {
            title: "部门描述",
            align: "center",
            dataIndex: "desc"
        },
        {
            title: "创建时间",
            align: "center",
            dataIndex: "created_at"
        }, {
            title: "操作",
            dataIndex: "option",
            align: "center",
            render: (_, row) => <>
                <Button type="link" onClick={() => optionModal(row.id, true,row)}>编辑</Button>
                <Button type="link" onClick={() => deleteDepartment(row.id)}>删除</Button>
            </>
        }
    ]
    const actionRef: any = React.useRef<ActionType>()
    const [form] = Form.useForm()
    const [state, setState] = useState({
        id: '',
        visible: false
    })

    const deleteDepartment = (id) => {
        Modal.confirm({
            title: '删除记录',
            content: '你确定删除这条记录吗？',
            onOk: async () => {
                await Department({ method: 'delete', id })
                message.success('操作成功！')
                actionRef.current.reload()
            }
        })
    }
    const optionModal = (id, state,row) => {
        if(row){
            form.setFieldsValue(row)
        }else{
            form.resetFields()
        }
        setState(pre => ({ ...pre, id, visible: state }))
    }
    const onSubmit = () => {
        form.validateFields().then(async (value) => {
            await Department({
                ...value,
                method:state.id ? "put" : "post",
                id:state.id
            })
            message.success(state.id?"修改成功":"添加成功")
            optionModal('',false,null)
            actionRef.current.reloadAndRest()
        })
    }
    return <>
        <ProTable
            actionRef={actionRef}
            rowKey="id"
            search={false}
            columns={columns}
            request={Department}
            toolBarRender={() => [
                <Button
                    type="primary"
                    key="primary"
                    onClick={() => optionModal('', true,null)}
                >添加</Button>
            ]}
        />
        <Modal
            title={state.id ? "编辑部门" : "添加部门"}
            visible={state.visible}
            maskClosable={false}
            width={680}
            onOk={onSubmit}
            onCancel={() => optionModal('', false,null)}
        >
            <Form
                labelCol={{ span: 5 }}
                wrapperCol={{ span: 15 }}
                form={form}
            >
                <Form.Item label="部门名称" name="department_name" rules={[{required:true,message:"请输入部门名称"}]}>
                    <Input placeholder="请输入部门名称" />
                </Form.Item>
                <Form.Item label="部门描述" name="desc">
                    <Input.TextArea placeholder="请输入部门描述" />
                </Form.Item>
            </Form>
        </Modal>
    </>
}

export default DepartmentList