import * as React from 'react';
import { useState } from 'react';
import {
    Collapse,
    Input,
    Row,
    Col,
    Button,
    Form,
    message,
    Tabs,
    Radio,
    Upload,
    Modal,
} from 'antd';
import { PersonRelated, GetOpen_Info, SetOpen_face } from '../../services/user';
import ImgCrop from 'antd-img-crop';
import { getBase64 } from '../../utils/utils';
import "./person.scss"
const { Panel } = Collapse;

const layout = {
    labelCol: { span: 3, xl: 4 },
    wrapperCol: { span: 5, xl: 6 },
};
const Person: React.FC = (props) => {
    const [form] = Form.useForm();
    const [info, setInfo]: any = React.useState({});
    const [refresh, setrefresh] = React.useState(true)
    const openim_id = sessionStorage.getItem('openim_id')
    /**
   * @description 获取用户信息
   */
    const getPerson = async () => {
        const { data } = await PersonRelated({});
        form.setFieldsValue(data);
        setInfo(data);
    }
    React.useEffect(() => {
        getPerson();
    }, [refresh])
    /**
     * @description 修改信息
     */
    const handleChangeName = (name) => {
        form.validateFields([name]).then(async (values) => {
            await PersonRelated({ method: "put", ...info, ...values });
            message.success("修改成功")
            setrefresh(!refresh)
        })
    };
    React.useEffect(() => {
        getopen_info();
    }, [])
    const getopen_info = async () => {
        const { data } = await GetOpen_Info({ openim_id });
        const { face_url } = data;
        if (face_url) {
            setface_url(face_url);
            setFileList([{
                uid: '-1',
                name: 'image.png',
                status: 'done',
                url: face_url,
            },])
        }
    }
    const [fileList, setFileList]: any = useState([]);
    const [previewVisible, setPreviewVisible] = useState(false);
    const [previewImage, setPreviewImage] = useState();
    const [previewTitle, setPreviewTitle] = useState('');
    const [face_url, setface_url] = useState("");
    const token: any = sessionStorage.getItem('area-token')

    const handleChange = (info) => {
        setFileList(info.fileList);
        if (info.file.status === 'done') {
            const { data } = info.file.response;
            setface_url(data);
        }
        if (info.fileList.length == 0) {
            setface_url("");
        }
    };
    const handlePreview = async (file) => {
        if (!file.url && !file.preview) {
            file.preview = await getBase64(file.originFileObj);
        }
        setPreviewImage(file.url || file.preview);
        setPreviewVisible(true);
        setPreviewTitle(file.name || file.url.substring(file.url.lastIndexOf('/') + 1));
    };
    const handleCancel = () => setPreviewVisible(false);
    const setFace_url = async () => {
        if (face_url) {
            await SetOpen_face({ face_url, openim_id });
            message.success("上传成功");
        } else {
            message.info('请先上传头像');
        }
    }
    const items = [
        {
            key: '1',
            label: `基本信息`,
            children: <Form form={form} labelCol={{ span: 2 }} wrapperCol={{ span: 5, }}>
                <Form.Item label="账户名" name="user">
                    <Input disabled />
                </Form.Item>
                <Form.Item label="姓名" name="real_name">
                    <Input disabled />
                </Form.Item>
                <Form.Item label="性别" name="gender">
                    <Radio.Group name="gender" style={{ width: "100%", display: "flex", justifyContent: "space-around" }}>
                        <Radio value={1}>男</Radio>
                        <Radio value={2}>女</Radio>
                    </Radio.Group>
                </Form.Item>
                <Form.Item label="所属部门" name="department">
                    <Input disabled />
                </Form.Item>
                <Form.Item wrapperCol={{ offset: 3, span: 4 }}>
                    <Button type='primary' onClick={() => {
                        handleChangeName("gender");
                    }}>保存</Button>
                </Form.Item>
            </Form>,
        },
        {
            key: '2',
            label: `修改头像`,
            children: <>
                <div className='avatar'>
                    <ImgCrop rotate>
                        <Upload
                            name="file"
                            className="avatar-uploader"
                            action="http://47.108.135.38:30002/api/v1/upload"
                            //  action="http://localhost:3000/api/v1/upload"
                            listType="picture-card"
                            headers={{ token }}
                            fileList={fileList}
                            onChange={handleChange}
                            onPreview={handlePreview}
                        >
                            {fileList.length < 1 && '+ Upload'}
                        </Upload>
                    </ImgCrop>
                    <Button type='primary' onClick={setFace_url}>保存</Button>
                </div>
                <Modal open={previewVisible} title={previewTitle} footer={null} onCancel={handleCancel}>
                    <img
                        alt="example"
                        style={{
                            width: '100%',
                        }}
                        src={previewImage} />
                </Modal></>
        },
        {
            key: '3',
            label: `账号安全`,
            children: <Form  {...layout}
                form={form}
            >
                <Collapse defaultActiveKey={['phone']} expandIconPosition='end'>
                    <Panel header={<div>手机号码:{info.phone}</div>} key='phone'>
                        <Form.Item
                            label='新手机号'
                            name='phone'
                            validateFirst
                            rules={[{ required: true, message: '请输入手机号' }]}
                            children={
                                <Input
                                    addonBefore='中国大陆+86'
                                    placeholder='您的手机号码'></Input>
                            }></Form.Item>
                        <Row align='middle'>
                            <Col offset={4}>
                                <Button
                                    type='primary'
                                    onClick={() => {
                                        handleChangeName("phone");
                                    }}
                                >
                                    确认
                                </Button>
                            </Col>
                        </Row>
                    </Panel>
                    <Panel
                        header={<div>邮箱账号:{info.email}</div>}
                        key='email'>
                        <Form.Item
                            label='新邮箱地址'
                            required
                            name='email'
                            rules={[
                                { type: 'email', message: '请输入正确的邮箱' },
                                { required: true, message: '请输入邮箱地址' },
                            ]}
                            children={<Input placeholder='新邮箱地址'></Input>}></Form.Item>
                        <Row align='middle'>
                            <Col offset={4}>
                                <Button
                                    type='primary'
                                    onClick={() => {
                                        handleChangeName("email");
                                    }}
                                >
                                    确认
                                </Button>
                            </Col>
                        </Row>
                    </Panel>
                </Collapse>
            </Form>,
        },
    ];

    return (
        <>
            <Tabs defaultActiveKey="1" items={items} />
        </>
    );
};
export default Person;
