import React, { useEffect, useState } from "react";
import type { ActionType } from "@ant-design/pro-table";
import ProTable from "@ant-design/pro-table";
import {
  Button,
  Modal,
  Form,
  Select,
  Input,
  message,
  InputNumber,
  Space,
  Upload, Col, Row, Tree
} from "antd";
import { PlusOutlined } from "@ant-design/icons";
import { Link, withRouter } from "react-router-dom";
import { BuildingHouse, BuildingUnit, BuildingsHouseImport, GetBuildingHouseTemplate } from "../../services/building";
import { SELECTOR_HOUSE_TYPE, SELECTOR_HOUSE_TYPE2 } from "../../CONSTANT";
import { useBuilding } from "./hooks";
import "./index.scss";


const initTreeData = [
  { title: '全部', key: '-' },
];

const updateTreeData = (list, key, children) =>
  list.map((node) => {
    if (node.key === key) {
      return {
        ...node,
        children,
      };
    }
    if (node.children) {
      return {
        ...node,
        children: updateTreeData(node.children, key, children),
      };
    }
    return node;
  });



const ParkingPositionPage: React.FC = (props: any) => {
  const [treeData, setTreeData] = useState(initTreeData);
  const [selectedKeys, setSelectedKeys]: any = useState(['-']);
  const [building_id, setbuilding_id]: any = useState('');
  const [unit_id, setunit_id]: any = useState("");
  const onLoadData = ({ key, children }: any) =>
    new Promise<void>((resolve) => {
      if (children) {
        resolve();
        return;
      }
      if (key == "-") {
        setTimeout(() => {
          setTreeData((origin) => {
            let arr = buildings.map(item => {
              return { title: item.label, key: item.value }
            })
            return updateTreeData(origin, key, arr)
          }
          );
          resolve();
        }, 1000);
      } else {
        getUnit({ building_id: key }, key, resolve);
      }
    });
  const onSelect = (selectedKeys, info) => {
    let val = selectedKeys[0];
    let building_id, unit_id;
    if (isNaN(val)) {
      let str = val.split('-');
      building_id = str[0];
      unit_id = str[1];
    } else {
      building_id = val;
      unit_id = "";
    }
    setbuilding_id(building_id);
    setunit_id(unit_id);
    setSelectedKeys(selectedKeys);
  };
  const getUnit = async (val, key, resolve) => {
    const { data } = await BuildingUnit({ page: -1, page_size: -1, ...val });
    let arr = data.map(item => {
      return { title: item.unit_name, key: `${key}-${item.id}`, isLeaf: true }
    })
    setTimeout(() => {
      setTreeData((origin) => {
        return updateTreeData(origin, key, arr)
      }
      );
      resolve();
    },1000);
  }
  const [buildings, setBuildings]: any = useBuilding();
  const [units, setUnits] = React.useState([]);
  const [state, setState] = React.useState({
    visible: false,
    exportVisible: false,
    editId: null
  });
  let uploadFile: any = null
  const columns: any = [
    {
      title: "房号",
      dataIndex: "house_name",
      search: false
    },
    {
      title: "门牌号",
      dataIndex: "house_number",
      hideInTable: true,
      search: true
    },
    {
      title: "楼层",
      dataIndex: "layer",
      search: false
    },
    {
      title: "类型",
      dataIndex: "house_type",
      valueType: "select",
      valueEnum: SELECTOR_HOUSE_TYPE2,
      search: true
    },
    {
      title: "建筑面积(㎡)",
      dataIndex: "house_area",
      search: false
    },
    {
      title: "使用面积(㎡)",
      dataIndex: "house_used_area",
      search: false
    },
    {
      title: "房屋状态",
      dataIndex: "status",
      search: false,
      valueEnum: {
        1: { text: "未入住" },
        2: { text: "已入住" },
        3: { text: "已出租" }
      }
    },
    {
      title: "备注",
      dataIndex: "comment",
      search: false
    },
    {
      title: "操作",
      dataIndex: "option",
      search: false,
      // width: 210,
      align: "center",
      render: (_, row, index, action) => <>
        <Button
          type="link"
          onClick={() => {
            onChangeBuilding(row.building_id)
            form.setFieldsValue(row);
            setState((prevState) => ({
              ...prevState,
              visible: true,
              editId: row.id
            }));
          }}
        >
          编辑
        </Button>
        <Button
          type="link"
          onClick={() => {
            Modal.confirm({
              title: "删除记录",
              content: "你确定删除这条记录吗？",
              onOk: async () => {
                await BuildingHouse({ method: "delete", id: row.id });
                message.success("操作成功！");
                actionRef.current.reload();
              }
            });
          }}
        >
          删除
        </Button>
        {row.status == 1 ? <Button type="link" disabled>人员</Button> :
          <Link to={{ pathname: "/admin/building/house/userlist", state: row.id }}>
            <Button type="link">人员</Button>
          </Link>
        }
      </>
    }
  ];
  const onChangeBuilding = (value) => {
    form.resetFields(["unit_id"])
    const params = { page_size: -1, building_id: value };
    BuildingUnit(params).then(({ data }) => {
      setUnits(
        data?.map(({ unit_name, id }) => ({ value: id, label: unit_name }))
      );
    });
  };

  const actionRef: any = React.useRef<ActionType>();
  const [form] = Form.useForm();
  const onSubmit = () => {
    form.validateFields().then(async (values) => {
      await BuildingHouse({
        ...values,
        method: state.editId ? "put" : "post",
        id: state.editId
      });
      message.success("操作成功！");
      actionRef.current?.reloadAndRest();
      setState((prevState) => ({ ...prevState, visible: false }));
    });
  };
  useEffect(() => {
    setBuildings();
  }, [])
  const getTemplate = async () => {
    const { data } = await GetBuildingHouseTemplate()
    window.open(data.url)
  }
  const limitNumber = (value) => {
    if (typeof value === "string") {
      return !isNaN(Number(value)) ? value.replace(/^(0+)|[^\d]/g, "") : "";
    } else if (typeof value === "number") {
      return !isNaN(value) ? String(value).replace(/^(0+)|[^\d]/g, "") : "";
    } else {
      return "";
    }
  };

  return (
    <React.Fragment>
      <Row>
        <Col span={3}>
          <Tree loadData={onLoadData} treeData={treeData}
            onSelect={onSelect}
            selectedKeys={selectedKeys}
          />
        </Col>
        <Col span={20} style={{marginLeft:"20px"}}>
          <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={BuildingHouse}
            search={{
              collapsed: false, collapseRender: () => false,
              span: 8
            }}
            params={{ building_id, unit_id }}
            toolBarRender={() => [
              <><Button
                type="primary"
                key="primary"
                icon={<PlusOutlined />}
                style={{ borderRadius: "5px", marginRight: '5px' }}
                onClick={() => {
                  form.resetFields();
                  setUnits([]);
                  setState((preState) => ({ ...preState, visible: true, editId: null }));
                }}
              >
                添加房屋
              </Button><Button
                type="primary"
                key="primary2"
                icon={<PlusOutlined />}
                style={{ borderRadius: "5px" }}
                onClick={() => {
                  setState(preState => ({ ...preState, exportVisible: true }));
                }}
              >房屋导入</Button></>
            ]}
            columns={columns}
          />
        </Col>
      </Row>
      <Modal
        title={state.editId ? "编辑房屋" : "添加房屋"}
        visible={state.visible}
        width={680}
        onOk={onSubmit}
        maskClosable={false}
        onCancel={() => setState((pre) => ({ ...pre, visible: false }))}
      >
        <Form labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} form={form}>
          <Form.Item
            label="楼栋"
            name="building_id"
            rules={[{ required: true }]}
          >
            <Select
              placeholder="请选择楼栋"
              options={buildings}
              onChange={onChangeBuilding}

            />
          </Form.Item>
          <Form.Item label="单元" name="unit_id" rules={[{ required: true }]}>
            <Select placeholder="请选择单元" options={units} />
          </Form.Item>
          <Form.Item
            label="房间号"
            name="house_number"
            rules={[{ required: true }]}
          >
            <Input placeholder="请输入纯房号(不包含楼栋和单元),如101" />
          </Form.Item>
          <Form.Item label="楼层" name="layer" rules={[{ required: true }]}>
            <InputNumber
              style={{ width: '100px' }}
              placeholder="请输入楼层"
              formatter={limitNumber}
              controls={false}
              min={1}
            />
          </Form.Item>

          <Form.Item label="房屋户型">
            <Space>
              <Form.Item
                noStyle
                name="room_count"
                rules={[{ required: false }]}
                style={{ display: "inline-block" }}
              >
                <InputNumber formatter={limitNumber} min={0} max={10} />
              </Form.Item>
              室
              <Form.Item
                noStyle
                name="hall_count"
                rules={[{ required: false }]}
                style={{
                  display: "inline-block",
                  width: "calc(50% - 8px)",
                  margin: "0 8px"
                }}
              >
                <InputNumber formatter={limitNumber} min={0} max={10} />
              </Form.Item>
              厅
            </Space>
          </Form.Item>
          <Form.Item
            label="房屋类型"
            name="house_type"
            rules={[{ required: true }]}
          >
            <Select
              placeholder="请选择房屋类型"
              options={SELECTOR_HOUSE_TYPE}
            />
          </Form.Item>
          <Form.Item
            label="建筑面积（㎡）"
            name="house_area"
            rules={[{ required: true }]}
          >
            <InputNumber
              placeholder="请输入建筑面积"
              min={0}
              style={{ width: 160 }}
            />
          </Form.Item>
          <Form.Item
            label="使用面积（㎡）"
            name="house_used_area"
            rules={[{ required: true }]}
          >
            <InputNumber
              placeholder="请输入使用面积"
              min={0}
              style={{ width: 160 }}
            />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title='单元导入'
        visible={state.exportVisible}
        onOk={async () => {
          if (!uploadFile) message.error('请先选择文件！')
          const files = new FormData()
          files.append('file', uploadFile)
          await BuildingsHouseImport({
            file: files
          })
          message.success('上传成功')
          actionRef.current.reloadAndRest()
          setState(prevState => ({
            ...prevState,
            exportVisible: false
          }))
          uploadFile = null
        }}
        destroyOnClose={true}
        maskClosable={false}
        onCancel={() => {
          setState(prevState => ({
            ...prevState,
            exportVisible: false
          }))
          uploadFile = null
        }}
        okText="导入"
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 16 }}
        >
          <Form.Item label='选择文件'>
            <Upload
              beforeUpload={file => {
                uploadFile = file
                return false
              }}
              maxCount={1}
            >
              <Button>选择文件</Button>
            </Upload>
          </Form.Item>
          <Form.Item label='下载模板'>
            请先下载 <span className='link-primary' onClick={getTemplate}>导入模板</span> 准备数据后，上传导入
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  );
};

export default withRouter(ParkingPositionPage);
