import React from "react";
import type { ActionType } from "@ant-design/pro-table";
import ProTable from "@ant-design/pro-table";
import { Button, Modal, Form, Input, InputNumber, message, Upload } from "antd";
import { Link, withRouter } from "react-router-dom";
import { Building, BuildingsImport, GetBuildingTemplate } from "../../services/building";
import { PlusOutlined } from "@ant-design/icons";
import "./index.scss";

const BuildingList: React.FC = (props: any) => {
  const columns: any = [
    {
      title: "楼栋编号",
      dataIndex: "building_number",
      search: true,
    },
    {
      title: "楼栋名",
      dataIndex: "building_name",
      search: false
    },
    {
      title: "单元数",
      dataIndex: "unit_count",
      search: false
    },
    {
      title: "是否存在单元",
      dataIndex: "unit_count",
      search: false,
      render: (_, row) => <span>
        {row.unit_count > 0 ? "是" : "否"}
      </span>
    },
    {
      title: "建筑面积",
      dataIndex: "building_area",
      search: false
    },
    {
      title: "使用面积",
      dataIndex: "building_used_area",
      search: false
    },
    {
      title: "备注",
      dataIndex: "comment",
      search: false
    },
    {
      title: "操作",
      dataIndex: "option",
      search: false,
      align: "center",
      render: (_, row, index, action) => <>
        <Button
          type="link"
          onClick={() => {
            form.setFieldsValue(row);
            setState((prevState) => ({
              ...prevState,
              visible: true,
              editId: row.id
            }));
          }}
        >
          编辑
        </Button>
        <Button
          type="link"
          onClick={() => {
            Modal.confirm({
              title: "删除记录",
              content: "你确定删除这条记录吗？",
              onOk: async () => {
                await Building({ method: "delete", id: row.id });
                message.success("操作成功！");
                actionRef.current.reload();
              }
            });
          }}
        >
          删除
        </Button>
        <Button
          type="link"
          onClick={() => {
            props.history.push("/admin/building/unit");
          }}
        >
          添加单元
        </Button>
        <Link to={{pathname:"/admin/building/house/manager",state:row.id}}>
          <Button type="link">楼栋管家</Button>
        </Link>
      </>
    }
  ];
  const [state, setState] = React.useState({
    visible: false,
    exportVisible: false,
    editId: null
  });
  let uploadFile: any = null
  const actionRef: any = React.useRef<ActionType>();
  const [form] = Form.useForm();
  const onSubmit = () => {
    form.validateFields().then(async (values) => {
      const { building_number } = values
      await Building({
        ...values,
        method: state.editId ? "put" : "post",
        building_number: building_number + '',
        id: state.editId
      });
      message.success("操作成功！");
      actionRef.current?.reloadAndRest();
      setState((prevState) => ({ ...prevState, visible: false }));
    });
  };
  const getTemplate = async () => {
    const { data } = await GetBuildingTemplate()
    window.open(data.url)
  }
  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        request={Building}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6
        }}
        toolBarRender={() => [
          <><Button
            icon={<PlusOutlined />}
            style={{ borderRadius: "5px", marginRight: '5px' }}
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields();
              setState((preState) => ({ ...preState, visible: true, editId: null }));
            }}
          >
            添加楼栋
          </Button><Button
            icon={<PlusOutlined />}
            style={{ borderRadius: "5px" }}
            type="primary"
            key="primary2"
            onClick={() => {
              setState(preState => ({ ...preState, exportVisible: true }))
            }}
          >
              楼栋导入
            </Button></>
        ]}
        columns={columns}
      />
      <Modal
        title={state.editId ? "编辑楼栋" : "添加楼栋"}
        visible={state.visible}
        maskClosable={false}
        width={500}
        okText={state.editId ? "保存" : "添加"}
        onOk={onSubmit}
        onCancel={() => setState((pre) => ({ ...pre, visible: false }))}
      >
        <Form labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} form={form}>
          <Form.Item
            label="楼栋编号"
            name="building_number"
            rules={[{ required: true }]}
          >
            <InputNumber placeholder="请输入" min={1} onChange={(value) => {
              if (value) {
                form.setFieldsValue({ building_name: `${value}栋` })
              } else {
                form.setFieldsValue({ building_name: '' })
              }
            }} />
          </Form.Item>
          <Form.Item
            label="楼栋名"
            name="building_name"
            rules={[{ required: true }]}
          >
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item
            label="建筑面积"
            name="building_area"
          >
            <InputNumber placeholder="请输入" min={1} />
          </Form.Item>
          <Form.Item
            label="使用面积"
            name="building_used_area"
          >
            <InputNumber placeholder="请输入" min={1} />
          </Form.Item>
          <Form.Item label="备注" name="comment">
            <Input.TextArea rows={4} placeholder="请输入" />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title='楼栋导入'
        visible={state.exportVisible}
        onOk={async () => {
          if (!uploadFile) message.error('请先选择文件！')
          const files = new FormData()
          files.append('file', uploadFile)
          await BuildingsImport({
            file: files
          })
          message.success('上传成功')
          actionRef.current.reloadAndRest()
          setState(prevState => ({
            ...prevState,
            exportVisible: false
          }))
          uploadFile = null
        }}
        destroyOnClose={true}
        maskClosable={false}
        onCancel={() => {
          setState(prevState => ({
            ...prevState,
            exportVisible: false
          }))
          uploadFile = null
        }}
        okText="导入"
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 16 }}
        >
          <Form.Item label='选择文件'>
            <Upload
              beforeUpload={file => {
                uploadFile = file
                return false
              }}
              maxCount={1}
            >
              <Button>选择文件</Button>
            </Upload>
          </Form.Item>
          <Form.Item label='下载模板'>
            请先下载 <span className='link-primary' onClick={getTemplate}>导入模板</span> 准备数据后，上传导入
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  );
};

export default withRouter(BuildingList);
