import { Button ,Form,Select,Modal,message} from "antd";
import React ,{useEffect,useState}from "react";
import { useHistory } from "react-router";
import type { ActionType } from "@ant-design/pro-table";
import ProTable from "@ant-design/pro-table";
import { PlusOutlined } from "@ant-design/icons";
import { BuildingManager } from "../../services/building";
import { User } from "../../services/api";

const Manager = () => {
    const history = useHistory();
    const location = history.location;
    const building_id: any = location.state;
    const actionRef: any = React.useRef<ActionType>();
    const [form] = Form.useForm();
    const [managerState, setManagerState] = useState(false)
    const [managerList, setManagerList] = useState([])
    const [exclude, setexclude]: any = useState()
    const [num,setNum] = useState(0)
    const columns: any = [
        {
            title: '用户名',
            align: "center",
            dataIndex: "user_name",
        },
        {
            title: '管家',
            align: "center",
            dataIndex: "name",
        },
        {
            title: '手机号',
            align: "center",
            dataIndex: "phone",
        },
        {
            title: '操作',
            align: "center",
            dataIndex: "option",
            render: (_, row) => <Button type="link" onClick={() => deleteManager(row.id)}>删除</Button>
        },
    ]
    
    useEffect(() => {
        User({ exclude}).then(res => {
            const data = res.data.map(item => {
                return { label: item.real_name, value: item.id }
            })
            setManagerList(data)
        })
    }, [exclude])
    useEffect(() => {
        BuildingManager({ building_id }).then(res => {
            const data = res.data.map(item => {
                return item.manager_uid
            })
            setexclude(data.join())
        })
    },[num])
    const controlModal = (visible) => {
        setManagerState(visible)
        form.resetFields()
    }
    const addManager = () => {
        form.validateFields().then(async (value) => {
            await BuildingManager({ method: 'post', ...value, building_id })
            setNum(Math.random())
            message.success("添加成功")
            actionRef.current.reload();
            controlModal(false)
        })
    }
    const deleteManager = (id) => {
        Modal.confirm({
            title: "删除记录",
            content: "你确定删除这条记录吗？",
            onOk: async () => {
                await BuildingManager({ method: 'delete', id });
                message.success("操作成功！");
                actionRef.current.reload();
                setNum(Math.random())
            }
        });
    }
    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey={record => record.id}
            request={BuildingManager}
            params={{ building_id }}
            search={false}
            toolBarRender={() => [
                <><Button
                    type="primary"
                    key="primary"
                    icon={<PlusOutlined />}
                    onClick={() => controlModal(true)}
                >
                    添加楼栋管家
                </Button>
                    <Button
                        type="primary"
                        key="primary2"
                        onClick={history.goBack}
                    >
                        返回
                    </Button>
                </>
            ]}
            columns={columns}
        />
          <Modal
            title='添加楼栋管家'
            visible={managerState}
            width='500px'
            onCancel={() => controlModal(false)}
            onOk={addManager}
            maskClosable={false}
        >
            <Form
                form={form}
            >
                <Form.Item label="楼栋管家" name="manager_uid" rules={[{ required: true, message: "请选择楼栋管家" }]}>
                    <Select placeholder="请选择楼栋管家" options={managerList}></Select>
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default Manager