import React, { useEffect } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, InputNumber, message, Select, Radio, Upload } from 'antd'
import { PlusOutlined } from "@ant-design/icons";
import { withRouter } from 'react-router-dom'
import { BuildingUnit, GetBuildingUnitTemplate, BuildingsUnitImport } from '../../services/building'
import { useBuilding } from './hooks'
import './index.scss'

const BuildingsUnit: React.FC = (props: any) => {
  const columns: any = [
    {
      title: '楼栋名',
      dataIndex: 'building_name',
      search: false,
    },
    {
      title: '单元编号',
      dataIndex: 'unit_number',
      search: true,
    },
    {
      title: '楼栋',
      dataIndex: 'building_id',
      hideInTable: true,
      valueType: 'select',
      search: true,
      renderFormItem: (_, { type, defaultRender, formItemProps, fieldProps, ...rest }, form) => {
        if (type === 'form') {
          return null;
        }
        const status = form.getFieldValue('state');

        if (status !== 'open') {
          return (
            // value 和 onchange 会通过 form 自动注入。
            <Select placeholder="请选择" options={buildings} />
          );
        }
        return defaultRender(_);
      }


    },
    {
      title: '单元名',
      dataIndex: 'unit_name',
      search: false,
    },
    {
      title: '总层数',
      dataIndex: 'unit_layers',
      search: false,
    },
    {
      title: '是否有电梯',
      dataIndex: 'has_lift',
      search: false,
      render: (_, record: any) => <span>{record.has_lift ? '是' : '否'}</span>
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      align: 'center',
      render: (_, row, index, action) => <>
        <Button type='link' onClick={() => {
          console.log(row.id);
          
          form.setFieldsValue(row)
          setState(prevState => ({ ...prevState, visible: true, editId: row.id }))
        }}>编辑</Button>
        <Button type='link' onClick={() => {
          Modal.confirm({
            title: '删除记录',
            content: '你确定删除这条记录吗？',
            onOk: async () => {
              await BuildingUnit({ method: 'delete', id: row.id })
              message.success('操作成功！')
              actionRef.current.reload()
            }
          })
        }}>删除</Button>
        <Button type='link' onClick={() => {
          props.history.push('/admin/building/house')
        }}>添加房屋</Button>
      </>
    }
  ]
  const [buildings, setBuildings] = useBuilding()
  const [state, setState]: any = React.useState({
    visible: false,
    exportVisible: false,
    editId: null
  })
  let uploadFile: any = null
  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(async values => {
      await BuildingUnit({
        ...values,
        id: state.editId,
        method: state.editId ? 'put' : 'post'
      })
      message.success('操作成功！')
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }

  useEffect(() => {
    setBuildings()
  }, []);
  const getTemplate = async () => {
    const { data } = await GetBuildingUnitTemplate()
    window.open(data.url)
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        request={BuildingUnit}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6
        }}
        toolBarRender={() => [
          <><Button
            type="primary"
            key="primary"
            icon={<PlusOutlined />}
            style={{ borderRadius: "5px", marginRight: '5px' }}
            onClick={() => {
              form.resetFields()
              setState(preState => ({ ...preState, visible: true, editId: null }))
            }}
          >添加单元</Button>
            <Button
              type="primary"
              key="primary2"
              icon={<PlusOutlined />}
              style={{ borderRadius: "5px" }}
              onClick={() => {
                setState(preState => ({ ...preState, exportVisible: true }))
              }}
            >单元导入</Button></>
        ]}
        columns={columns}
      />
      <Modal
        title={state.editId ? "编辑单元" : "添加单元"}
        visible={state.visible}
        maskClosable={false}
        width={600}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='楼栋' name="building_id" rules={[{ required: true }]}>
            <Select placeholder="请选择" options={buildings} />
          </Form.Item>
          <Form.Item label='单元编号' name="unit_number" rules={[{ required: true }]}>
            <InputNumber placeholder="请输入" min={1} onChange={(value)=>{
              if(value){
                form.setFieldsValue({unit_name:`${value}单元`})
              }else{
                form.setFieldsValue({unit_name:''})
              }
            }} />
          </Form.Item>
          <Form.Item label='单元名' name="unit_name" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='总层数' name="unit_layers" rules={[{ required: true }]}>
            <InputNumber placeholder="请输入" />
          </Form.Item>
          <Form.Item label='是否有电梯' name="has_lift" rules={[{ required: true }]}>
            <Radio.Group>
              <Radio value={true}>是</Radio>
              <Radio value={false}>否</Radio>
            </Radio.Group>
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title='单元导入'
        visible={state.exportVisible}
        maskClosable={false}
        onOk={async () => {
          if (!uploadFile) message.error('请先选择文件！')
          const files = new FormData()
          files.append('file', uploadFile)
          await BuildingsUnitImport({
            file: files
          })
          message.success('上传成功')
          actionRef.current.reloadAndRest()
          setState(prevState => ({
            ...prevState,
            exportVisible: false
          }))
          uploadFile = null
        }}
        destroyOnClose={true}
        onCancel={() => {
          setState(prevState => ({
            ...prevState,
            exportVisible: false
          }))
          uploadFile = null
        }}
        okText="导入"
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 16 }}
        >
          <Form.Item label='选择文件'>
            <Upload
              beforeUpload={file => {
                uploadFile = file
                return false
              }}
              maxCount={1}
            >
              <Button>选择文件</Button>
            </Upload>
          </Form.Item>
          <Form.Item label='下载模板'>
            请先下载 <span className='link-primary' onClick={getTemplate}>导入模板</span> 准备数据后，上传导入
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(BuildingsUnit)